@@ -194,11 +194,17 @@ def ticket_grant(lib: Any, arg_list: Argv, modifiers: InputModifiers) -> None:
 
 def ticket_cleanup(lib: Any, arg_list: Argv, modifiers: InputModifiers) -> None:
     """
-    Options: None
+    Options:
+      * --name - name of a booth instance
     """
-    modifiers.ensure_only_supported()
+    if not arg_list:
+        modifiers.ensure_only_supported("--name")
+        lib.booth.ticket_cleanup_auto(instance_name=modifiers.get("--name"))
+        return
+
     if len(arg_list) != 1:
         raise CmdLineInputError()
+    modifiers.ensure_only_supported()
     lib.booth.ticket_cleanup(arg_list[0])
 
 
