@@ -22,6 +22,8 @@ def middleware_config(config_path, key_path):
         )
     is_mocked_environment = config_path and key_path
 
+    config_file = None
+    key_file = None
     if is_mocked_environment:
         config_file = pcs_file.RawFile(
             metadata.for_file_type(file_type_codes.BOOTH_CONFIG, config_path)
@@ -32,8 +34,14 @@ def middleware_config(config_path, key_path):
 
     def create_booth_env():
         try:
-            config_data = config_file.read() if config_file.exists() else None
-            key_data = key_file.read() if key_file.exists() else None
+            config_data = (
+                config_file.read()
+                if config_file and config_file.exists()
+                else None
+            )
+            key_data = (
+                key_file.read() if key_file and key_file.exists() else None
+            )
         # TODO write custom error handling, do not use pcs.lib specific code
         # and LibraryError
         except pcs_file.RawFileError as e:
