@@ -30,6 +30,7 @@ from pcs.lib.commands import (
 )
 from pcs.lib.commands.constraint import colocation as constraint_colocation
 from pcs.lib.commands.constraint import common as constraint_common
+from pcs.lib.commands.constraint import location as constraint_location
 from pcs.lib.commands.constraint import order as constraint_order
 from pcs.lib.commands.constraint import ticket as constraint_ticket
 from pcs.lib.env import LibraryEnvironment
@@ -159,6 +160,7 @@ def load_module(env, middleware_factory, name):
             "restart": booth.restart,
             "start_booth": booth.start_booth,
             "stop_booth": booth.stop_booth,
+            "ticket_cleanup_auto": booth.ticket_cleanup_auto,
             "ticket_cleanup": booth.ticket_cleanup,
             "ticket_grant": booth.ticket_grant,
             "ticket_revoke": booth.ticket_revoke,
@@ -251,6 +253,15 @@ def load_module(env, middleware_factory, name):
             },
         )
 
+    if name == "constraint_location":
+        return bind_all(
+            env,
+            middleware.build(middleware_factory.cib),
+            {
+                "create_plain_with_rule": constraint_location.create_plain_with_rule,
+            },
+        )
+
     if name == "constraint_order":
         return bind_all(
             env,
@@ -467,7 +478,6 @@ def load_module(env, middleware_factory, name):
             ),
             {
                 "create": stonith.create,
-                "create_in_group": stonith.create_in_group,
                 "history_get_text": stonith.history_get_text,
                 "history_cleanup": stonith.history_cleanup,
                 "history_update": stonith.history_update,
