@@ -11,6 +11,7 @@ from pcs.cli.common.errors import (
     SEE_MAN_CHANGES,
     CmdLineInputError,
 )
+from pcs.cli.reports.output import deprecation_warning
 from pcs.common.const import INFINITY
 from pcs.common.str_tools import (
     format_list,
@@ -79,7 +80,6 @@ PCS_LONG_OPTIONS: Final = [
     "no-default-ops",
     "defaults",
     "nodesc",
-    "master",  # deprecated, replaced by --promoted
     "promoted",
     "name=",
     "group=",
@@ -116,6 +116,8 @@ PCS_LONG_OPTIONS: Final = [
     "agent-validation",
     # disable text output in query commands
     "quiet",
+    # proceed with dangerous actions, meant for / used in CLI only
+    "yes",
 ]
 
 
@@ -560,6 +562,7 @@ class InputModifiers:
                 "--skip-offline": "--skip-offline" in options,
                 "--start": "--start" in options,
                 "--strict": "--strict" in options,
+                "--yes": "--yes" in options,
                 # string values
                 "--after": options.get("--after", None),
                 "--before": options.get("--before", None),
@@ -597,7 +600,7 @@ class InputModifiers:
     def ensure_only_supported(
         self,
         *supported_options: str,
-        hint_syntax_changed: bool = False,
+        hint_syntax_changed: Optional[str] = None,
         output_format_supported: bool = False,
     ) -> None:
         # --debug is supported in all commands
@@ -616,7 +619,7 @@ class InputModifiers:
                 ),
                 hint=(
                     "Syntax has changed from previous version. {}".format(
-                        SEE_MAN_CHANGES.format("0.11")
+                        SEE_MAN_CHANGES.format(hint_syntax_changed)
                     )
                     if hint_syntax_changed
                     else None
@@ -717,3 +720,17 @@ class InputModifiers:
                 supported=format_list(list(supported_formats)),
             )
         )
+
+
+def get_rule_str(argv: Argv) -> Optional[str]:
+    if argv:
+        if len(argv) > 1:
+            # deprecated after 0.11.7
+            deprecation_warning(
+                "Specifying a rule as multiple arguments is deprecated and "
+                "might be removed in a future release, specify the rule as "
+                "a single string instead"
+            )
+            return " ".join(argv)
+        return argv[0]
+    return None
