@@ -564,8 +564,8 @@ class InvalidStonithAgentName(CliReportMessageCustom):
         )
 
 
-class ResourceStonithCommandsMismatch(CliReportMessageCustom):
-    _obj: messages.ResourceStonithCommandsMismatch
+class CommandArgumentTypeMismatch(CliReportMessageCustom):
+    _obj: messages.CommandArgumentTypeMismatch
 
     @property
     def message(self) -> str:
@@ -601,6 +601,19 @@ class AgentSelfValidationResult(CliReportMessageCustom):
         return f"{self._base_msg}{force_text}:\n{self._formatted_result}"
 
 
+class AgentSelfValidationAutoOnWithWarnings(CliReportMessageCustom):
+    _obj: messages.AgentSelfValidationAutoOnWithWarnings
+
+    @property
+    def message(self) -> str:
+        return (
+            "Validating resource options using the resource agent itself is "
+            "enabled by default and produces warnings. In a future version, "
+            "this might be changed to errors. Specify --agent-validation to "
+            "switch to the future behavior."
+        )
+
+
 class BoothAuthfileNotUsed(CliReportMessageCustom):
     _obj: messages.BoothAuthfileNotUsed
 
@@ -637,6 +650,19 @@ class ResourceMoveAutocleanSimulationFailure(CliReportMessageCustom):
         )
 
 
+class ResourceWaitDeprecated(CliReportMessageCustom):
+    _obj: messages.ResourceWaitDeprecated
+
+    @property
+    def message(self) -> str:
+        return (
+            "Using '--wait' is deprecated. Instead, use the 'pcs status wait' "
+            "command to wait for the cluster to settle into stable state. Use "
+            "the 'pcs status query resource' commands to verify that the "
+            "resource is in the expected state after the wait."
+        )
+
+
 def _create_report_msg_map() -> Dict[str, type]:
     result: Dict[str, type] = {}
     for report_msg_cls in get_all_subclasses(CliReportMessageCustom):
