@@ -3,7 +3,6 @@ from typing import (
     List,
     Mapping,
     Sequence,
-    cast,
 )
 
 from pcs.cli.common.errors import CmdLineInputError
@@ -44,9 +43,7 @@ def show_resource_relations_cmd(
             lib.resource.get_resource_relations_tree(argv[0]),
         )
     )
-    for line in tree_to_lines(
-        tree, verbose=cast(bool, modifiers.get("--full"))
-    ):
+    for line in tree_to_lines(tree, verbose=bool(modifiers.get("--full"))):
         print(line)
 
 
