@@ -4,10 +4,6 @@ from pcs import (
 )
 from pcs.cli.booth import command
 from pcs.cli.common.routing import create_router
-from pcs.resource import (
-    resource_remove,
-    resource_restart,
-)
 
 mapping = {
     "help": lambda lib, argv, modifiers: print(usage.booth(argv)),
@@ -18,19 +14,20 @@ mapping = {
         {
             "help": lambda lib, argv, modifiers: print(usage.booth(["ticket"])),
             "add": command.config_ticket_add,
+            "cleanup": command.ticket_cleanup,
             "delete": command.config_ticket_remove,
-            "remove": command.config_ticket_remove,
             "grant": command.ticket_grant,
+            "remove": command.config_ticket_remove,
             "revoke": command.ticket_revoke,
+            "standby": command.ticket_standby,
+            "unstandby": command.ticket_unstandby,
         },
         ["booth", "ticket"],
     ),
     "create": command.create_in_cluster,
-    # ignoring mypy errors, these functions need to be fixed, they are passing
-    # a function to pcs.lib
-    "delete": command.get_remove_from_cluster(resource_remove),  # type:ignore
-    "remove": command.get_remove_from_cluster(resource_remove),  # type:ignore
-    "restart": command.get_restart(resource_restart),  # type:ignore
+    "delete": command.remove_from_cluster,
+    "remove": command.remove_from_cluster,
+    "restart": command.restart,
     "sync": command.sync,
     "pull": command.pull,
     "enable": command.enable,
