@@ -30,9 +30,6 @@ resource_cmd = create_router(
         "meta": resource.meta_cmd,
         "delete": resource.resource_remove_cmd,
         "remove": resource.resource_remove_cmd,
-        # TODO remove, deprecated command
-        # replaced with 'resource status' and 'resource config'
-        "show": resource.resource_show,
         "status": resource.resource_status,
         "config": resource_cli.config,
         "group": create_router(
