@@ -6,6 +6,7 @@ PcmkRoleType = NewType("PcmkRoleType", str)
 PcmkStatusRoleType = NewType("PcmkStatusRoleType", str)
 PcmkOnFailAction = NewType("PcmkOnFailAction", str)
 PcmkAction = NewType("PcmkAction", str)
+ResourceIdType = NewType("ResourceIdType", str)
 
 INFINITY = "INFINITY"
 PCMK_ROLE_STARTED = PcmkRoleType("Started")
@@ -31,14 +32,17 @@ PCMK_ON_FAIL_ACTION_RESTART = PcmkOnFailAction("restart")
 PCMK_ON_FAIL_ACTION_STANDBY = PcmkOnFailAction("standby")
 PCMK_ON_FAIL_ACTION_FENCE = PcmkOnFailAction("fence")
 PCMK_ON_FAIL_ACTION_RESTART_CONTAINER = PcmkOnFailAction("restart-container")
-PCMK_ROLE_PROMOTED_PRIMARY = PCMK_ROLE_PROMOTED
-PCMK_ROLE_UNPROMOTED_PRIMARY = PCMK_ROLE_UNPROMOTED
-PCMK_ROLES_PROMOTED = (PCMK_ROLE_PROMOTED, PCMK_ROLE_PROMOTED_LEGACY)
-PCMK_ROLES_UNPROMOTED = (PCMK_ROLE_UNPROMOTED, PCMK_ROLE_UNPROMOTED_LEGACY)
 PCMK_ROLES_RUNNING = (
-    (PCMK_ROLE_STARTED,) + PCMK_ROLES_PROMOTED + PCMK_ROLES_UNPROMOTED
+    PCMK_ROLE_STARTED,
+    PCMK_ROLE_PROMOTED,
+    PCMK_ROLE_UNPROMOTED,
+)
+PCMK_ROLES_RUNNING_WITH_LEGACY = PCMK_ROLES_RUNNING + (
+    PCMK_ROLE_PROMOTED_LEGACY,
+    PCMK_ROLE_UNPROMOTED_LEGACY,
 )
 PCMK_ROLES = (PCMK_ROLE_STOPPED,) + PCMK_ROLES_RUNNING
+PCMK_ROLES_WITH_LEGACY = (PCMK_ROLE_STOPPED,) + PCMK_ROLES_RUNNING_WITH_LEGACY
 PCMK_STATUS_ROLES_RUNNING = (
     PCMK_STATUS_ROLE_STARTED,
     PCMK_STATUS_ROLE_PROMOTED,
@@ -67,6 +71,11 @@ PCMK_ACTIONS = (
     PCMK_ACTION_DEMOTE,
 )
 PCMK_NEW_ROLES_CIB_VERSION = Version(3, 7, 0)
-PCMK_RULES_NODE_ATTR_EXPR_WITH_INT_TYPE_CIB_VERSION = Version(3, 5, 0)
-PCMK_RULES_WITH_RSC_OR_OP_EXPR_CIB_VERSION = Version(3, 4, 0)
+# CIB schema which supports new rules syntax and options defined in Pacemaker 3.
+# Lower schema is not supported for rules by pcs, as we support Pacemaker 3+
+# only in pcs-0.12.
+PCMK_RULES_PCMK3_SYNTAX_CIB_VERSION = Version(3, 9, 0)
 PCMK_ON_FAIL_DEMOTE_CIB_VERSION = Version(3, 4, 0)
+
+RESOURCE_ID_TYPE_PLAIN = ResourceIdType("resource_id_plain")
+RESOURCE_ID_TYPE_REGEXP = ResourceIdType("resource_id_regexp")
