@@ -1,7 +1,18 @@
 import base64
 import io
 import re
-from collections import namedtuple
+from dataclasses import (
+    dataclass,
+    field,
+)
+from typing import (
+    Generator,
+    Iterable,
+    Mapping,
+    Optional,
+    Sequence,
+    Union,
+)
 from urllib.parse import urlencode
 
 # We should ignore SIGPIPE when using pycurl.NOSIGNAL - see the libcurl tutorial
@@ -15,81 +26,39 @@ except ImportError:
 
 from pcs import settings
 from pcs.common import pcs_pycurl as pycurl
-from pcs.common.host import Destination
-
-
-def _find_value_for_possible_keys(value_dict, possible_key_list):
-    for key in possible_key_list:
-        if key in value_dict:
-            return value_dict[key]
-    return None
+from pcs.common.host import (
+    Destination,
+    PcsKnownHost,
+)
+from pcs.common.types import StringIterable
 
 
 class HostNotFound(Exception):
-    def __init__(self, name):
+    def __init__(self, name: str):
         super().__init__()
         self.name = name
 
 
-class NodeTargetFactory:
-    def __init__(self, known_hosts):
-        self._known_hosts = known_hosts
-
-    def get_target(self, host_name):
-        known_host = self._known_hosts.get(host_name)
-        if known_host is None:
-            raise HostNotFound(host_name)
-        return RequestTarget.from_known_host(known_host)
-
-    def get_target_from_hostname(self, hostname):
-        try:
-            return self.get_target(hostname)
-        except HostNotFound:
-            return RequestTarget(hostname)
-
-
-class RequestData(
-    namedtuple("RequestData", ["action", "structured_data", "data"])
-):
-    """
-    This class represents action and data associated with action which will be
-    send in request
-    """
-
-    def __new__(cls, action, structured_data=(), data=None):
-        """
-        string action -- action to perform
-        list structured_data -- list of tuples, data to send with specified
-            action
-        string data -- raw data to send in request's body
-        """
-        return super(RequestData, cls).__new__(
-            cls,
-            action,
-            data if data else structured_data,
-            data if data else urlencode(structured_data),
-        )
-
-
-class RequestTarget(
-    namedtuple("RequestTarget", ["label", "token", "dest_list"])
-):
+@dataclass(frozen=True)
+class RequestTarget:
     """
     This class represents target (host) for request to be performed on
     """
 
-    def __new__(cls, label, token=None, dest_list=()):
-        if not dest_list:
-            dest_list = [Destination(label, settings.pcsd_default_port)]
-        return super(RequestTarget, cls).__new__(
-            cls,
-            label,
-            token=token,
-            dest_list=list(dest_list),
-        )
+    label: str
+    token: Optional[str] = None
+    dest_list: list[Destination] = field(default_factory=list)
+
+    def __post_init__(self) -> None:
+        if not self.dest_list:
+            object.__setattr__(
+                self,
+                "dest_list",
+                [Destination(self.label, settings.pcsd_default_port)],
+            )
 
     @classmethod
-    def from_known_host(cls, known_host):
+    def from_known_host(cls, known_host: PcsKnownHost) -> "RequestTarget":
         return cls(
             known_host.name,
             token=known_host.token,
@@ -97,29 +66,69 @@ class RequestTarget(
         )
 
     @property
-    def first_addr(self):
-        # __new__ ensures there is always at least one item in self.dest_list
+    def first_addr(self) -> str:
+        # __post_init__ ensures there is always at least one item in
+        # self.dest_list
         return self.dest_list[0].addr
 
 
+class NodeTargetFactory:
+    def __init__(self, known_hosts: Mapping[str, PcsKnownHost]):
+        self._known_hosts = known_hosts
+
+    def get_target(self, host_name: str) -> RequestTarget:
+        known_host = self._known_hosts.get(host_name)
+        if known_host is None:
+            raise HostNotFound(host_name)
+        return RequestTarget.from_known_host(known_host)
+
+    def get_target_from_hostname(self, hostname: str) -> RequestTarget:
+        try:
+            return self.get_target(hostname)
+        except HostNotFound:
+            return RequestTarget(hostname)
+
+
+@dataclass(frozen=True)
+class RequestData:
+    """
+    This class represents action and data associated with action which will be
+    send in request
+
+    action -- action to perform
+    structured_data -- list of tuples, data to send with specified action
+    data -- raw data to send in request's body
+    """
+
+    action: str
+    structured_data: Union[
+        Sequence[tuple[Union[str, bytes], Union[str, bytes]]],
+        Sequence[tuple[Union[str, bytes], Sequence[Union[str, bytes]]]],
+    ] = ()
+    data: str = ""
+
+    def __post_init__(self) -> None:
+        if not self.data:
+            object.__setattr__(self, "data", urlencode(self.structured_data))
+        else:
+            object.__setattr__(self, "structured_data", self.data)
+
+
 class Request:
     """
     This class represents request. With usage of RequestTarget it provides
     interface for getting next available host to make request on.
     """
 
-    def __init__(self, request_target, request_data):
-        """
-        RequestTarget request_target
-        RequestData request_data
-        """
+    def __init__(
+        self, request_target: RequestTarget, request_data: RequestData
+    ) -> None:
         self._target = request_target
         self._data = request_data
         self._current_dest_iterator = iter(self._target.dest_list)
-        self._current_dest = None
         self.next_dest()
 
-    def next_dest(self):
+    def next_dest(self) -> None:
         """
         Move to the next available host connection. Raises StopIteration when
         there is no connection to use.
@@ -127,7 +136,7 @@ class Request:
         self._current_dest = next(self._current_dest_iterator)
 
     @property
-    def url(self):
+    def url(self) -> str:
         """
         URL representing request using current host.
         """
@@ -140,33 +149,33 @@ class Request:
         )
 
     @property
-    def dest(self):
+    def dest(self) -> Destination:
         return self._current_dest
 
     @property
-    def host_label(self):
+    def host_label(self) -> str:
         return self._target.label
 
     @property
-    def target(self):
+    def target(self) -> RequestTarget:
         return self._target
 
     @property
-    def data(self):
+    def data(self) -> str:
         return self._data.data
 
     @property
-    def action(self):
+    def action(self) -> str:
         return self._data.action
 
     @property
-    def cookies(self):
+    def cookies(self) -> dict[str, str]:
         cookies = {}
         if self._target.token:
             cookies["token"] = self._target.token
         return cookies
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return str("Request({0}, {1})").format(self._target, self._data)
 
 
@@ -176,7 +185,13 @@ class Response:
     property.
     """
 
-    def __init__(self, handle, was_connected, errno=None, error_msg=None):
+    def __init__(
+        self,
+        handle: pycurl.Curl,
+        was_connected: bool,
+        errno: Optional[int] = None,
+        error_msg: Optional[str] = None,
+    ) -> None:
         self._handle = handle
         self._was_connected = was_connected
         self._errno = errno
@@ -185,64 +200,66 @@ class Response:
         self._debug = None
 
     @classmethod
-    def connection_successful(cls, handle):
+    def connection_successful(cls, handle: pycurl.Curl) -> "Response":
         """
         Returns Response instance that is marked as successfully connected.
 
-        pycurl.Curl handle -- curl easy handle, which connection was successful
+        handle -- curl easy handle, which connection was successful
         """
         return cls(handle, True)
 
     @classmethod
-    def connection_failure(cls, handle, errno, error_msg):
+    def connection_failure(
+        cls, handle: pycurl.Curl, errno: int, error_msg: str
+    ) -> "Response":
         """
         Returns Response instance that is marked as not successfully connected.
 
-        pycurl.Curl handle -- curl easy handle, which was not connected
-        int errno -- error number
-        string error_msg -- text description of error
+        handle -- curl easy handle, which was not connected
+        errno -- error number
+        error_msg -- text description of error
         """
         return cls(handle, False, errno, error_msg)
 
     @property
-    def request(self):
-        return self._handle.request_obj
+    def request(self) -> Request:
+        return self._handle.request_obj  # type: ignore[attr-defined]
 
     @property
-    def handle(self):
+    def handle(self) -> pycurl.Curl:
         return self._handle
 
     @property
-    def was_connected(self):
+    def was_connected(self) -> bool:
         return self._was_connected
 
     @property
-    def errno(self):
+    def errno(self) -> Optional[int]:
         return self._errno
 
     @property
-    def error_msg(self):
+    def error_msg(self) -> Optional[str]:
         return self._error_msg
 
     @property
-    def data(self):
+    def data(self) -> str:
         if self._data is None:
-            self._data = self._handle.output_buffer.getvalue().decode("utf-8")
-        return self._data
+            self._data = self._handle.output_buffer.getvalue().decode("utf-8")  # type: ignore[attr-defined]
+        return str(self._data)
 
     @property
-    def debug(self):
+    def debug(self) -> str:
         if self._debug is None:
-            self._debug = self._handle.debug_buffer.getvalue().decode("utf-8")
-        return self._debug
+            self._debug = self._handle.debug_buffer.getvalue().decode("utf-8")  # type: ignore[attr-defined]
+        return str(self._debug)
 
     @property
-    def response_code(self):
+    def response_code(self) -> Optional[int]:
         if not self.was_connected:
             return None
         return self._handle.getinfo(pycurl.RESPONSE_CODE)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return str(
             "Response({0} data='{1}' was_connected={2}) errno='{3}'"
             " error_msg='{4}' response_code='{5}')"
@@ -256,27 +273,18 @@ class Response:
         )
 
 
-class NodeCommunicatorFactory:
-    def __init__(self, communicator_logger, user, groups, request_timeout):
-        self._logger = communicator_logger
-        self._user = user
-        self._groups = groups
-        self._request_timeout = request_timeout
+class CommunicatorLoggerInterface:
+    def log_request_start(self, request: Request) -> None:
+        raise NotImplementedError()
 
-    def get_communicator(self, request_timeout=None):
-        return self.get_simple_communicator(request_timeout=request_timeout)
+    def log_response(self, response: Response) -> None:
+        raise NotImplementedError()
 
-    def get_simple_communicator(self, request_timeout=None):
-        timeout = request_timeout if request_timeout else self._request_timeout
-        return Communicator(
-            self._logger, self._user, self._groups, request_timeout=timeout
-        )
+    def log_retry(self, response: Response, previous_dest: Destination) -> None:
+        raise NotImplementedError()
 
-    def get_multiaddress_communicator(self, request_timeout=None):
-        timeout = request_timeout if request_timeout else self._request_timeout
-        return MultiaddressCommunicator(
-            self._logger, self._user, self._groups, request_timeout=timeout
-        )
+    def log_no_more_addresses(self, response: Response) -> None:
+        raise NotImplementedError()
 
 
 class Communicator:
@@ -288,7 +296,13 @@ class Communicator:
 
     curl_multi_select_timeout_default = 0.8  # in seconds
 
-    def __init__(self, communicator_logger, user, groups, request_timeout=None):
+    def __init__(
+        self,
+        communicator_logger: CommunicatorLoggerInterface,
+        user: Optional[str],
+        groups: Optional[StringIterable],
+        request_timeout: Optional[int] = None,
+    ) -> None:
         self._logger = communicator_logger
         self._auth_cookies = _get_auth_cookies(user, groups)
         self._request_timeout = (
@@ -301,9 +315,9 @@ class Communicator:
         # This is used just for storing references of curl easy handles.
         # We need to have references for all the handles, so they don't be
         # cleaned up by the garbage collector.
-        self._easy_handle_list = []
+        self._easy_handle_list: list[pycurl.Curl] = []
 
-    def add_requests(self, request_list):
+    def add_requests(self, request_list: Iterable[Request]) -> None:
         """
         Add requests to queue to be processed. It is possible to call this
         method before getting generator using start_loop method and also during
@@ -312,7 +326,7 @@ class Communicator:
         method is in progress (returned at least one response and not raised
         StopIteration exception).
 
-        list request_list -- Request objects to add to the queue
+        request_list -- Request objects to add to the queue
         """
         for request in request_list:
             handle = _create_request_handle(
@@ -325,7 +339,7 @@ class Communicator:
             if self._is_running:
                 self._logger.log_request_start(request)
 
-    def start_loop(self):
+    def start_loop(self) -> Generator[Response, None, None]:
         """
         Returns generator. When generator is invoked, all requests in queue
         (added by method add_requests) will be invoked in parallel, and
@@ -352,7 +366,7 @@ class Communicator:
             raise AssertionError("Method start_loop already running")
         self._is_running = True
         for handle in self._easy_handle_list:
-            self._logger.log_request_start(handle.request_obj)
+            self._logger.log_request_start(handle.request_obj)  # type: ignore[attr-defined]
 
         finished_count = 0
         while finished_count < len(self._easy_handle_list):
@@ -372,7 +386,7 @@ class Communicator:
         self._easy_handle_list = []
         self._is_running = False
 
-    def __get_all_ready_responses(self):
+    def __get_all_ready_responses(self) -> list[Response]:
         response_list = []
         repeat = True
         while repeat:
@@ -387,7 +401,7 @@ class Communicator:
             repeat = num_queued > 0
         return response_list
 
-    def __multi_perform(self):
+    def __multi_perform(self) -> int:
         # run all internal operation required by libcurl
         status, num_to_process = self._multi_handle.perform()
         # if perform returns E_CALL_MULTI_PERFORM it requires to call perform
@@ -396,7 +410,7 @@ class Communicator:
             status, num_to_process = self._multi_handle.perform()
         return num_to_process
 
-    def __wait_for_multi_handle(self):
+    def __wait_for_multi_handle(self) -> None:
         # try to wait until there is something to do for us
         need_to_wait = True
         while need_to_wait:
@@ -404,7 +418,7 @@ class Communicator:
             if timeout == 0:
                 # if timeout == 0 then there is something to precess already
                 return
-            timeout = (
+            select_timeout = (
                 timeout / 1000.0
                 if timeout > 0
                 # curl don't have timeout set, so we can use our default
@@ -412,7 +426,7 @@ class Communicator:
             )
             # when value returned from select is -1, it timed out, so we can
             # wait
-            need_to_wait = self._multi_handle.select(timeout) == -1
+            need_to_wait = self._multi_handle.select(select_timeout) == -1
 
 
 class MultiaddressCommunicator(Communicator):
@@ -423,7 +437,7 @@ class MultiaddressCommunicator(Communicator):
     until connection will be successful or there is no host left.
     """
 
-    def start_loop(self):
+    def start_loop(self) -> Generator[Response, None, None]:
         for response in super().start_loop():
             if response.was_connected:
                 yield response
@@ -431,34 +445,58 @@ class MultiaddressCommunicator(Communicator):
             try:
                 previous_dest = response.request.dest
                 response.request.next_dest()
-                self._logger.log_retry(response, previous_dest)
+                if previous_dest is not None:
+                    self._logger.log_retry(response, previous_dest)
                 self.add_requests([response.request])
             except StopIteration:
                 self._logger.log_no_more_addresses(response)
                 yield response
 
 
-class CommunicatorLoggerInterface:
-    def log_request_start(self, request):
-        raise NotImplementedError()
+class NodeCommunicatorFactory:
+    def __init__(
+        self,
+        communicator_logger: CommunicatorLoggerInterface,
+        user: Optional[str],
+        groups: Optional[StringIterable],
+        request_timeout: Optional[int],
+    ) -> None:
+        self._logger = communicator_logger
+        self._user = user
+        self._groups = groups
+        self._request_timeout = request_timeout
 
-    def log_response(self, response):
-        raise NotImplementedError()
+    def get_communicator(
+        self, request_timeout: Optional[int] = None
+    ) -> Communicator:
+        return self.get_simple_communicator(request_timeout=request_timeout)
 
-    def log_retry(self, response, previous_dest):
-        raise NotImplementedError()
+    def get_simple_communicator(
+        self, request_timeout: Optional[int] = None
+    ) -> Communicator:
+        timeout = request_timeout if request_timeout else self._request_timeout
+        return Communicator(
+            self._logger, self._user, self._groups, request_timeout=timeout
+        )
 
-    def log_no_more_addresses(self, response):
-        raise NotImplementedError()
+    def get_multiaddress_communicator(
+        self, request_timeout: Optional[int] = None
+    ) -> MultiaddressCommunicator:
+        timeout = request_timeout if request_timeout else self._request_timeout
+        return MultiaddressCommunicator(
+            self._logger, self._user, self._groups, request_timeout=timeout
+        )
 
 
-def _get_auth_cookies(user, group_list):
+def _get_auth_cookies(
+    user: Optional[str], group_list: Optional[StringIterable]
+) -> dict[str, str]:
     """
     Returns input parameters in a dictionary which is prepared to be converted
     to cookie string.
 
-    string user -- CIB user
-    string group_list -- CIB user groups
+    user -- CIB user
+    group_list -- CIB user groups
     """
     # Let's be safe about characters in variables (they can come from env)
     # and do base64. We cannot do it for CIB_user however to be backward
@@ -475,25 +513,28 @@ def _get_auth_cookies(user, group_list):
     return cookies
 
 
-def _create_request_handle(request, cookies, timeout):
+def _create_request_handle(
+    request: Request, cookies: Mapping[str, str], timeout: int
+) -> pycurl.Curl:
     """
-    Returns Curl object (easy handle) which is set up witc specified parameters.
+    Returns Curl object (easy handle) which is set up with specified parameters.
 
-    Request request -- request specification
-    dict cookies -- cookies to add to request
-    int timeout -- request timeout
+    request -- request specification
+    cookies -- cookies to add to request
+    timeout -- request timeout
     """
 
     # it is not possible to take this callback out of this function, because of
     # curl API
-    def __debug_callback(data_type, debug_data):
+    def __debug_callback(data_type: int, debug_data: bytes) -> None:
         # pylint: disable=no-member
         prefixes = {
-            pycurl.DEBUG_TEXT: b"* ",
-            pycurl.DEBUG_HEADER_IN: b"< ",
-            pycurl.DEBUG_HEADER_OUT: b"> ",
-            pycurl.DEBUG_DATA_IN: b"<< ",
-            pycurl.DEBUG_DATA_OUT: b">> ",
+            # Dynamically added attributes in pcs/common/pcs_pycurl.py
+            pycurl.DEBUG_TEXT: b"* ",  # type: ignore[attr-defined]
+            pycurl.DEBUG_HEADER_IN: b"< ",  # type: ignore[attr-defined]
+            pycurl.DEBUG_HEADER_OUT: b"> ",  # type: ignore[attr-defined]
+            pycurl.DEBUG_DATA_IN: b"<< ",  # type: ignore[attr-defined]
+            pycurl.DEBUG_DATA_OUT: b">> ",  # type: ignore[attr-defined]
         }
         if data_type in prefixes:
             debug_output.write(prefixes[data_type])
@@ -503,7 +544,8 @@ def _create_request_handle(request, cookies, timeout):
 
     output = io.BytesIO()
     debug_output = io.BytesIO()
-    cookies.update(request.cookies)
+    handle_cookies = dict(cookies.items())
+    handle_cookies.update(request.cookies)
     handle = pycurl.Curl()
     handle.setopt(pycurl.PROTOCOLS, pycurl.PROTO_HTTPS)
     handle.setopt(pycurl.TIMEOUT, timeout)
@@ -515,8 +557,10 @@ def _create_request_handle(request, cookies, timeout):
     handle.setopt(pycurl.SSL_VERIFYPEER, 0)
     handle.setopt(pycurl.NOSIGNAL, 1)  # required for multi-threading
     handle.setopt(pycurl.HTTPHEADER, ["Expect: "])
-    if cookies:
-        handle.setopt(pycurl.COOKIE, _dict_to_cookies(cookies).encode("utf-8"))
+    if handle_cookies:
+        handle.setopt(
+            pycurl.COOKIE, _dict_to_cookies(handle_cookies).encode("utf-8")
+        )
     if request.data:
         handle.setopt(pycurl.COPYPOSTFIELDS, request.data.encode("utf-8"))
     # add reference for request object and output buffers to handle, so later
@@ -524,13 +568,13 @@ def _create_request_handle(request, cookies, timeout):
     # pycurl after they've been processed
     # similar usage is in pycurl example:
     # https://github.com/pycurl/pycurl/blob/REL_7_19_0_3/examples/retriever-multi.py
-    handle.request_obj = request
-    handle.output_buffer = output
-    handle.debug_buffer = debug_output
+    handle.request_obj = request  # type: ignore[attr-defined]
+    handle.output_buffer = output  # type: ignore[attr-defined]
+    handle.debug_buffer = debug_output  # type: ignore[attr-defined]
     return handle
 
 
-def _dict_to_cookies(cookies_dict):
+def _dict_to_cookies(cookies_dict: Mapping[str, str]) -> str:
     return ";".join(
         [f"{key}={value}" for key, value in sorted(cookies_dict.items())]
     )
