@@ -44,6 +44,9 @@ AGENT_IMPLEMENTS_UNSUPPORTED_OCF_VERSION = M(
 AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE = M("AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE")
 AGENT_NAME_GUESS_FOUND_NONE = M("AGENT_NAME_GUESS_FOUND_NONE")
 AGENT_NAME_GUESSED = M("AGENT_NAME_GUESSED")
+AGENT_SELF_VALIDATION_AUTO_ON_WITH_WARNINGS = M(
+    "AGENT_SELF_VALIDATION_AUTO_ON_WITH_WARNINGS"
+)
 AGENT_SELF_VALIDATION_INVALID_DATA = M("AGENT_SELF_VALIDATION_INVALID_DATA")
 AGENT_SELF_VALIDATION_SKIPPED_UPDATED_RESOURCE_MISCONFIGURED = M(
     "AGENT_SELF_VALIDATION_SKIPPED_UPDATED_RESOURCE_MISCONFIGURED"
@@ -163,6 +166,9 @@ CLUSTER_DESTROY_STARTED = M("CLUSTER_DESTROY_STARTED")
 CLUSTER_DESTROY_SUCCESS = M("CLUSTER_DESTROY_SUCCESS")
 CLUSTER_ENABLE_STARTED = M("CLUSTER_ENABLE_STARTED")
 CLUSTER_ENABLE_SUCCESS = M("CLUSTER_ENABLE_SUCCESS")
+CLUSTER_OPTIONS_METADATA_NOT_SUPPORTED = M(
+    "CLUSTER_OPTIONS_METADATA_NOT_SUPPORTED"
+)
 CLUSTER_RESTART_REQUIRED_TO_APPLY_CHANGES = M(
     "CLUSTER_RESTART_REQUIRED_TO_APPLY_CHANGES"
 )
@@ -176,12 +182,15 @@ CLUSTER_UUID_ALREADY_SET = M("CLUSTER_UUID_ALREADY_SET")
 CLUSTER_WILL_BE_DESTROYED = M("CLUSTER_WILL_BE_DESTROYED")
 COMMAND_INVALID_PAYLOAD = M("COMMAND_INVALID_PAYLOAD")
 COMMAND_UNKNOWN = M("COMMAND_UNKNOWN")
+CONFIGURED_RESOURCE_MISSING_IN_STATUS = M(
+    "CONFIGURED_RESOURCE_MISSING_IN_STATUS"
+)
 LIVE_ENVIRONMENT_NOT_CONSISTENT = M("LIVE_ENVIRONMENT_NOT_CONSISTENT")
 LIVE_ENVIRONMENT_REQUIRED = M("LIVE_ENVIRONMENT_REQUIRED")
 LIVE_ENVIRONMENT_REQUIRED_FOR_LOCAL_NODE = M(
     "LIVE_ENVIRONMENT_REQUIRED_FOR_LOCAL_NODE"
 )
-RESOURCE_STONITH_COMMANDS_MISMATCH = M("RESOURCE_STONITH_COMMANDS_MISMATCH")
+COMMAND_ARGUMENT_TYPE_MISMATCH = M("COMMAND_ARGUMENT_TYPE_MISMATCH")
 COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK = M(
     "COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK"
 )
@@ -302,6 +311,7 @@ ID_NOT_FOUND = M("ID_NOT_FOUND")
 INVALID_CIB_CONTENT = M("INVALID_CIB_CONTENT")
 INVALID_ID_BAD_CHAR = M("INVALID_ID_BAD_CHAR")
 INVALID_ID_IS_EMPTY = M("INVALID_ID_IS_EMPTY")
+INVALID_ID_TYPE = M("INVALID_ID_TYPE")
 INVALID_OPTIONS = M("INVALID_OPTIONS")
 INVALID_USERDEFINED_OPTIONS = M("INVALID_USERDEFINED_OPTIONS")
 INVALID_OPTION_TYPE = M("INVALID_OPTION_TYPE")
@@ -481,6 +491,7 @@ RESOURCE_MOVE_AFFECTS_OTRHER_RESOURCES = M(
 RESOURCE_MOVE_AUTOCLEAN_SIMULATION_FAILURE = M(
     "RESOURCE_MOVE_AUTOCLEAN_SIMULATION_FAILURE"
 )
+RESOURCE_WAIT_DEPRECATED = M("RESOURCE_WAIT_DEPRECATED")
 RULE_IN_EFFECT_STATUS_DETECTION_NOT_SUPPORTED = M(
     "RULE_IN_EFFECT_STATUS_DETECTION_NOT_SUPPORTED"
 )
@@ -490,6 +501,7 @@ RULE_EXPRESSION_PARSE_ERROR = M("RULE_EXPRESSION_PARSE_ERROR")
 RULE_EXPRESSION_SINCE_GREATER_THAN_UNTIL = M(
     "RULE_EXPRESSION_SINCE_GREATER_THAN_UNTIL"
 )
+RULE_NO_EXPRESSION_SPECIFIED = M("RULE_NO_EXPRESSION_SPECIFIED")
 RUN_EXTERNAL_PROCESS_ERROR = M("RUN_EXTERNAL_PROCESS_ERROR")
 RUN_EXTERNAL_PROCESS_FINISHED = M("RUN_EXTERNAL_PROCESS_FINISHED")
 RUN_EXTERNAL_PROCESS_STARTED = M("RUN_EXTERNAL_PROCESS_STARTED")
@@ -623,8 +635,6 @@ USE_COMMAND_NODE_ADD_REMOTE = M("USE_COMMAND_NODE_ADD_REMOTE")
 USE_COMMAND_NODE_ADD_GUEST = M("USE_COMMAND_NODE_ADD_GUEST")
 USE_COMMAND_NODE_REMOVE_REMOTE = M("USE_COMMAND_NODE_REMOVE_REMOTE")
 USE_COMMAND_NODE_REMOVE_GUEST = M("USE_COMMAND_NODE_REMOVE_GUEST")
-REMOTE_NODE_REMOVAL_INCOMPLETE = M("REMOTE_NODE_REMOVAL_INCOMPLETE")
-GUEST_NODE_REMOVAL_INCOMPLETE = M("GUEST_NODE_REMOVAL_INCOMPLETE")
 USING_DEFAULT_ADDRESS_FOR_HOST = M("USING_DEFAULT_ADDRESS_FOR_HOST")
 USING_DEFAULT_WATCHDOG = M("USING_DEFAULT_WATCHDOG")
 WAIT_FOR_IDLE_STARTED = M("WAIT_FOR_IDLE_STARTED")
