@@ -21,7 +21,6 @@ from pcs import (
     quorum,
     settings,
     status,
-    stonith,
     usage,
     utils,
 )
@@ -46,6 +45,8 @@ from pcs.cli.resource.output import (
     ResourcesConfigurationFacade,
     resources_to_text,
 )
+from pcs.cli.stonith.levels.output import stonith_level_config_to_text
+from pcs.cli.tag.output import tags_to_text
 from pcs.common.interface import dto
 from pcs.common.pacemaker.constraint import CibConstraintsDto
 from pcs.common.str_tools import indent
@@ -151,8 +152,8 @@ def _config_show_cib_lines(lib, properties_facade=None):
         all_lines.append("Stonith Devices:")
         all_lines.extend(stonith_lines)
 
-    levels_lines = stonith.stonith_level_config_to_str(
-        lib.fencing_topology.get_config()
+    levels_lines = stonith_level_config_to_text(
+        lib.fencing_topology.get_config_dto()
     )
     if levels_lines:
         if all_lines:
@@ -220,15 +221,11 @@ def _config_show_cib_lines(lib, properties_facade=None):
             all_lines.append("")
         all_lines.extend(properties_lines)
 
-    tags = lib.tag.config([])
-    if tags:
+    tag_lines = smart_wrap_text(tags_to_text(lib.tag.get_config_dto([])))
+    if tag_lines:
         if all_lines:
             all_lines.append("")
         all_lines.append("Tags:")
-        tag_lines = []
-        for tag in tags:
-            tag_lines.append(tag["tag_id"])
-            tag_lines.extend(indent(tag["idref_list"]))
         all_lines.extend(indent(tag_lines, indent_step=1))
 
     return all_lines
@@ -809,9 +806,11 @@ def config_checkpoint_diff(lib, argv, modifiers):
     print(
         "Differences between {0} (-) and {1} (+):".format(
             *[
-                "live configuration"
-                if label == "live"
-                else f"checkpoint {label}"
+                (
+                    "live configuration"
+                    if label == "live"
+                    else f"checkpoint {label}"
+                )
                 for label in argv
             ]
         )
