@@ -12,15 +12,20 @@ from typing import (
 from xml.dom.minidom import parseString
 
 import pcs.cli.constraint_order.command as order_command
-from pcs import rule as rule_utils
 from pcs import utils
 from pcs.cli.common import parse_args
-from pcs.cli.common.errors import CmdLineInputError
+from pcs.cli.common.errors import (
+    CmdLineInputError,
+    raise_command_replaced,
+)
 from pcs.cli.common.output import (
     INDENT_STEP,
     lines_to_str,
 )
-from pcs.cli.constraint.location import command as location_command
+from pcs.cli.constraint.location.command import (
+    RESOURCE_TYPE_REGEXP,
+    RESOURCE_TYPE_RESOURCE,
+)
 from pcs.cli.constraint.output import (
     CibConstraintLocationAnyDto,
     filter_constraints_by_rule_expired_status,
@@ -70,7 +75,6 @@ from pcs.lib.pacemaker.values import (
 # pylint: disable=too-many-branches
 # pylint: disable=too-many-lines
 # pylint: disable=too-many-locals
-# pylint: disable=too-many-nested-blocks
 # pylint: disable=too-many-statements
 
 DEFAULT_ACTION = const.PCMK_ACTION_START
@@ -81,9 +85,10 @@ OPTIONS_SYMMETRICAL = order_attrib["symmetrical"]
 LOCATION_NODE_VALIDATION_SKIP_MSG = (
     "Validation for node existence in the cluster will be skipped"
 )
-
-RESOURCE_TYPE_RESOURCE = "resource"
-RESOURCE_TYPE_REGEXP = "regexp"
+STANDALONE_SCORE_MSG = (
+    "Specifying score as a standalone value is deprecated and "
+    "might be removed in a future release, use score=value instead"
+)
 
 
 class CrmRuleReturnCode(Enum):
@@ -92,34 +97,6 @@ class CrmRuleReturnCode(Enum):
     TO_BE_IN_EFFECT = 111
 
 
-def constraint_location_cmd(lib, argv, modifiers):
-    if not argv:
-        sub_cmd = "config"
-    else:
-        sub_cmd = argv.pop(0)
-
-    try:
-        if sub_cmd == "add":
-            location_add(lib, argv, modifiers)
-        elif sub_cmd in ["remove", "delete"]:
-            location_command.remove(lib, argv, modifiers)
-        elif sub_cmd == "show":
-            location_show(lib, argv, modifiers)
-        elif sub_cmd == "config":
-            location_config_cmd(lib, argv, modifiers)
-        elif len(argv) >= 2:
-            if argv[0] == "rule":
-                location_rule(lib, [sub_cmd] + argv, modifiers)
-            else:
-                location_prefer(lib, [sub_cmd] + argv, modifiers)
-        else:
-            raise CmdLineInputError()
-    except CmdLineInputError as e:
-        utils.exit_on_cmdline_input_error(
-            e, "constraint", ["location", sub_cmd]
-        )
-
-
 def constraint_order_cmd(lib, argv, modifiers):
     if not argv:
         sub_cmd = "config"
@@ -132,7 +109,9 @@ def constraint_order_cmd(lib, argv, modifiers):
         elif sub_cmd in ["remove", "delete"]:
             order_rm(lib, argv, modifiers)
         elif sub_cmd == "show":
-            order_command.show(lib, argv, modifiers)
+            raise_command_replaced(
+                ["pcs constraint order config"], pcs_version="0.12"
+            )
         elif sub_cmd == "config":
             order_command.config_cmd(lib, argv, modifiers)
         else:
@@ -141,14 +120,6 @@ def constraint_order_cmd(lib, argv, modifiers):
         utils.exit_on_cmdline_input_error(e, "constraint", ["order", sub_cmd])
 
 
-def constraint_show(lib, argv, modifiers):
-    deprecation_warning(
-        "This command is deprecated and will be removed. "
-        "Please use 'pcs constraint config' instead."
-    )
-    config_cmd(lib, argv, modifiers)
-
-
 def config_cmd(
     lib: Any, argv: list[str], modifiers: parse_args.InputModifiers
 ) -> None:
@@ -190,6 +161,8 @@ def _validate_resources_not_in_same_group(cib_dom, resource1, resource2):
 #        <src> with <role> <tgt> [score] [options]
 # <role> <src> with        <tgt> [score] [options]
 # <role> <src> with <role> <tgt> [score] [options]
+# Specifying score as a single argument is deprecated, though. The correct way
+# is score=value in options.
 def colocation_add(lib, argv, modifiers):
     """
     Options:
@@ -205,8 +178,13 @@ def colocation_add(lib, argv, modifiers):
         Commandline options: no options
         """
         if not argv:
-            return SCORE_INFINITY, []
-        score = SCORE_INFINITY if "=" in argv[0] else argv.pop(0)
+            return None, []
+        score = None
+        if "=" not in argv[0]:
+            score = argv.pop(0)
+            # TODO added to pcs in the first 0.12.x version
+            deprecation_warning(STANDALONE_SCORE_MSG)
+
         # create a list of 2-tuples (name, value)
         arg_array = [
             parse_args.split_option(arg, allow_empty_value=False)
@@ -235,7 +213,6 @@ def colocation_add(lib, argv, modifiers):
                     role, format_list(const.PCMK_ROLES)
                 )
             )
-        utils.print_depracation_warning_for_legacy_roles(role)
         return pacemaker.role.get_value_for_cib(
             role_cleaned, new_roles_supported
         )
@@ -288,6 +265,10 @@ def colocation_add(lib, argv, modifiers):
                     % value
                 )
             id_in_nvpairs = True
+        elif name == "score":
+            score = value
+    if score is None:
+        score = SCORE_INFINITY
     if not id_in_nvpairs:
         nv_pairs.append(
             (
@@ -674,14 +655,6 @@ def order_find_duplicates(dom, constraint_el):
     ]
 
 
-def location_show(lib, argv, modifiers):
-    deprecation_warning(
-        "This command is deprecated and will be removed. "
-        "Please use 'pcs constraint location config' instead."
-    )
-    return location_config_cmd(lib, argv, modifiers)
-
-
 _SetConstraint = TypeVar(
     "_SetConstraint",
     CibConstraintLocationSetDto,
@@ -772,7 +745,7 @@ def _filter_location_by_node_base(
 
 
 def location_config_cmd(
-    lib: Any, argv: StringSequence, modifiers: parse_args.InputModifiers
+    lib: Any, argv: parse_args.Argv, modifiers: parse_args.InputModifiers
 ) -> None:
     """
     Options:
@@ -876,7 +849,9 @@ def _verify_score(score):
         )
 
 
-def location_prefer(lib, argv, modifiers):
+def location_prefer(
+    lib: Any, argv: parse_args.Argv, modifiers: parse_args.InputModifiers
+) -> None:
     """
     Options:
       * --force - allow unknown options, allow constraint for any resource type
@@ -939,7 +914,7 @@ def location_prefer(lib, argv, modifiers):
                 sanitize_id(f"location-{rsc_value}-{node}-{score}"),
                 rsc,
                 node,
-                score,
+                f"score={score}",
             ]
         )
 
@@ -952,7 +927,12 @@ def location_prefer(lib, argv, modifiers):
         location_add(lib, parameters, modifiers, skip_score_and_node_check=True)
 
 
-def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
+def location_add(
+    lib: Any,
+    argv: parse_args.Argv,
+    modifiers: parse_args.InputModifiers,
+    skip_score_and_node_check: bool = False,
+) -> None:
     """
     Options:
       * --force - allow unknown options, allow constraint for any resource type
@@ -970,43 +950,43 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
         RESOURCE_TYPE_RESOURCE,
     )
     node = argv.pop(0)
-    score = argv.pop(0)
+    score = None
+    if "=" not in argv[0]:
+        score = argv.pop(0)
+        # TODO added to pcs in the first 0.12.x version
+        deprecation_warning(STANDALONE_SCORE_MSG)
     options = []
-    # For now we only allow setting resource-discovery
-    if argv:
-        for arg in argv:
-            if "=" in arg:
-                name, value = arg.split("=", 1)
-                if name == "resource-discovery":
-                    if not modifiers.get("--force"):
-                        allowed_discovery = list(
-                            map(
-                                str,
-                                [
-                                    CibResourceDiscovery.ALWAYS,
-                                    CibResourceDiscovery.EXCLUSIVE,
-                                    CibResourceDiscovery.NEVER,
-                                ],
-                            )
-                        )
-                        if value not in allowed_discovery:
-                            utils.err(
-                                (
-                                    "invalid {0} value '{1}', allowed values are: "
-                                    "{2}, use --force to override"
-                                ).format(
-                                    name, value, format_list(allowed_discovery)
-                                )
-                            )
-                options.append([name, value])
-            else:
-                raise CmdLineInputError(f"bad option '{arg}'")
-            if options[-1][0] != "resource-discovery" and not modifiers.get(
-                "--force"
-            ):
-                utils.err(
-                    "bad option '%s', use --force to override" % options[-1][0]
+    # For now we only allow setting resource-discovery and score
+    for arg in argv:
+        name, value = parse_args.split_option(arg, allow_empty_value=False)
+        if name == "score":
+            score = value
+        elif name == "resource-discovery":
+            if not modifiers.get("--force"):
+                allowed_discovery = list(
+                    map(
+                        str,
+                        [
+                            CibResourceDiscovery.ALWAYS,
+                            CibResourceDiscovery.EXCLUSIVE,
+                            CibResourceDiscovery.NEVER,
+                        ],
+                    )
                 )
+                if value not in allowed_discovery:
+                    utils.err(
+                        (
+                            "invalid {0} value '{1}', allowed values are: {2}"
+                            ", use --force to override"
+                        ).format(name, value, format_list(allowed_discovery))
+                    )
+            options.append([name, value])
+        elif modifiers.get("--force"):
+            options.append([name, value])
+        else:
+            utils.err("bad option '%s', use --force to override" % name)
+    if score is None:
+        score = "INFINITY"
 
     # Verify that specified node exists in the cluster and score is valid
     if not skip_score_and_node_check:
@@ -1077,174 +1057,6 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
     utils.replace_cib_configuration(dom)
 
 
-def location_rule(lib, argv, modifiers):
-    """
-    Options:
-      * -f - CIB file
-      * --force - allow constraint on any resource type, allow duplicate
-        constraints
-    """
-    del lib
-    modifiers.ensure_only_supported("-f", "--force")
-    if len(argv) < 3:
-        raise CmdLineInputError()
-
-    rsc_type, rsc_value = parse_args.parse_typed_arg(
-        argv.pop(0),
-        [RESOURCE_TYPE_RESOURCE, RESOURCE_TYPE_REGEXP],
-        RESOURCE_TYPE_RESOURCE,
-    )
-    argv.pop(0)  # pop "rule"
-    options, rule_argv = rule_utils.parse_argv(
-        argv,
-        {
-            "constraint-id": None,
-            "resource-discovery": None,
-        },
-    )
-    resource_discovery = (
-        "resource-discovery" in options and options["resource-discovery"]
-    )
-
-    try:
-        # Parse the rule to see if we need to upgrade CIB schema. All errors
-        # would be properly reported by a validator called bellow, so we can
-        # safely ignore them here.
-        parsed_rule = rule_utils.RuleParser().parse(
-            rule_utils.TokenPreprocessor().run(rule_argv)
-        )
-        if rule_utils.has_node_attr_expr_with_type_integer(parsed_rule):
-            utils.checkAndUpgradeCIB(
-                const.PCMK_RULES_NODE_ATTR_EXPR_WITH_INT_TYPE_CIB_VERSION
-            )
-    except (rule_utils.ParserException, rule_utils.CibBuilderException):
-        pass
-
-    dom = utils.get_cib_dom()
-
-    if rsc_type == RESOURCE_TYPE_RESOURCE:
-        (
-            rsc_valid,
-            rsc_error,
-            dummy_correct_id,
-        ) = utils.validate_constraint_resource(dom, rsc_value)
-        if not rsc_valid:
-            utils.err(rsc_error)
-
-    cib, constraints = getCurrentConstraints(dom)
-    lc = cib.createElement("rsc_location")
-
-    # If resource-discovery is specified, we use it with the rsc_location
-    # element not the rule
-    if resource_discovery:
-        if not modifiers.get("--force"):
-            allowed_discovery = list(
-                map(
-                    str,
-                    [
-                        CibResourceDiscovery.ALWAYS,
-                        CibResourceDiscovery.EXCLUSIVE,
-                        CibResourceDiscovery.NEVER,
-                    ],
-                )
-            )
-            if resource_discovery not in allowed_discovery:
-                utils.err(
-                    (
-                        "invalid {0} value '{1}', allowed values are: {2}, "
-                        "use --force to override"
-                    ).format(
-                        "resource-discovery",
-                        resource_discovery,
-                        format_list(allowed_discovery),
-                    )
-                )
-        lc.setAttribute("resource-discovery", options.pop("resource-discovery"))
-
-    constraints.appendChild(lc)
-    if options.get("constraint-id"):
-        id_valid, id_error = utils.validate_xml_id(
-            options["constraint-id"], "constraint id"
-        )
-        if not id_valid:
-            utils.err(id_error)
-        if utils.does_id_exist(dom, options["constraint-id"]):
-            utils.err(
-                "id '%s' is already in use, please specify another one"
-                % options["constraint-id"]
-            )
-        lc.setAttribute("id", options["constraint-id"])
-        del options["constraint-id"]
-    else:
-        lc.setAttribute(
-            "id",
-            utils.find_unique_id(dom, sanitize_id("location-" + rsc_value)),
-        )
-    if rsc_type == RESOURCE_TYPE_RESOURCE:
-        lc.setAttribute("rsc", rsc_value)
-    elif rsc_type == RESOURCE_TYPE_REGEXP:
-        lc.setAttribute("rsc-pattern", rsc_value)
-
-    rule_utils.dom_rule_add(
-        lc, options, rule_argv, utils.getValidateWithVersion(cib)
-    )
-    location_rule_check_duplicates(constraints, lc, modifiers.get("--force"))
-    utils.replace_cib_configuration(cib)
-
-
-def location_rule_check_duplicates(dom, constraint_el, force):
-    """
-    Commandline options: no options
-    """
-    if not force:
-        duplicates = location_rule_find_duplicates(dom, constraint_el)
-        if duplicates:
-            lines = []
-            for dup in duplicates:
-                lines.append("  Constraint: %s" % dup.getAttribute("id"))
-                for dup_rule in utils.dom_get_children_by_tag_name(dup, "rule"):
-                    lines.append(
-                        rule_utils.ExportDetailed().get_string(
-                            dup_rule, False, True, indent="    "
-                        )
-                    )
-            utils.err(
-                "duplicate constraint already exists, use --force to override\n"
-                + "\n".join(lines)
-            )
-
-
-def location_rule_find_duplicates(dom, constraint_el):
-    """
-    Commandline options: no options
-    """
-
-    def normalize(constraint_el):
-        if constraint_el.hasAttribute("rsc-pattern"):
-            rsc = (
-                RESOURCE_TYPE_REGEXP,
-                constraint_el.getAttribute("rsc-pattern"),
-            )
-        else:
-            rsc = (RESOURCE_TYPE_RESOURCE, constraint_el.getAttribute("rsc"))
-        return (
-            rsc,
-            [
-                rule_utils.ExportAsExpression().get_string(rule_el, True)
-                for rule_el in constraint_el.getElementsByTagName("rule")
-            ],
-        )
-
-    normalized_el = normalize(constraint_el)
-    return [
-        other_el
-        for other_el in dom.getElementsByTagName("rsc_location")
-        if other_el.getElementsByTagName("rule")
-        and constraint_el is not other_el
-        and normalized_el == normalize(other_el)
-    ]
-
-
 # Grabs the current constraints and returns the dom and constraint element
 def getCurrentConstraints(passed_dom=None):
     """
@@ -1514,53 +1326,3 @@ def constraint_resource_update(old_id, dom):
                 if constraint.getAttribute(attr) == old_id:
                     constraint.setAttribute(attr, new_id)
     return dom
-
-
-def constraint_rule_add(lib, argv, modifiers):
-    """
-    Options:
-      * -f - CIB file
-      * --force - allow duplicate constraints
-    """
-    # deprecated in pacemaker 2, removed in pacemaker 3
-    # added to pcs after 0.11.8
-    # the whole command removed in pcs-0.12
-    deprecation_warning(
-        "The possibility of defining multiple rules in a single location "
-        "constraint is deprecated and will be removed."
-    )
-    del lib
-    modifiers.ensure_only_supported("-f", "--force")
-    if not argv:
-        raise CmdLineInputError()
-    constraint_id = argv.pop(0)
-    options, rule_argv = rule_utils.parse_argv(argv)
-    try:
-        # Parse the rule to see if we need to upgrade CIB schema. All errors
-        # would be properly reported by a validator called bellow, so we can
-        # safely ignore them here.
-        parsed_rule = rule_utils.RuleParser().parse(
-            rule_utils.TokenPreprocessor().run(rule_argv)
-        )
-        if rule_utils.has_node_attr_expr_with_type_integer(parsed_rule):
-            utils.checkAndUpgradeCIB(
-                const.PCMK_RULES_NODE_ATTR_EXPR_WITH_INT_TYPE_CIB_VERSION
-            )
-    except (rule_utils.ParserException, rule_utils.CibBuilderException):
-        pass
-    cib = utils.get_cib_dom()
-    constraint = utils.dom_get_element_with_id(
-        cib.getElementsByTagName("constraints")[0],
-        "rsc_location",
-        constraint_id,
-    )
-    if not constraint:
-        utils.err("Unable to find constraint: " + constraint_id)
-    rule_utils.dom_rule_add(
-        constraint,
-        options,
-        rule_argv,
-        utils.getValidateWithVersion(cib),
-    )
-    location_rule_check_duplicates(cib, constraint, modifiers.get("--force"))
-    utils.replace_cib_configuration(cib)
