@@ -6,4 +6,4 @@ from pcs.common.async_tasks.dto import CommandDto
 @dataclass(frozen=True)
 class Command:
     command_dto: CommandDto
-    api_v1_compatible: bool = False
+    is_legacy_command: bool = False
