@@ -113,6 +113,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=booth.ticket_cleanup,
         required_permission=p.WRITE,
     ),
+    "booth.ticket_cleanup_auto": _Cmd(
+        cmd=booth.ticket_cleanup_auto,
+        required_permission=p.WRITE,
+    ),
     "booth.ticket_standby": _Cmd(
         cmd=booth.ticket_standby,
         required_permission=p.WRITE,
@@ -177,6 +181,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=constraint.colocation.create_with_set,
         required_permission=p.WRITE,
     ),
+    "constraint.location.create_with_rule": _Cmd(
+        cmd=constraint.location.create_plain_with_rule,
+        required_permission=p.WRITE,
+    ),
     "constraint.order.create_with_set": _Cmd(
         cmd=constraint.order.create_with_set,
         required_permission=p.WRITE,
@@ -410,10 +418,6 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=stonith.create,
         required_permission=p.WRITE,
     ),
-    "stonith.create_in_group": _Cmd(
-        cmd=stonith.create_in_group,
-        required_permission=p.WRITE,
-    ),
     "tag.get_config_dto": _Cmd(
         cmd=tag.get_config_dto,
         required_permission=p.READ,
