@@ -1,4 +1,5 @@
 import logging
+import logging.handlers
 import multiprocessing as mp
 import os
 
@@ -6,7 +7,6 @@ WORKER_LOGGER = "pcs_worker"
 
 
 class Logger(logging.Logger):
-    # pylint: disable=too-many-arguments
     def makeRecord(  # type: ignore
         self,
         name,
@@ -20,6 +20,8 @@ class Logger(logging.Logger):
         extra=None,
         sinfo=None,
     ) -> logging.LogRecord:
+        # pylint: disable=too-many-arguments
+        # pylint: disable=too-many-positional-arguments
         pid = os.getpid()
         return super().makeRecord(
             name,
@@ -44,7 +46,7 @@ def setup_worker_logger(queue: mp.Queue) -> logging.Logger:
     logger = logging.getLogger(WORKER_LOGGER)
     logger.setLevel(logging.DEBUG)
 
-    queue_handler = logging.handlers.QueueHandler(queue)  # type: ignore
+    queue_handler = logging.handlers.QueueHandler(queue)
     logger.addHandler(queue_handler)
 
     return logger
