@@ -9,9 +9,14 @@ from pcs.common.validate import (
     is_port_number,
 )
 
+try:
+    from pcs.daemon.app import webui
+except ImportError:
+    webui = None
+
 # Relative location instead of system location is used for development purposes.
 LOCAL_PUBLIC_DIR = os.path.realpath(
-    os.path.dirname(os.path.abspath(__file__)) + "/../../pcsd/static"
+    os.path.dirname(os.path.abspath(__file__)) + "/../../pcsd/public"
 )
 LOCAL_WEBUI_DIR = os.path.join(LOCAL_PUBLIC_DIR, "ui")
 WEBUI_FALLBACK_FILE = "ui_instructions.html"
@@ -22,7 +27,6 @@ PCSD_SSL_OPTIONS = "PCSD_SSL_OPTIONS"
 PCSD_BIND_ADDR = "PCSD_BIND_ADDR"
 NOTIFY_SOCKET = "NOTIFY_SOCKET"
 PCSD_DEBUG = "PCSD_DEBUG"
-PCSD_DISABLE_GUI = "PCSD_DISABLE_GUI"
 PCSD_SESSION_LIFETIME = "PCSD_SESSION_LIFETIME"
 PCSD_DEV = "PCSD_DEV"
 WEBUI_DIR = "WEBUI_DIR"
@@ -45,7 +49,6 @@ Env = namedtuple(
         PCSD_BIND_ADDR,
         NOTIFY_SOCKET,
         PCSD_DEBUG,
-        PCSD_DISABLE_GUI,
         PCSD_SESSION_LIFETIME,
         WEBUI_DIR,
         WEBUI_FALLBACK,
@@ -73,7 +76,6 @@ def prepare_env(environ, logger=None):
         loader.bind_addresses(),
         loader.notify_socket(),
         loader.pcsd_debug(),
-        loader.pcsd_disable_gui(),
         loader.session_lifetime(),
         loader.webui_dir(),
         loader.webui_fallback(),
@@ -172,9 +174,6 @@ class EnvLoader:
     def notify_socket(self):
         return self.environ.get(NOTIFY_SOCKET, None)
 
-    def pcsd_disable_gui(self):
-        return self.__has_true_in_environ(PCSD_DISABLE_GUI)
-
     def session_lifetime(self):
         session_lifetime = self.environ.get(
             PCSD_SESSION_LIFETIME, settings.gui_session_lifetime_seconds
@@ -192,7 +191,7 @@ class EnvLoader:
         return self.__has_true_in_environ(PCSD_DEBUG)
 
     def check_webui(self):
-        if not self.pcsd_disable_gui() and not (
+        if webui and not (
             os.path.exists(self.webui_dir())
             or os.path.exists(self.webui_fallback())
         ):
