@@ -22,7 +22,6 @@ from pcs.common.types import StringCollection
 from pcs.daemon import (
     log,
     ruby_pcsd,
-    session,
     ssl,
     systemd,
 )
@@ -36,8 +35,13 @@ from pcs.daemon.app import capabilities as capabilities_app
 from pcs.daemon.app import (
     sinatra_remote,
     sinatra_ui,
-    ui,
 )
+
+try:
+    from pcs.daemon.app import webui
+except ImportError:
+    webui = None
+
 from pcs.daemon.app.common import (
     Http404Handler,
     RedirectHandler,
@@ -86,14 +90,13 @@ def config_sync(sync_config_lock: Lock, ruby_pcsd_wrapper: ruby_pcsd.Wrapper):
 def configure_app(
     async_scheduler: Scheduler,
     auth_provider: AuthProvider,
-    session_storage: session.Storage,
+    session_lifetime: int,
     ruby_pcsd_wrapper: ruby_pcsd.Wrapper,
     sync_config_lock: Lock,
     webui_dir: str,
     webui_fallback: str,
     pcsd_capabilities: Iterable[capabilities.Capability],
     *,
-    disable_gui: bool = False,
     debug: bool = False,
 ):
     # pylint: disable=too-many-arguments
@@ -120,20 +123,27 @@ def configure_app(
             )
         )
 
-        if not disable_gui:
+        if webui:
+            session_storage = webui.session.Storage(session_lifetime)
             routes.extend(
                 [(r"/(ui)?", RedirectHandler, dict(url="/ui/"))]
-                + ui.get_routes(
+                + webui.core.get_routes(
                     url_prefix="/ui/",
                     app_dir=webui_dir,
                     fallback_page_path=webui_fallback,
                     session_storage=session_storage,
                     auth_provider=auth_provider,
                 )
-                + sinatra_ui.get_routes(
+                + webui.sinatra_ui.get_routes(
                     session_storage, auth_provider, ruby_pcsd_wrapper
                 )
             )
+        else:
+            # Even with disabled (standalone) webui the following routes must be
+            # provided because they can be used via unix socket from cockpit.
+            routes.extend(
+                sinatra_ui.get_routes(auth_provider, ruby_pcsd_wrapper)
+            )
 
         return Application(
             routes, debug=debug, default_handler_class=Http404Handler
@@ -216,13 +226,12 @@ def main(argv=None) -> None:
     make_app = configure_app(
         async_scheduler,
         auth_provider,
-        session.Storage(env.PCSD_SESSION_LIFETIME),
+        env.PCSD_SESSION_LIFETIME,
         ruby_pcsd_wrapper,
         sync_config_lock,
         env.WEBUI_DIR,
         env.WEBUI_FALLBACK,
         pcsd_capabilities,
-        disable_gui=env.PCSD_DISABLE_GUI,
         debug=env.PCSD_DEV,
     )
     pcsd_ssl = ssl.PcsdSSL(
