@@ -42,19 +42,11 @@ from pcs.lib.cib.resource.common import (
     is_resource,
 )
 from pcs.lib.cib.resource.group import is_group
-from pcs.lib.cib.resource.guest_node import (
-    get_node_name_from_resource as get_node_name_from_guest,
-)
-from pcs.lib.cib.resource.guest_node import is_guest_node
-from pcs.lib.cib.resource.remote_node import (
-    get_node_name_from_resource as get_node_name_from_remote,
-)
 from pcs.lib.cib.tag import is_tag
 from pcs.lib.cib.tools import (
     ElementNotFound,
     IdProvider,
     find_elements_referencing_id,
-    find_location_constraints_referencing_node_name,
     get_element_by_id,
     get_elements_by_ids,
     get_fencing_topology,
@@ -259,17 +251,27 @@ def warn_resource_unmanaged(
         report_list.extend(parser.get_warnings())
 
         status = ResourcesStatusFacade.from_resources_status_dto(status_dto)
-        report_list.extend(
-            reports.ReportItem.warning(
-                reports.messages.ResourceIsUnmanaged(resource_id)
-            )
-            for resource_id in resource_ids
-            if status.is_state(
-                resource_id,
-                None,
-                ResourceState.UNMANAGED,
-            )
-        )
+        for r_id in resource_ids:
+            if not status.exists(r_id, None):
+                # Pacemaker does not put misconfigured resources into cluster
+                # status and we are unable to check state of such resources.
+                # This happens for e.g. undle with primitive resource inside and
+                # no IP address for the bundle specified. We expect the resource
+                # to be stopped since it is misconfigured. Stopping it again
+                # even when it is unmanaged should not break anything.
+                report_list.append(
+                    reports.ReportItem.debug(
+                        reports.messages.ConfiguredResourceMissingInStatus(
+                            r_id, ResourceState.UNMANAGED
+                        )
+                    )
+                )
+            elif status.is_state(r_id, None, ResourceState.UNMANAGED):
+                report_list.append(
+                    reports.ReportItem.warning(
+                        reports.messages.ResourceIsUnmanaged(r_id)
+                    )
+                )
     except NotImplementedError:
         # TODO remove when issue with bundles in status is fixed
         report_list.extend(
@@ -318,20 +320,31 @@ def ensure_resources_stopped(
         report_list.extend(parser.get_warnings())
 
         status = ResourcesStatusFacade.from_resources_status_dto(status_dto)
-        not_stopped_ids = [
-            resource_id
-            for resource_id in resource_ids
-            if not status.is_state(
-                resource_id,
+        for r_id in resource_ids:
+            if not status.exists(r_id, None):
+                # Pacemaker does not put misconfigured resources into cluster
+                # status and we are unable to check state of such resources.
+                # This happens for e.g. undle with primitive resource inside and
+                # no IP address for the bundle specified. We expect the resource
+                # to be stopped since it is misconfigured.
+                report_list.append(
+                    reports.ReportItem.debug(
+                        reports.messages.ConfiguredResourceMissingInStatus(
+                            r_id, ResourceState.STOPPED
+                        )
+                    )
+                )
+            elif not status.is_state(
+                r_id,
                 None,
                 ResourceState.STOPPED,
                 instances_quantifier=(
                     MoreChildrenQuantifierType.ALL
-                    if status.can_have_multiple_instances(resource_id)
+                    if status.can_have_multiple_instances(r_id)
                     else None
                 ),
-            )
-        ]
+            ):
+                not_stopped_ids.append(r_id)
     except NotImplementedError:
         # TODO remove when issue with bundles in status is fixed
         not_stopped_ids = [
@@ -471,9 +484,6 @@ def _get_dependencies_to_remove(
             element_ids_to_remove.add(element_id)
             elements_to_process.extend(_get_element_references(el))
             elements_to_process.extend(_get_inner_references(el))
-            elements_to_process.extend(
-                _get_remote_node_name_constraint_references(el)
-            )
 
             for level_el in find_levels_with_device(
                 get_fencing_topology(get_root(el)), element_id
@@ -565,26 +575,3 @@ def _is_empty_after_inner_el_removal(parent_el: _Element) -> bool:
     if is_location_constraint(parent_el):
         return _is_last_element(parent_el, const.TAG_RULE)
     return False
-
-
-def _get_remote_node_name_constraint_references(
-    element: _Element,
-) -> Iterable[_Element]:
-    """
-    Return all location constraints referencing remote or guest node name.
-    """
-    if not is_resource(element):
-        return []
-
-    if is_guest_node(element):
-        return find_location_constraints_referencing_node_name(
-            element, get_node_name_from_guest(element)
-        )
-
-    remote_node_name = get_node_name_from_remote(element)
-    if remote_node_name is not None:
-        return find_location_constraints_referencing_node_name(
-            element, remote_node_name
-        )
-
-    return []
