@@ -32,12 +32,11 @@ from pcs.lib.xml_tools import (
     update_attributes_remove_empty,
 )
 
-GENERIC_CONTAINER_TYPES = {"docker", "podman", "rkt"}
+GENERIC_CONTAINER_TYPES = {"docker", "podman"}
 
 GENERIC_CONTAINER_OPTIONS = frozenset(
     (
         "image",
-        "masters",
         "network",
         "options",
         "promoted-max",
@@ -187,6 +186,23 @@ def _bundle_network_element_to_dto(
     )
 
 
+def verify(resources_el: _Element) -> reports.ReportItemList:
+    """
+    Check if there are configuration errors in existing bundles
+
+    resource_el -- element with bundles
+    """
+    report_list = []
+    for bundle_el in resources_el.iterfind(TAG):
+        if not _is_supported_container(_get_container_element(bundle_el)):
+            report_list.append(
+                _get_report_unsupported_container(
+                    bundle_el, updating_options=False
+                )
+            )
+    return report_list
+
+
 def validate_new(
     id_provider,
     bundle_id,
@@ -331,11 +347,20 @@ def reset_to_minimal(bundle_element):
             reset_element(child, keep_attrs=["image"])
 
 
-def _get_report_unsupported_container(bundle_el):
+def _get_report_unsupported_container(
+    bundle_el: _Element, updating_options: bool = True
+) -> reports.ReportItem:
+    """
+    Create an error report for unsupported bundle container type
+
+    bundle_el -- bundle with an unsupported container
+    updating_options -- True if this was detected when changing the bundle
+    """
     return reports.ReportItem.error(
         reports.messages.ResourceBundleUnsupportedContainerType(
-            bundle_el.get("id"),
+            bundle_el.get("id", ""),
             sorted(GENERIC_CONTAINER_TYPES),
+            updating_options=updating_options,
         )
     )
 
@@ -527,22 +552,7 @@ def _validate_container(container_type, container_options, force_options=False):
                 )
             )
         ]
-    report_list = []
-    if container_type == "rkt":
-        # TODO deprecated in pacemaker 2, to be removed in pacemaker 3
-        # added to pcs after 0.11.7
-        report_list.append(
-            reports.ReportItem.deprecation(
-                reports.messages.DeprecatedOptionValue(
-                    "container type", container_type
-                )
-            )
-        )
-
-    report_list += _validate_generic_container_options(
-        container_options, force_options
-    )
-    return report_list
+    return _validate_generic_container_options(container_options, force_options)
 
 
 def _validate_generic_container_options(container_options, force_options=False):
@@ -556,32 +566,11 @@ def _validate_generic_container_options(container_options, force_options=False):
         ),
         validate.IsRequiredAll(["image"], option_type="container"),
         validate.ValueNotEmpty("image", "image name"),
-        validate.ValueNonnegativeInteger("masters"),
         validate.ValueNonnegativeInteger("promoted-max"),
-        validate.MutuallyExclusive(
-            ["masters", "promoted-max"],
-            option_type="container",
-        ),
         validate.ValuePositiveInteger("replicas"),
         validate.ValuePositiveInteger("replicas-per-host"),
     ]
-
-    deprecation_reports = []
-    if "masters" in container_options:
-        deprecation_reports.append(
-            reports.ReportItem.deprecation(
-                reports.messages.DeprecatedOption(
-                    "masters",
-                    ["promoted-max"],
-                    "container",
-                )
-            )
-        )
-
-    return (
-        validate.ValidatorAll(validators).validate(container_options)
-        + deprecation_reports
-    )
+    return validate.ValidatorAll(validators).validate(container_options)
 
 
 def _validate_container_reset(bundle_el, container_options, force_options):
@@ -612,7 +601,6 @@ def _validate_generic_container_options_update(
     container_el, options, force_options
 ):
     validators_optional_options = [
-        validate.ValueNonnegativeInteger("masters"),
         validate.ValueNonnegativeInteger("promoted-max"),
         validate.ValuePositiveInteger("replicas"),
         validate.ValuePositiveInteger("replicas-per-host"),
@@ -632,49 +620,9 @@ def _validate_generic_container_options_update(
         validate.ValueNotEmpty("image", "image name"),
     ] + validators_optional_options
 
-    # CIB does not allow both to be set. Deleting both is not a problem,
-    # though. Deleting one while setting another also works and is further
-    # checked bellow.
-    if not (
-        options.get("masters", "") == ""
-        or options.get("promoted-max", "") == ""
-    ):
-        validators.append(
-            validate.MutuallyExclusive(
-                ["masters", "promoted-max"],
-                option_type="container",
-            )
-        )
-
     deprecation_reports = []
-    if options.get("masters"):
-        # If the user wants to delete the masters option, do not report it is
-        # deprecated. They may be removing it because they just found out it is
-        # deprecated.
-        deprecation_reports.append(
-            reports.ReportItem.deprecation(
-                reports.messages.DeprecatedOption(
-                    "masters",
-                    ["promoted-max"],
-                    "container",
-                )
-            )
-        )
-    # Do not allow to set masters if promoted-max is set unless promoted-max is
-    # going to be removed now. Do the same check also the other way around. CIB
-    # only allows one of them to be set.
-    if (
-        options.get("masters")
-        and container_el.get("promoted-max")
-        and options.get("promoted-max") != ""
-    ):
-        deprecation_reports.append(
-            reports.ReportItem.error(
-                reports.messages.PrerequisiteOptionMustNotBeSet(
-                    "masters", "promoted-max", "container", "container"
-                )
-            )
-        )
+    # Do not allow to set promoted-max if masters is set unless masters is
+    # going to be removed now. CIB only allows one of them to be set.
     if (
         options.get("promoted-max")
         and container_el.get("masters")
