@@ -39,6 +39,9 @@ from pcs.lib.booth import (
     resource,
     status,
 )
+from pcs.lib.booth.cib import (
+    get_booth_ticket_names as get_cib_booth_ticket_names,
+)
 from pcs.lib.booth.cib import get_ticket_names as get_cib_ticket_names
 from pcs.lib.booth.env import BoothEnv
 from pcs.lib.cib.remove_elements import (
@@ -724,41 +727,76 @@ def ticket_cleanup(env: LibraryEnvironment, ticket_name: str) -> None:
     """
     _ensure_live_cib(env)
 
-    report_processor = env.report_processor
-
-    if report_processor.report_list(
+    if env.report_processor.report_list(
         _validate_ticket_in_cib(env.get_cib(), ticket_name)
     ).has_errors:
         raise LibraryError()
 
-    cmd_runner = env.cmd_runner()
+    _cleanup_tickets(env.cmd_runner(), env.report_processor, [ticket_name])
 
-    # standby the ticket first, so the node is not fenced if ticket-loss
-    # policy is set to 'fence' in the ticket constraint
-    report_processor.report_list(_ticket_standby(cmd_runner, ticket_name))
+
+def ticket_cleanup_auto(
+    env: LibraryEnvironment, instance_name: Optional[str] = None
+) -> None:
+    """
+    Cleanup (remove from CIB on local site) all booth tickets that are in CIB
+    but not in booth configuration
+
+    instance_name -- booth instance name
+    """
+    booth_env = env.get_booth_env(instance_name)
+    report_processor = env.report_processor
+    _ensure_live_env(env, booth_env)
+
+    try:
+        booth_conf = booth_env.config.read_to_facade()
+    except RawFileError as e:
+        report_processor.report(raw_file_error_report(e))
+    except ParserErrorException as e:
+        report_processor.report_list(
+            booth_env.config.parser_exception_to_report_list(e)
+        )
     if report_processor.has_errors:
         raise LibraryError()
 
-    report_processor.report(
-        reports.ReportItem.info(
-            reports.messages.BoothTicketCleanup(ticket_name)
-        )
+    conf_tickets = set(booth_conf.get_ticket_names())
+    cib_tickets = set(get_cib_booth_ticket_names(env.get_cib(), instance_name))
+
+    _cleanup_tickets(
+        env.cmd_runner(), report_processor, sorted(cib_tickets - conf_tickets)
     )
-    stdout, stderr, retval = live_ticket_cleanup(cmd_runner, ticket_name)
-    if retval != 0:
+
+
+def _cleanup_tickets(
+    cmd_runner: CommandRunner,
+    report_processor: ReportProcessor,
+    ticket_names: StringSequence,
+) -> None:
+    for ticket in ticket_names:
+        # standby the ticket first, so the node is not fenced if ticket-loss
+        # policy is set to 'fence' in the ticket constraint
+        report_processor.report_list(_ticket_standby(cmd_runner, ticket))
+        if report_processor.has_errors:
+            raise LibraryError()
+
         report_processor.report(
-            reports.ReportItem.error(
-                reports.messages.BoothTicketOperationFailed(
-                    "cleanup",
-                    join_multilines([stderr, stdout]),
-                    None,
-                    ticket_name,
+            reports.ReportItem.info(reports.messages.BoothTicketCleanup(ticket))
+        )
+        stdout, stderr, retval = live_ticket_cleanup(cmd_runner, ticket)
+        if retval != 0:
+            report_processor.report(
+                reports.ReportItem.error(
+                    reports.messages.BoothTicketOperationFailed(
+                        "cleanup",
+                        join_multilines([stderr, stdout]),
+                        None,
+                        ticket,
+                    )
                 )
             )
-        )
 
-    if report_processor.has_errors:
-        raise LibraryError()
+        if report_processor.has_errors:
+            raise LibraryError()
 
 
 def ticket_standby(env: LibraryEnvironment, ticket_name: str) -> None:
