@@ -172,22 +172,14 @@ def _get_agent_facade(
         )
         if split_name.is_stonith:
             report_processor.report(
-                reports.ReportItem.deprecation(
-                    reports.messages.ResourceStonithCommandsMismatch(
-                        "fence agent", reports.const.PCS_COMMAND_STONITH_CREATE
-                    )
-                )
-            )
-        if split_name.standard in ("nagios", "upstart"):
-            # TODO deprecated in pacemaker 2, to be removed in pacemaker 3
-            # added to pcs after 0.11.7
-            report_processor.report(
-                reports.ReportItem.deprecation(
-                    reports.messages.DeprecatedOptionValue(
-                        "standard", split_name.standard
+                reports.ReportItem.error(
+                    reports.messages.CommandArgumentTypeMismatch(
+                        "stonith resource",
+                        reports.const.PCS_COMMAND_STONITH_CREATE,
                     )
                 )
             )
+            raise LibraryError()
 
         return factory.facade_from_parsed_name(split_name)
     except (UnableToGetAgentMetadata, UnsupportedOcfVersion) as e:
@@ -413,6 +405,14 @@ def create(
     enable_agent_self_validation -- if True, use agent self-validation feature
         to validate instance attributes
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     runner = env.cmd_runner()
     agent_factory = ResourceAgentFacadeFactory(runner, env.report_processor)
     resource_agent = _get_agent_facade(
@@ -520,6 +520,14 @@ def create_as_clone(
     enable_agent_self_validation -- if True, use agent self-validation feature
         to validate instance attributes
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     runner = env.cmd_runner()
     agent_factory = ResourceAgentFacadeFactory(runner, env.report_processor)
     resource_agent = _get_agent_facade(
@@ -668,6 +676,14 @@ def create_in_group(
     enable_agent_self_validation -- if True, use agent self-validation feature
         to validate instance attributes
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     runner = env.cmd_runner()
     agent_factory = ResourceAgentFacadeFactory(runner, env.report_processor)
     resource_agent = _get_agent_facade(
@@ -813,6 +829,14 @@ def create_into_bundle(
     enable_agent_self_validation -- if True, use agent self-validation feature
         to validate instance attributes
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     runner = env.cmd_runner()
     agent_factory = ResourceAgentFacadeFactory(runner, env.report_processor)
     resource_agent = _get_agent_facade(
@@ -913,6 +937,14 @@ def bundle_create(
     bool ensure_disabled -- set the bundle's target-role to "Stopped"
     mixed wait -- False: no wait, None: wait default timeout, int: wait timeout
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     container_options = container_options or {}
     network_options = network_options or {}
     port_map = port_map or []
@@ -991,6 +1023,14 @@ def bundle_reset(
     bool ensure_disabled -- set the bundle's target-role to "Stopped"
     mixed wait -- False: no wait, None: wait default timeout, int: wait timeout
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     container_options = container_options or {}
     network_options = network_options or {}
     port_map = port_map or []
@@ -1078,6 +1118,14 @@ def bundle_update(
     bool force_options -- return warnings instead of forceable errors
     mixed wait -- False: no wait, None: wait default timeout, int: wait timeout
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     container_options = container_options or {}
     network_options = network_options or {}
     port_map_add = port_map_add or []
@@ -1221,6 +1269,14 @@ def disable(
         of tag ids, all resources in tags are to be disabled
     wait -- False: no wait, None: wait default timeout, int: wait timeout
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     wait_timeout = env.ensure_wait_satisfiable(wait)
     _disable_validate_and_edit_cib(env, env.get_cib(), resource_or_tag_ids)
     _push_cib_wait(
@@ -1247,6 +1303,14 @@ def disable_safe(
     strict -- if False, allow resources to be migrated
     wait -- False: no wait, None: wait default timeout, int: wait timeout
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     if not env.is_cib_live:
         raise LibraryError(
             ReportItem.error(
@@ -1264,9 +1328,9 @@ def disable_safe(
         for resource_el in resource_el_list
     ):
         env.report_processor.report(
-            reports.ReportItem.deprecation(
-                reports.messages.ResourceStonithCommandsMismatch(
-                    "stonith device"
+            reports.ReportItem.error(
+                reports.messages.CommandArgumentTypeMismatch(
+                    "stonith resources"
                 )
             )
         )
@@ -1359,6 +1423,14 @@ def enable(
         of tag ids, all resources in tags are to be enabled
     wait -- False: no wait, None: wait default timeout, int: wait timeout
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     wait_timeout = env.ensure_wait_satisfiable(wait)
     cib = env.get_cib()
     resource_el_list, report_list = _find_resources_expand_tags(
@@ -1530,6 +1602,15 @@ def group_add(
     """
     # pylint: disable = too-many-locals
     # pylint: disable = too-many-branches
+
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     wait_timeout = env.ensure_wait_satisfiable(wait)
     resources_section = get_resources(env.get_cib(None))
 
@@ -1568,18 +1649,6 @@ def group_add(
             ReportItem.error(reports.messages.IdNotFound(resource_id, []))
         )
 
-    if any(
-        resource.stonith.is_stonith(resource_el)
-        for resource_el in resource_element_list
-    ):
-        env.report_processor.report(
-            reports.ReportItem.deprecation(
-                reports.messages.ResourceStonithCommandsMismatch(
-                    "stonith resource"
-                )
-            )
-        )
-
     if env.report_processor.report_list(
         resource.validations.validate_move_resources_to_group(
             group_element,
@@ -1711,12 +1780,17 @@ def move(
     LibraryEnvironment env
     resource_id -- id of a resource to be moved
     node -- node to move the resource to, ban on the current node if None
-    master -- limit the constraint to the Master role
+    master -- limit the constraint to the Promoted role
     lifetime -- lifespan of the constraint, forever if None
     wait -- flag for controlling waiting for pacemaker idle mechanism
     """
     return _Move().run(
-        env, resource_id, node=node, master=master, lifetime=lifetime, wait=wait
+        env,
+        resource_id,
+        node=node,
+        promoted=master,
+        lifetime=lifetime,
+        wait=wait,
     )
 
 
@@ -1755,7 +1829,7 @@ def move_autoclean(
 
     resource_id -- id of a resource to be moved
     node -- node to move the resource to, ban on the current node if None
-    master -- limit the constraint to the Master role
+    master -- limit the constraint to the Promoted role
     wait_timeout -- timeout when waiting for the cluster to apply new
         configuration, if <= 0 wait indefinitely
     strict -- if True affecting other resources than the specified resource
@@ -1807,7 +1881,7 @@ def move_autoclean(
             env.cmd_runner(dict(CIB_file=rsc_moved_cib_file.name)),
             resource_id,
             node=node,
-            master=master,
+            promoted=master,
         )
         rsc_moved_cib_file.seek(0)
         rsc_moved_cib_xml = rsc_moved_cib_file.read()
@@ -2031,12 +2105,17 @@ def ban(env, resource_id, node=None, master=False, lifetime=None, wait=False):
     LibraryEnvironment env
     string resource_id -- id of a resource to be banned
     string node -- node to ban the resource on, ban on the current node if None
-    bool master -- limit the constraint to the Master role
+    bool master -- limit the constraint to the Promoted role
     string lifetime -- lifespan of the constraint, forever if None
     mixed wait -- flag for controlling waiting for pacemaker idle mechanism
     """
     return _Ban().run(
-        env, resource_id, node=node, master=master, lifetime=lifetime, wait=wait
+        env,
+        resource_id,
+        node=node,
+        promoted=master,
+        lifetime=lifetime,
+        wait=wait,
     )
 
 
@@ -2133,10 +2212,10 @@ def _move_ban_pcmk_error_report(
 class _MoveBanTemplate:
     _is_ban = False
 
-    def _validate(self, resource_el, master):
+    def _validate(self, resource_el, promoted):
         raise NotImplementedError()
 
-    def _run_action(self, runner, resource_id, node, master, lifetime):
+    def _run_action(self, runner, resource_id, node, promoted, lifetime):
         raise NotImplementedError()
 
     def _report_action_pcmk_success(self, resource_id, stdout, stderr):
@@ -2163,12 +2242,21 @@ class _MoveBanTemplate:
         env: LibraryEnvironment,
         resource_id,
         node=None,
-        master=False,
+        promoted=False,
         lifetime=None,
         wait: WaitType = False,
     ):
         # pylint: disable=too-many-locals
         # validate
+
+        if wait is not False:
+            # deprecated in the first version of 0.12
+            env.report_processor.report(
+                reports.ReportItem.deprecation(
+                    reports.messages.ResourceWaitDeprecated()
+                )
+            )
+
         wait_timeout = env.ensure_wait_satisfiable(wait)  # raises on error
 
         cib = env.get_cib()
@@ -2176,7 +2264,7 @@ class _MoveBanTemplate:
             get_resources(cib), resource_id
         )
         if resource_el is not None:
-            report_list.extend(self._validate(resource_el, master))
+            report_list.extend(self._validate(resource_el, promoted))
         if node:
             report_list.extend(_nodes_exist_reports(cib, [node]))
         if env.report_processor.report_list(report_list).has_errors:
@@ -2193,7 +2281,7 @@ class _MoveBanTemplate:
             env.cmd_runner(),
             resource_id,
             node=node,
-            master=master,
+            promoted=promoted,
             lifetime=lifetime,
         )
         if retval != 0:
@@ -2229,12 +2317,12 @@ class _MoveBanTemplate:
 
 
 class _Move(_MoveBanTemplate):
-    def _validate(self, resource_el, master):
-        return resource.validations.validate_move(resource_el, master)
+    def _validate(self, resource_el, promoted):
+        return resource.validations.validate_move(resource_el, promoted)
 
-    def _run_action(self, runner, resource_id, node, master, lifetime):
+    def _run_action(self, runner, resource_id, node, promoted, lifetime):
         return resource_move(
-            runner, resource_id, node=node, master=master, lifetime=lifetime
+            runner, resource_id, node=node, promoted=promoted, lifetime=lifetime
         )
 
     def _report_action_pcmk_success(self, resource_id, stdout, stderr):
@@ -2274,12 +2362,12 @@ class _Move(_MoveBanTemplate):
 class _Ban(_MoveBanTemplate):
     _is_ban = True
 
-    def _validate(self, resource_el, master):
-        return resource.validations.validate_ban(resource_el, master)
+    def _validate(self, resource_el, promoted):
+        return resource.validations.validate_ban(resource_el, promoted)
 
-    def _run_action(self, runner, resource_id, node, master, lifetime):
+    def _run_action(self, runner, resource_id, node, promoted, lifetime):
         return resource_ban(
-            runner, resource_id, node=node, master=master, lifetime=lifetime
+            runner, resource_id, node=node, promoted=promoted, lifetime=lifetime
         )
 
     def _report_action_pcmk_success(
@@ -2335,10 +2423,18 @@ def unmove_unban(
     LibraryEnvironment env
     string resource_id -- id of a resource to be unmoved/unbanned
     string node -- node to limit unmoving/unbanning to, all nodes if None
-    bool master -- only remove constraints for Master role
+    bool master -- only remove constraints for Promoted role
     bool expired -- only remove constrains which have already expired
     mixed wait -- flag for controlling waiting for pacemaker idle mechanism
     """
+    if wait is not False:
+        # deprecated in the first version of 0.12
+        env.report_processor.report(
+            reports.ReportItem.deprecation(
+                reports.messages.ResourceWaitDeprecated()
+            )
+        )
+
     # validate
     wait_timeout = env.ensure_wait_satisfiable(wait)  # raises on error
 
@@ -2362,7 +2458,11 @@ def unmove_unban(
 
     # run the action
     stdout, stderr, retval = resource_unmove_unban(
-        env.cmd_runner(), resource_id, node=node, master=master, expired=expired
+        env.cmd_runner(),
+        resource_id,
+        node=node,
+        promoted=master,
+        expired=expired,
     )
     if retval != 0:
         raise LibraryError(
@@ -2425,12 +2525,11 @@ def get_resource_relations_tree(
         )
     if resource.stonith.is_stonith(resource_el):
         env.report_processor.report(
-            reports.ReportItem.deprecation(
-                reports.messages.ResourceStonithCommandsMismatch(
-                    "stonith resource"
-                )
+            reports.ReportItem.error(
+                reports.messages.CommandArgumentTypeMismatch("stonith resource")
             )
         )
+        raise LibraryError()
 
     (
         resources_dict,
@@ -2566,56 +2665,69 @@ def restart(
     timeout -- abort if the command doesn't finish in this time (integer + unit)
     """
     cib = env.get_cib()
+
+    # To be able to restart bundle instances, which are not to be found in CIB,
+    # do not fail if specified ID is not found in CIB. Pacemaker provides
+    # reasonable messages when the ID to be restarted is not a resource or
+    # doesn't exist. We only search for the resource in order to provide hints
+    # when the user attempts to restart bundle's or clone's inner resources.
+    resource_found = False
     try:
         resource_el = get_element_by_id(cib, resource_id)
-    except ElementNotFound as e:
-        env.report_processor.report(
-            ReportItem.error(
-                reports.messages.IdNotFound(
-                    resource_id, expected_types=["resource"]
-                )
-            )
-        )
-        raise LibraryError() from e
-    if not resource.common.is_resource(resource_el):
-        env.report_processor.report(
-            ReportItem.error(
-                reports.messages.IdBelongsToUnexpectedType(
-                    resource_id,
-                    expected_types=["resource"],
-                    current_type=resource_el.tag,
-                )
-            )
-        )
-        raise LibraryError()
+        resource_found = True
+    except ElementNotFound:
+        pass
 
-    parent_resource_el = resource.clone.get_parent_any_clone(resource_el)
-    if parent_resource_el is None:
-        parent_resource_el = resource.bundle.get_parent_bundle(resource_el)
-    if parent_resource_el is not None:
-        env.report_processor.report(
-            reports.ReportItem.warning(
-                reports.messages.ResourceRestartUsingParentRersource(
-                    str(resource_el.attrib["id"]),
-                    str(parent_resource_el.attrib["id"]),
+    if resource_found:
+        if not resource.common.is_resource(resource_el):
+            env.report_processor.report(
+                ReportItem.error(
+                    reports.messages.IdBelongsToUnexpectedType(
+                        resource_id,
+                        expected_types=["resource"],
+                        current_type=resource_el.tag,
+                    )
                 )
             )
-        )
-        resource_el = parent_resource_el
+            raise LibraryError()
 
-    if node and not (
-        resource.clone.is_any_clone(resource_el)
-        or resource.bundle.is_bundle(resource_el)
-    ):
-        env.report_processor.report(
-            reports.ReportItem.error(
-                reports.messages.ResourceRestartNodeIsForMultiinstanceOnly(
-                    str(resource_el.attrib["id"]),
-                    resource_el.tag,
-                    node,
+        if resource.stonith.is_stonith(resource_el):
+            env.report_processor.report(
+                reports.ReportItem.error(
+                    reports.messages.CommandArgumentTypeMismatch(
+                        "stonith resource"
+                    )
+                )
+            )
+            raise LibraryError()
+
+        parent_resource_el = resource.clone.get_parent_any_clone(resource_el)
+        if parent_resource_el is None:
+            parent_resource_el = resource.bundle.get_parent_bundle(resource_el)
+        if parent_resource_el is not None:
+            env.report_processor.report(
+                reports.ReportItem.warning(
+                    reports.messages.ResourceRestartUsingParentRersource(
+                        str(resource_el.attrib["id"]),
+                        str(parent_resource_el.attrib["id"]),
+                    )
+                )
+            )
+            resource_el = parent_resource_el
+
+        if node and not (
+            resource.clone.is_any_clone(resource_el)
+            or resource.bundle.is_bundle(resource_el)
+        ):
+            env.report_processor.report(
+                reports.ReportItem.error(
+                    reports.messages.ResourceRestartNodeIsForMultiinstanceOnly(
+                        str(resource_el.attrib["id"]),
+                        resource_el.tag,
+                        node,
+                    )
                 )
             )
-        )
 
     if timeout is not None:
         env.report_processor.report_list(
@@ -2627,7 +2739,7 @@ def restart(
 
     resource_restart(
         env.cmd_runner(),
-        str(resource_el.attrib["id"]),
+        str(resource_el.attrib["id"]) if resource_found else resource_id,
         node=node,
         timeout=timeout,
     )
