@@ -102,10 +102,10 @@ class LibraryEnvironment:
         known_hosts_getter: Optional[
             Callable[[], Mapping[str, PcsKnownHost]]
         ] = None,
-        # TODO there is no validation and transformation from str to int
-        request_timeout: Optional[Union[int, str]] = None,
+        request_timeout: Optional[int] = None,
     ):
         # pylint: disable=too-many-arguments
+        # pylint: disable=too-many-positional-arguments
         self._logger = logger
         self._report_processor = report_processor
         self._user_login = user_login
