@@ -1,8 +1,10 @@
 from typing import Optional
 
+from pcs.common.reports import ReportItem
+
 
 class LibraryError(Exception):
-    def __init__(self, *args, output: Optional[str] = None):
+    def __init__(self, *args: ReportItem, output: Optional[str] = None):
         super().__init__(*args)
         self._output = output
 
