@@ -2,17 +2,26 @@ from typing import (
     Iterable,
     List,
     Optional,
+    Set,
     Tuple,
 )
 
 from lxml.etree import _Element
 
 from pcs.common import reports
-from pcs.common.reports import ReportItemList
-from pcs.common.reports import ReportItemSeverity
+from pcs.common.reports import (
+    ReportItemList,
+    ReportItemSeverity,
+)
 from pcs.common.reports.item import ReportItem
-from pcs.lib.cib.node import PacemakerNode
-from pcs.lib.cib.resource import remote_node, guest_node
+from pcs.lib.cib.node import (
+    PacemakerNode,
+    get_node_names,
+)
+from pcs.lib.cib.resource import (
+    guest_node,
+    remote_node,
+)
 from pcs.lib.corosync.config_facade import ConfigFacade as CorosyncConfigFacade
 from pcs.lib.corosync.node import CorosyncNode
 from pcs.lib.xml_tools import get_root
@@ -28,6 +37,10 @@ def get_existing_nodes_names(
     )
 
 
+def get_pacemaker_node_names(cib: _Element) -> Set[str]:
+    return get_node_names(cib) | set(get_existing_nodes_names(None, cib)[0])
+
+
 def get_existing_nodes_names_addrs(
     corosync_conf=None, cib=None, error_on_missing_name=False
 ):
