@@ -15,6 +15,9 @@ from pcs.common import (
     const,
     reports,
 )
+from pcs.common.pacemaker.role import (
+    get_value_primary as get_primary_role_value,
+)
 from pcs.common.reports.item import ReportItem
 from pcs.lib.pacemaker.values import (
     is_false,
@@ -194,8 +197,13 @@ def _get_primitive_roles_with_nodes(primitive_el_list):
     # Clone resources are represented by multiple primitive elements.
     roles_with_nodes = defaultdict(set)
     for resource_element in primitive_el_list:
-        if resource_element.attrib["role"] in const.PCMK_ROLES_RUNNING:
-            roles_with_nodes[resource_element.attrib["role"]].update(
+        if (
+            resource_element.attrib["role"]
+            in const.PCMK_ROLES_RUNNING_WITH_LEGACY
+        ):
+            roles_with_nodes[
+                get_primary_role_value(resource_element.attrib["role"])
+            ].update(
                 [
                     node.attrib["name"]
                     for node in resource_element.findall(".//node")
