@@ -1,7 +1,7 @@
-import os
-import sys
 import logging
 import logging.handlers
+import os
+import sys
 
 # pylint: disable=import-error
 import pyagentx
@@ -10,7 +10,6 @@ import pcs.utils
 from pcs.snmp import settings
 from pcs.snmp.updaters.v1 import ClusterPcsV1Updater
 
-
 logger = logging.getLogger("pcs.snmp")
 logger.addHandler(logging.NullHandler())
 
@@ -71,7 +70,9 @@ class PcsAgent(pyagentx.Agent):
         update_interval = get_update_interval()
         logger.info("Update interval set to: %s", str(update_interval))
         self.register(
-            settings.PCS_OID + ".1", ClusterPcsV1Updater, freq=update_interval,
+            settings.PCS_OID + ".1",
+            ClusterPcsV1Updater,
+            freq=update_interval,
         )
 
 
