@@ -19,7 +19,6 @@ from pcs.cli.common.parse_args import (
 )
 from pcs.cli.fencing_topology import target_type_map_cli_to_lib
 from pcs.cli.reports.output import (
-    deprecation_warning,
     error,
     print_to_stderr,
 )
@@ -29,10 +28,7 @@ from pcs.cli.resource.parse_args import (
 )
 from pcs.cli.stonith.levels.output import stonith_level_config_to_text
 from pcs.common import reports
-from pcs.common.fencing_topology import (
-    TARGET_TYPE_ATTRIBUTE,
-    TARGET_TYPE_NODE,
-)
+from pcs.common.fencing_topology import TARGET_TYPE_ATTRIBUTE
 from pcs.common.pacemaker.resource.list import (
     get_all_resources_ids,
     get_stonith_resources_ids,
@@ -44,13 +40,6 @@ from pcs.common.str_tools import (
     format_plural,
     indent,
 )
-from pcs.lib.errors import LibraryError
-
-
-def stonith_show_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
-    # TODO remove, deprecated command
-    # replaced with 'stonith status' and 'stonith config'
-    resource.resource_show(lib, argv, modifiers, stonith=True)
 
 
 def stonith_status_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
@@ -140,10 +129,8 @@ def _check_is_stonith(
     cmd_to_use: Optional[str] = None,
 ) -> None:
     if lib.resource.is_any_resource_except_stonith(resource_id_list):
-        deprecation_warning(
-            reports.messages.ResourceStonithCommandsMismatch(
-                "resources"
-            ).message
+        raise error(
+            reports.messages.CommandArgumentTypeMismatch("resources").message
             + format_optional(cmd_to_use, " Please use '{}' instead.")
         )
 
@@ -151,11 +138,6 @@ def _check_is_stonith(
 def stonith_create(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
-      * --before - specified resource inside a group before which new resource
-        will be placed inside the group
-      * --after - specified resource inside a group after which new resource
-        will be placed inside the group
-      * --group - specifies group in which resource will be created
       * --force - allow not existing agent, invalid operations or invalid
         instance attributes
       * --disabled - created resource will be disabled
@@ -165,30 +147,14 @@ def stonith_create(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
       * -f - CIB file
     """
     modifiers.ensure_only_supported(
-        "--before",
-        "--after",
-        "--group",
         "--force",
         "--disabled",
         "--no-default-ops",
         "--agent-validation",
         "--wait",
         "-f",
+        hint_syntax_changed="0.12",
     )
-    if modifiers.is_specified("--before") and modifiers.is_specified("--after"):
-        raise error(
-            "you cannot specify both --before and --after{0}".format(
-                ""
-                if modifiers.is_specified("--group")
-                else " and you have to specify --group"
-            )
-        )
-
-    if not modifiers.is_specified("--group"):
-        if modifiers.is_specified("--before"):
-            raise error("you cannot use --before without --group")
-        if modifiers.is_specified("--after"):
-            raise error("you cannot use --after without --group")
 
     if len(argv) < 2:
         raise CmdLineInputError()
@@ -208,41 +174,14 @@ def stonith_create(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
         enable_agent_self_validation=modifiers.get("--agent-validation"),
     )
 
-    if not modifiers.get("--group"):
-        lib.stonith.create(
-            stonith_id,
-            stonith_type,
-            parts.operations,
-            parts.meta_attrs,
-            parts.instance_attrs,
-            **settings,
-        )
-    else:
-        # deprecated since 0.11.3
-        deprecation_warning(
-            "Option to group stonith resource is deprecated and will be "
-            "removed in a future release."
-        )
-        adjacent_resource_id = None
-        put_after_adjacent = False
-        if modifiers.get("--after"):
-            adjacent_resource_id = modifiers.get("--after")
-            put_after_adjacent = True
-        if modifiers.get("--before"):
-            adjacent_resource_id = modifiers.get("--before")
-            put_after_adjacent = False
-
-        lib.stonith.create_in_group(
-            stonith_id,
-            stonith_type,
-            modifiers.get("--group"),
-            parts.operations,
-            parts.meta_attrs,
-            parts.instance_attrs,
-            adjacent_resource_id=adjacent_resource_id,
-            put_after_adjacent=put_after_adjacent,
-            **settings,
-        )
+    lib.stonith.create(
+        stonith_id,
+        stonith_type,
+        parts.operations,
+        parts.meta_attrs,
+        parts.instance_attrs,
+        **settings,
+    )
 
 
 def _stonith_level_parse_node(arg):
@@ -290,20 +229,6 @@ def _stonith_level_parse_target_and_stonith(argv: Argv):
     return target_type, target_value, devices
 
 
-def _stonith_level_normalize_devices(argv: Argv) -> Argv:
-    """
-    Commandline options: no options
-    """
-    # normalize devices - previously it was possible to delimit devices by both
-    # a comma and a space
-    if any("," in arg for arg in argv):
-        deprecation_warning(
-            "Delimiting stonith devices with ',' is deprecated and will be "
-            "removed. Please use a space to delimit stonith devices."
-        )
-    return ",".join(argv).split(",")
-
-
 def stonith_level_add_cmd(
     lib: Any, argv: Argv, modifiers: InputModifiers
 ) -> None:
@@ -316,6 +241,9 @@ def stonith_level_add_cmd(
     modifiers.ensure_only_supported("-f", "--force")
     if len(argv) < 3:
         raise CmdLineInputError()
+
+    level = argv[0]
+
     # KeyValueParser supports only key value arguments, so we will only filter
     # out those by looking for "=" to also include mistyped or missing keys
     kvpairs = [arg for arg in argv[2:] if "=" in arg]
@@ -325,11 +253,11 @@ def stonith_level_add_cmd(
     parser.check_allowed_keys(["id"])
     level_id = parser.get_unique().get("id")
     target_type, target_value = _stonith_level_parse_node(argv[1])
-    stonith_devices = _stonith_level_normalize_devices(argv[2:])
+    stonith_devices = argv[2:]
     _check_is_stonith(lib, stonith_devices)
 
     lib.fencing_topology.add_level(
-        argv[0],
+        level,
         target_type,
         target_value,
         stonith_devices,
@@ -352,65 +280,19 @@ def stonith_level_clear_cmd(
         lib.fencing_topology.remove_all_levels()
         return
 
-    allowed_keywords = {"target", "stonith"}
-    if len(argv) > 1 or (len(argv) == 1 and argv[0] in allowed_keywords):
-        (
-            target_type,
-            target_value,
-            devices,
-        ) = _stonith_level_parse_target_and_stonith(argv)
-        if devices is not None and target_value is not None:
-            raise CmdLineInputError(
-                "Only one of 'target' and 'stonith' can be used"
-            )
-        lib.fencing_topology.remove_levels_by_params(
-            None,
-            target_type,
-            target_value,
-            devices,
-        )
-        return
-
-    # TODO remove, deprecated backward compatibility mode for old syntax
-    # Command parameters are: node, stonith-list
-    # Both the node and the stonith list are optional. If the node is omitted
-    # and the stonith list is present, there is no way to figure it out, since
-    # there is no specification of what the parameter is. Hence the pre-lib
-    # code tried both. It deleted all levels having the first parameter as
-    # either a node or a device list. Since it was only possible to specify
-    # node as a target back then, this is enabled only in that case.
-    deprecation_warning(
-        "Syntax 'pcs stonith level clear [<target> | <stonith id(s)>] is "
-        "deprecated and will be removed. Please use 'pcs stonith level clear "
-        "[target <target>] | [stonith <stonith id>...]'."
+    (target_type, target_value, devices) = (
+        _stonith_level_parse_target_and_stonith(argv)
     )
-    target_type, target_value = _stonith_level_parse_node(argv[0])
-    was_error = False
-    try:
-        lib.fencing_topology.remove_levels_by_params(
-            None,
-            target_type,
-            target_value,
-            None,
-            # pre-lib code didn't return any error when no level was found
-            ignore_if_missing=True,
+    if devices is not None and target_value is not None:
+        raise CmdLineInputError(
+            "Only one of 'target' and 'stonith' can be used"
         )
-    except LibraryError:
-        was_error = True
-    if target_type == TARGET_TYPE_NODE:
-        try:
-            lib.fencing_topology.remove_levels_by_params(
-                None,
-                None,
-                None,
-                argv[0].split(","),
-                # pre-lib code didn't return any error when no level was found
-                ignore_if_missing=True,
-            )
-        except LibraryError:
-            was_error = True
-    if was_error:
-        raise LibraryError()
+    lib.fencing_topology.remove_levels_by_params(
+        None,
+        target_type,
+        target_value,
+        devices,
+    )
 
 
 def stonith_level_remove_cmd(
@@ -421,46 +303,19 @@ def stonith_level_remove_cmd(
       * -f - CIB file
     """
     modifiers.ensure_only_supported("-f")
-    if not argv:
+    if not argv or len(argv) < 1:
         raise CmdLineInputError()
-    target_type, target_value, devices = None, None, None
-    level = argv[0]
 
-    allowed_keywords = {"target", "stonith"}
-    if len(argv) > 1 and argv[1] in allowed_keywords:
-        (
-            target_type,
-            target_value,
-            devices,
-        ) = _stonith_level_parse_target_and_stonith(argv[1:])
-        target_may_be_a_device = False
-    else:
-        # TODO remove, deprecated backward compatibility layer for old syntax
-        if len(argv) > 1:
-            deprecation_warning(
-                "Syntax 'pcs stonith level delete | remove <level> [<target>] "
-                "[<stonith id>...]' is deprecated and will be removed. Please "
-                "use 'pcs stonith level delete | remove <level> "
-                "[target <target>] [stonith <stonith id>...]'."
-            )
-            if not parse_args.ARG_TYPE_DELIMITER in argv[1] and "," in argv[1]:
-                deprecation_warning(
-                    "Delimiting stonith devices with ',' is deprecated and "
-                    "will be removed. Please use a space to delimit stonith "
-                    "devices."
-                )
-            target_type, target_value = _stonith_level_parse_node(argv[1])
-        if len(argv) > 2:
-            devices = _stonith_level_normalize_devices(argv[2:])
-        target_may_be_a_device = True
+    level = argv[0]
+    target_type, target_value, devices = (
+        _stonith_level_parse_target_and_stonith(argv[1:])
+    )
 
     lib.fencing_topology.remove_levels_by_params(
         level,
         target_type,
         target_value,
         devices,
-        # backward compatibility mode, see lib command for details
-        target_may_be_a_device=target_may_be_a_device,
     )
 
 
@@ -504,17 +359,19 @@ def stonith_fence(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
 def stonith_confirm(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
-      * --force - do not warn user
+      * --force - required for confirming that fencing happened - DEPRECATED
+      * --yes - required for confirming that fencing happened
     """
     del lib
-    modifiers.ensure_only_supported("--force")
+    modifiers.ensure_only_supported("--force", "--yes")
     if len(argv) != 1:
         utils.err("must specify one (and only one) node to confirm fenced")
 
     node = argv.pop(0)
-    if not utils.get_continue_confirmation_or_force(
+    if not utils.get_continue_confirmation(
         f"If node '{node}' is not powered off or it does have access to shared "
         "resources, data corruption and/or cluster failure may occur",
+        bool(modifiers.get("--yes")),
         bool(modifiers.get("--force")),
     ):
         return
@@ -580,14 +437,17 @@ def sbd_watchdog_list_json(
 
 def sbd_watchdog_test(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
-    Options: no options
+    Options:
+      * --force - required for testing the watchdog - DEPRECATED
+      * --yes - required for testing the watchdog
     """
-    modifiers.ensure_only_supported("--force")
+    modifiers.ensure_only_supported("--force", "--yes")
     if len(argv) > 1:
         raise CmdLineInputError()
-    if not utils.get_continue_confirmation_or_force(
+    if not utils.get_continue_confirmation(
         "This operation is expected to force-reboot this system without "
         "following any shutdown procedures",
+        bool(modifiers.get("--yes")),
         bool(modifiers.get("--force")),
     ):
         return
@@ -807,18 +667,20 @@ def sbd_setup_block_device(
 ) -> None:
     """
     Options:
-      * --force - do not show warning about wiping the devices
+      * --force - required for wiping specified storage devices - DEPRECATED
+      * --yes - required for wiping specified storage devices
     """
-    modifiers.ensure_only_supported("--force")
+    modifiers.ensure_only_supported("--force", "--yes")
     parser = KeyValueParser(argv, repeatable=("device",))
     repeatable_options = parser.get_repeatable()
     device_list = repeatable_options.get("device", [])
     if not device_list:
         raise CmdLineInputError("No device defined")
 
-    if not utils.get_continue_confirmation_or_force(
+    if not utils.get_continue_confirmation(
         f"All current content on device(s) {format_list(device_list)} will be "
         "overwritten",
+        bool(modifiers.get("--yes")),
         bool(modifiers.get("--force")),
     ):
         return
@@ -961,11 +823,14 @@ def delete_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
         resources_dto
     )
     if non_stonith_ids:
-        deprecation_warning(
-            reports.messages.ResourceStonithCommandsMismatch(
-                "resources"
-            ).message
-            + " Please use 'pcs resource remove' instead."
+        raise CmdLineInputError(
+            (
+                "This command cannot remove {resource}: {id_list}. Use 'pcs "
+                "resource remove' instead."
+            ).format(
+                resource=format_plural(non_stonith_ids, "resource"),
+                id_list=format_list(non_stonith_ids),
+            )
         )
 
     force_flags = set()
@@ -995,10 +860,6 @@ def disable_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file
-      * --brief - show brief output of --simulate
-      * --safe - only disable if no other resource gets stopped or demoted
-      * --simulate - do not push the CIB, print its effects
-      * --no-strict - allow disable if other resource is affected
       * --wait
     """
     if not argv:
@@ -1006,11 +867,7 @@ def disable_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
             "You must specify stonith resource(s) to disable"
         )
     _check_is_stonith(lib, argv, "pcs resource disable")
-    if modifiers.is_specified_any(("--safe", "--no-strict", "--simulate")):
-        deprecation_warning(
-            "Options '--safe', '--no-strict' and '--simulate' are deprecated "
-            "and will be removed in a future release."
-        )
+    modifiers.ensure_only_supported("-f", "--wait", hint_syntax_changed="0.12")
     resource.resource_disable_common(lib, argv, modifiers)
 
 
