@@ -93,7 +93,7 @@ filename = ""
 pcs_options: Dict[Any, Any] = {}
 
 
-def getValidateWithVersion(dom) -> Version:
+def _getValidateWithVersion(dom) -> Version:
     """
     Commandline options: no options
     """
@@ -117,12 +117,12 @@ def getValidateWithVersion(dom) -> Version:
 def isCibVersionSatisfied(cib_dom, required_version: Version) -> bool:
     if not isinstance(cib_dom, DomDocument):
         cib_dom = cib_dom.ownerDocument
-    return getValidateWithVersion(cib_dom) >= required_version
+    return _getValidateWithVersion(cib_dom) >= required_version
 
 
 # Check the current pacemaker version in cib and upgrade it if necessary
 # Returns False if not upgraded and True if upgraded
-def checkAndUpgradeCIB(required_version: Version) -> bool:
+def _checkAndUpgradeCIB(required_version: Version) -> bool:
     """
     Commandline options:
       * -f - CIB file
@@ -154,9 +154,9 @@ def cluster_upgrade_to_version(required_version: Version) -> Any:
     Commandline options:
       * -f - CIB file
     """
-    checkAndUpgradeCIB(required_version)
+    _checkAndUpgradeCIB(required_version)
     dom = get_cib_dom()
-    current_version = getValidateWithVersion(dom)
+    current_version = _getValidateWithVersion(dom)
     if current_version < required_version:
         err(
             CibUpgradeFailedToMinimalRequiredVersion(
@@ -1468,16 +1468,6 @@ def dom_get_meta_attr_value(dom_resource, meta_name):
     return None
 
 
-def dom_get_element_with_id(dom, tag_name, element_id):
-    """
-    Commandline options: no options
-    """
-    for elem in dom.getElementsByTagName(tag_name):
-        if elem.hasAttribute("id") and elem.getAttribute("id") == element_id:
-            return elem
-    return None
-
-
 def dom_get_node(dom, node_name):
     """
     Commandline options: no options
@@ -1488,7 +1478,7 @@ def dom_get_node(dom, node_name):
     return None
 
 
-def dom_get_children_by_tag_name(dom_el, tag_name):
+def _dom_get_children_by_tag_name(dom_el, tag_name):
     """
     Commandline options: no options
     """
@@ -1514,28 +1504,6 @@ def dom_get_parent_by_tag_names(dom_el, tag_names):
     return None
 
 
-def dom_attrs_to_list(dom_el, with_id=False):
-    """
-    Commandline options: no options
-    """
-    attributes = [
-        "%s=%s"
-        % (
-            name,
-            (
-                value
-                if name != "role"
-                else common_pacemaker.role.get_value_primary(value.capitalize())
-            ),
-        )
-        for name, value in sorted(dom_el.attributes.items())
-        if name != "id"
-    ]
-    if with_id:
-        attributes.append("(id:%s)" % (dom_el.getAttribute("id")))
-    return attributes
-
-
 # moved to pcs.lib.pacemaker.state
 def get_resource_for_running_check(cluster_state, resource_id, stopped=False):
     """
@@ -1596,9 +1564,15 @@ def resource_running_on(resource, passed_state=None, stopped=False):
                 role = res.getAttribute("role")
                 if role == const.PCMK_ROLE_STARTED:
                     nodes_started.append(node_name)
-                elif role in const.PCMK_ROLES_PROMOTED:
+                elif role in (
+                    const.PCMK_ROLE_PROMOTED,
+                    const.PCMK_ROLE_PROMOTED_LEGACY,
+                ):
                     nodes_promoted.append(node_name)
-                elif role in const.PCMK_ROLES_UNPROMOTED:
+                elif role in (
+                    const.PCMK_ROLE_UNPROMOTED,
+                    const.PCMK_ROLE_UNPROMOTED_LEGACY,
+                ):
                     nodes_unpromoted.append(node_name)
     if not nodes_started and not nodes_promoted and not nodes_unpromoted:
         message = "Resource '%s' is not running on any node" % resource_original
@@ -1606,8 +1580,8 @@ def resource_running_on(resource, passed_state=None, stopped=False):
         message_parts = []
         for alist, label in (
             (nodes_started, "running"),
-            (nodes_promoted, str(const.PCMK_ROLE_PROMOTED_PRIMARY).lower()),
-            (nodes_unpromoted, str(const.PCMK_ROLE_UNPROMOTED_PRIMARY).lower()),
+            (nodes_promoted, str(const.PCMK_ROLE_PROMOTED).lower()),
+            (nodes_unpromoted, str(const.PCMK_ROLE_UNPROMOTED).lower()),
         ):
             if alist:
                 alist.sort()
@@ -1774,7 +1748,7 @@ def does_id_exist(dom, check_id):
             else dom.ownerDocument
         )
         cib_found = False
-        for cib in dom_get_children_by_tag_name(document, "cib"):
+        for cib in _dom_get_children_by_tag_name(document, "cib"):
             cib_found = True
             for section in cib.childNodes:
                 if section.nodeType != xml.dom.minidom.Node.ELEMENT_NODE:
@@ -2003,7 +1977,7 @@ def get_terminal_input(message=None):
         sys.exit(1)
 
 
-def _get_continue_confirmation(warning_text: str) -> bool:
+def _get_continue_confirmation_interactive(warning_text: str) -> bool:
     """
     Warns user and asks for permission to continue. Returns True if user wishes
     to continue, False otherwise.
@@ -2035,23 +2009,34 @@ def is_run_interactive() -> bool:
     )
 
 
-def get_continue_confirmation_or_force(warning_text: str, force: bool) -> bool:
+def get_continue_confirmation(
+    warning_text: str, yes: bool, force: bool
+) -> bool:
     """
-    Either asks user to confirm continuation interactively or use --force to
+    Either asks user to confirm continuation interactively or use --yes to
     override when running from a script. Returns True if user wants to continue.
     Returns False if user cancels the action. If a non-interactive environment
     is detected, pcs exits with an error formed from warning_text.
 
     warning_text -- describes action that we want the user to confirm
-    force -- was force flag provided?
+    yes -- was --yes flag provided?
+    force -- was --force flag provided? (deprecated)
     """
-    if force:
+    if force and not yes:
+        # Force may be specified for overriding library errors. We don't want
+        # to report an issue in that case.
+        # deprecated in the first pcs-0.12 version
+        reports_output.deprecation_warning(
+            "Using --force to confirm this action is deprecated and might be "
+            "removed in a future release, use --yes instead"
+        )
+    if yes or force:
         reports_output.warn(warning_text)
         return True
     if not is_run_interactive():
-        err(f"{warning_text}, use --force to override")
+        err(f"{warning_text}, use --yes to override")
         return False
-    return _get_continue_confirmation(warning_text)
+    return _get_continue_confirmation_interactive(warning_text)
 
 
 def get_terminal_password(message="Password: "):
@@ -2456,7 +2441,7 @@ def dom_update_nvset(dom_element, nvpair_tuples, tag_name, id_candidate):
     # Do not use dom.getElementsByTagName, that would get elements we do not
     # want to. For example if dom_element is a clone, we would get the clones's
     # as well as clone's primitive's attributes.
-    nvset_element_list = dom_get_children_by_tag_name(dom_element, tag_name)
+    nvset_element_list = _dom_get_children_by_tag_name(dom_element, tag_name)
 
     # Do not create new nvset if we are only removing values from it.
     if not nvset_element_list and only_removing:
@@ -2743,12 +2728,6 @@ def get_user_and_pass():
 
 
 def get_input_modifiers() -> InputModifiers:
-    if "--master" in pcs_options:
-        reports_output.deprecation_warning(
-            "Option '--master' is deprecated and has been replaced by option "
-            "'--promoted' "
-        )
-        pcs_options["--promoted"] = pcs_options.pop("--master")
     return InputModifiers(pcs_options)
 
 
@@ -2767,20 +2746,6 @@ def get_token_from_file(file_name: str) -> str:
         raise SystemExit(1) from e
 
 
-def print_depracation_warning_for_legacy_roles(role: str) -> None:
-    deprecation_map: Dict[str, str] = {
-        const.PCMK_ROLE_PROMOTED_LEGACY: const.PCMK_ROLE_PROMOTED,
-        const.PCMK_ROLE_UNPROMOTED_LEGACY: const.PCMK_ROLE_UNPROMOTED,
-    }
-    role_normalized = role.capitalize()
-    if role_normalized in deprecation_map:
-        replaced_by = deprecation_map[role_normalized]
-        reports_output.deprecation_warning(
-            f"Role value '{role}' is deprecated and should not be used, use "
-            f"'{replaced_by}' instead"
-        )
-
-
 def print_warning_if_utilization_attrs_has_no_effect(
     properties_facade: PropertyConfigurationFacade,
 ):
