@@ -664,16 +664,16 @@ class StonithRestartlessUpdateUnableToPerform(CliReportMessageTestBase):
         )
 
 
-class ResourceStonithCommandsMismatch(CliReportMessageTestBase):
+class CommandArgumentTypeMismatch(CliReportMessageTestBase):
     def test_no_cmd(self):
-        report_msg = messages.ResourceStonithCommandsMismatch("element type")
+        report_msg = messages.CommandArgumentTypeMismatch("element type")
         self.assert_message(
             report_msg,
             report_msg.message,
         )
 
     def test_unknown_cmd(self):
-        report_msg = messages.ResourceStonithCommandsMismatch(
+        report_msg = messages.CommandArgumentTypeMismatch(
             "element type", const.PCS_COMMAND_RESOURCE_CREATE
         )
         self.assert_message(
@@ -682,7 +682,7 @@ class ResourceStonithCommandsMismatch(CliReportMessageTestBase):
         )
 
     def test_use_instead(self):
-        report_msg = messages.ResourceStonithCommandsMismatch(
+        report_msg = messages.CommandArgumentTypeMismatch(
             "element type", const.PCS_COMMAND_STONITH_CREATE
         )
         self.assert_message(
@@ -720,6 +720,19 @@ class AgentSelfValidationResult(CliReportMessageTestBase):
         )
 
 
+class AgentSelfValidationAutoOnWithWarnings(CliReportMessageTestBase):
+    def test_message(self):
+        self.assert_message(
+            messages.AgentSelfValidationAutoOnWithWarnings(),
+            (
+                "Validating resource options using the resource agent itself "
+                "is enabled by default and produces warnings. In a future "
+                "version, this might be changed to errors. Specify "
+                "--agent-validation to switch to the future behavior."
+            ),
+        )
+
+
 class BoothAuthfileNotUsed(CliReportMessageTestBase):
     def test_message(self):
         self.assert_message(
@@ -836,3 +849,16 @@ class ResourceMoveAutocleanSimulationFailure(CliReportMessageTestBase):
                 " Run 'pcs resource clear R1 node1' to remove the constraint."
             ),
         )
+
+
+class ResourceWaitDeprecated(CliReportMessageTestBase):
+    def test_success(self):
+        self.assert_message(
+            messages.ResourceWaitDeprecated(),
+            (
+                "Using '--wait' is deprecated. Instead, use the 'pcs status "
+                "wait' command to wait for the cluster to settle into stable "
+                "state. Use the 'pcs status query resource' commands to verify "
+                "that the resource is in the expected state after the wait."
+            ),
+        )
