@@ -497,7 +497,6 @@ class ResourceBan(ResourceMoveBanMixin, TestCase):
         self.no_args_error = "must specify a resource to ban"
 
 
-@mock.patch("pcs.resource.deprecation_warning")
 class ResourceMove(TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["resource"])
@@ -505,16 +504,15 @@ class ResourceMove(TestCase):
         self.resource.is_any_stonith.return_value = False
         self.lib.resource = self.resource
 
-    def test_no_args(self, mock_deprecation):
+    def test_no_args(self):
         with self.assertRaises(CmdLineInputError) as cm:
             resource.resource_move(self.lib, [], dict_to_modifiers({}))
         self.assertEqual(
             cm.exception.message, "must specify a resource to move"
         )
         self.resource.move_autoclean.assert_not_called()
-        mock_deprecation.assert_not_called()
 
-    def test_too_many_args(self, mock_deprecation):
+    def test_too_many_args(self):
         with self.assertRaises(CmdLineInputError) as cm:
             resource.resource_move(
                 self.lib,
@@ -523,48 +521,30 @@ class ResourceMove(TestCase):
             )
         self.assertIsNone(cm.exception.message)
         self.resource.move_autoclean.assert_not_called()
-        mock_deprecation.assert_not_called()
 
-    def test_success(self, mock_deprecation):
+    def test_success(self):
         resource.resource_move(self.lib, ["resource"], dict_to_modifiers({}))
         self.resource.move_autoclean.assert_called_once_with(
             "resource", node=None, master=False, wait_timeout=-1, strict=False
         )
-        mock_deprecation.assert_not_called()
 
-    def test_success_node(self, mock_deprecation):
+    def test_success_node(self):
         resource.resource_move(
             self.lib, ["resource", "node"], dict_to_modifiers({})
         )
         self.resource.move_autoclean.assert_called_once_with(
             "resource", node="node", master=False, wait_timeout=-1, strict=False
         )
-        mock_deprecation.assert_not_called()
 
-    def test_success_wait(self, mock_warn):
+    def test_success_wait(self):
         resource.resource_move(
             self.lib, ["resource", "node"], dict_to_modifiers(dict(wait=None))
         )
         self.resource.move_autoclean.assert_called_once_with(
             "resource", node="node", master=False, wait_timeout=0, strict=False
         )
-        mock_warn.assert_not_called()
 
-    def test_success_autodelete(self, mock_deprecation):
-        resource.resource_move(
-            self.lib,
-            ["resource", "node"],
-            dict_to_modifiers(dict(autodelete=True)),
-        )
-        self.resource.move_autoclean.assert_called_once_with(
-            "resource", node="node", master=False, wait_timeout=-1, strict=False
-        )
-        mock_deprecation.assert_called_once_with(
-            "Option '--autodelete' is deprecated. There is no need to use it "
-            "as its functionality is default now."
-        )
-
-    def test_success_all_options(self, mock_warn):
+    def test_success_all_options(self):
         resource.resource_move(
             self.lib,
             ["resource", "node"],
@@ -573,7 +553,6 @@ class ResourceMove(TestCase):
         self.resource.move_autoclean.assert_called_once_with(
             "resource", node="node", master=True, wait_timeout=10, strict=True
         )
-        mock_warn.assert_not_called()
 
 
 class ResourceClear(TestCase):
@@ -1240,8 +1219,7 @@ class ResourceUnmanage(TestCase):
 class ResourceRestart(TestCase):
     def setUp(self):
         self.lib = mock.Mock(spec_set=["resource"])
-        self.resource = mock.Mock(spec_set=["restart", "is_any_stonith"])
-        self.resource.is_any_stonith.return_value = False
+        self.resource = mock.Mock(spec_set=["restart"])
         self.lib.resource = self.resource
 
     def test_no_args(self, mock_print):
@@ -1289,16 +1267,3 @@ class ResourceRestart(TestCase):
         )
         self.resource.restart.assert_called_once_with("resource", "node", "10s")
         mock_print.assert_called_once_with("resource successfully restarted")
-
-    @mock.patch("pcs.resource.deprecation_warning")
-    def test_stonith(self, mock_deprecation, mock_print):
-        self.resource.is_any_stonith.return_value = True
-        resource.resource_restart_cmd(
-            self.lib, ["stonith"], dict_to_modifiers({})
-        )
-        self.resource.restart.assert_called_once_with("stonith", None, None)
-        mock_print.assert_called_once_with("stonith successfully restarted")
-        mock_deprecation.assert_called_once_with(
-            "Ability of this command to accept stonith resources is deprecated "
-            "and will be removed in a future release."
-        )
