@@ -32,6 +32,8 @@ class ValidateMoveResourcesToGroup(TestCase):
                 <primitive id="R1" />
                 <primitive id="R2" />
                 <primitive id="R3" />
+                <primitive id="S1" class="stonith" />
+                <primitive id="S2" class="stonith" />
                 <clone id="RC1-clone">
                     <primitive id="RC1" />
                 </clone>
@@ -98,6 +100,27 @@ class ValidateMoveResourcesToGroup(TestCase):
             ],
         )
 
+    def test_resources_are_stonith_resources(self):
+        assert_report_item_list_equal(
+            self._validate("G", ["S1", "S2"]),
+            [
+                fixture.error(
+                    reports.codes.CANNOT_GROUP_RESOURCE_WRONG_TYPE,
+                    resource_id="S1",
+                    resource_type="stonith",
+                    parent_id=None,
+                    parent_type=None,
+                ),
+                fixture.error(
+                    reports.codes.CANNOT_GROUP_RESOURCE_WRONG_TYPE,
+                    resource_id="S2",
+                    resource_type="stonith",
+                    parent_id=None,
+                    parent_type=None,
+                ),
+            ],
+        )
+
     def test_resources_are_in_clones_etc(self):
         assert_report_item_list_equal(
             self._validate("G", ["RC1", "R1", "RB1"]),
@@ -371,186 +394,186 @@ class ValidateMoveBanClearMixin:
             """
         )
 
-    def test_master_true_promotable_clone(self):
+    def test_promoted_true_promotable_clone(self):
         element = self._fixture_clone(True)
         assert_report_item_list_equal(self.validate(element, True), [])
 
-    def test_master_false_promotable_clone(self):
+    def test_promoted_false_promotable_clone(self):
         element = self._fixture_clone(True)
         assert_report_item_list_equal(self.validate(element, False), [])
 
-    def test_master_true_clone(self):
+    def test_promoted_true_clone(self):
         element = self._fixture_clone(False)
         assert_report_item_list_equal(
             self.validate(element, True),
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="R-clone",
                     promotable_id="",
                 ),
             ],
         )
 
-    def test_master_false_clone(self):
+    def test_promoted_false_clone(self):
         element = self._fixture_clone(False)
         assert_report_item_list_equal(self.validate(element, False), [])
 
-    def test_master_true_master(self):
+    def test_promoted_true_master(self):
         element = self._fixture_master()
         assert_report_item_list_equal(self.validate(element, True), [])
 
-    def test_master_false_master(self):
+    def test_promoted_false_master(self):
         element = self._fixture_master()
         assert_report_item_list_equal(self.validate(element, False), [])
 
-    def test_master_true_promotable_clone_resource(self):
+    def test_promoted_true_promotable_clone_resource(self):
         element = self._fixture_clone(True)
         assert_report_item_list_equal(
             self.validate(element.find("./primitive"), True),
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="R",
                     promotable_id="R-clone",
                 ),
             ],
         )
 
-    def test_master_false_promotable_clone_resource(self):
+    def test_promoted_false_promotable_clone_resource(self):
         element = self._fixture_clone(True)
         assert_report_item_list_equal(
             self.validate(element.find("./primitive"), False), []
         )
 
-    def test_master_true_promotable_clone_group(self):
+    def test_promoted_true_promotable_clone_group(self):
         element = self._fixture_group_clone(True)
         assert_report_item_list_equal(
             self.validate(element.find("./group"), True),
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="G",
                     promotable_id="G-clone",
                 ),
             ],
         )
 
-    def test_master_false_promotable_clone_group(self):
+    def test_promoted_false_promotable_clone_group(self):
         element = self._fixture_group_clone(True)
         assert_report_item_list_equal(
             self.validate(element.find("./group"), False), []
         )
 
-    def test_master_true_promotable_clone_group_resource(self):
+    def test_promoted_true_promotable_clone_group_resource(self):
         element = self._fixture_group_clone(True)
         assert_report_item_list_equal(
             self.validate(element.find("./group/primitive"), True),
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="R",
                     promotable_id="G-clone",
                 ),
             ],
         )
 
-    def test_master_false_promotable_clone_group_resource(self):
+    def test_promoted_false_promotable_clone_group_resource(self):
         element = self._fixture_group_clone(True)
         assert_report_item_list_equal(
             self.validate(element.find("./group/primitive"), False), []
         )
 
-    def test_master_true_clone_resource(self):
+    def test_promoted_true_clone_resource(self):
         element = self._fixture_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./primitive"), True),
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="R",
                     promotable_id="",
                 ),
             ],
         )
 
-    def test_master_false_clone_resource(self):
+    def test_promoted_false_clone_resource(self):
         element = self._fixture_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./primitive"), False), []
         )
 
-    def test_master_true_clone_group(self):
+    def test_promoted_true_clone_group(self):
         element = self._fixture_group_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./group"), True),
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="G",
                     promotable_id="",
                 ),
             ],
         )
 
-    def test_master_false_clone_group(self):
+    def test_promoted_false_clone_group(self):
         element = self._fixture_group_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./group"), False), []
         )
 
-    def test_master_true_clone_group_resource(self):
+    def test_promoted_true_clone_group_resource(self):
         element = self._fixture_group_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./group/primitive"), True),
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="R",
                     promotable_id="",
                 ),
             ],
         )
 
-    def test_master_false_clone_group_resource(self):
+    def test_promoted_false_clone_group_resource(self):
         element = self._fixture_group_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./group/primitive"), False), []
         )
 
-    def test_master_true_master_resource(self):
+    def test_promoted_true_master_resource(self):
         element = self._fixture_master()
         assert_report_item_list_equal(
             self.validate(element.find("./primitive"), True),
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="R",
                     promotable_id="R-master",
                 ),
             ],
         )
 
-    def test_master_true_master_group(self):
+    def test_promoted_true_master_group(self):
         element = self._fixture_group_master()
         assert_report_item_list_equal(
             self.validate(element.find("./group"), True),
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="G",
                     promotable_id="G-master",
                 ),
             ],
         )
 
-    def test_master_true_master_group_resource(self):
+    def test_promoted_true_master_group_resource(self):
         element = self._fixture_group_master()
         assert_report_item_list_equal(
             self.validate(element.find("./group/primitive"), True),
             [
                 fixture.error(
-                    self.report_code_bad_master,
+                    self.report_code_bad_promoted,
                     resource_id="R",
                     promotable_id="G-master",
                 ),
@@ -560,25 +583,25 @@ class ValidateMoveBanClearMixin:
 
 class ValidateMove(ValidateMoveBanClearMixin, TestCase):
     validate = staticmethod(validations.validate_move)
-    report_code_bad_master = (
+    report_code_bad_promoted = (
         reports.codes.CANNOT_MOVE_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
     )
 
-    def test_master_false_promotable_clone(self):
+    def test_promoted_false_promotable_clone(self):
         element = self._fixture_clone(True)
         assert_report_item_list_equal(
             self.validate(element, False),
             [],
         )
 
-    def test_master_true_promotable_clone(self):
+    def test_promoted_true_promotable_clone(self):
         element = self._fixture_clone(True)
         assert_report_item_list_equal(
             self.validate(element, True),
             [],
         )
 
-    def test_master_true_clone(self):
+    def test_promoted_true_clone(self):
         element = self._fixture_clone(False)
         assert_report_item_list_equal(
             self.validate(element, True),
@@ -591,28 +614,28 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             ],
         )
 
-    def test_master_false_clone(self):
+    def test_promoted_false_clone(self):
         element = self._fixture_clone(False)
         assert_report_item_list_equal(
             self.validate(element, False),
             [],
         )
 
-    def test_master_false_master(self):
+    def test_promoted_false_master(self):
         element = self._fixture_master()
         assert_report_item_list_equal(
             self.validate(element, False),
             [],
         )
 
-    def test_master_true_master(self):
+    def test_promoted_true_master(self):
         element = self._fixture_master()
         assert_report_item_list_equal(
             self.validate(element, True),
             [],
         )
 
-    def test_master_false_promotable_clone_resource(self):
+    def test_promoted_false_promotable_clone_resource(self):
         element = self._fixture_clone(True)
         assert_report_item_list_equal(
             self.validate(element.find("./primitive"), False),
@@ -625,7 +648,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             ],
         )
 
-    def test_master_false_promotable_clone_group(self):
+    def test_promoted_false_promotable_clone_group(self):
         element = self._fixture_group_clone(True)
         assert_report_item_list_equal(
             self.validate(element.find("./group"), False),
@@ -638,7 +661,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             ],
         )
 
-    def test_master_false_promotable_clone_group_resource(self):
+    def test_promoted_false_promotable_clone_group_resource(self):
         element = self._fixture_group_clone(True)
         assert_report_item_list_equal(
             self.validate(element.find("./group/primitive"), False),
@@ -651,7 +674,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             ],
         )
 
-    def test_master_true_clone_resource(self):
+    def test_promoted_true_clone_resource(self):
         element = self._fixture_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./primitive"), True),
@@ -664,7 +687,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             ],
         )
 
-    def test_master_false_clone_resource(self):
+    def test_promoted_false_clone_resource(self):
         element = self._fixture_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./primitive"), False),
@@ -677,7 +700,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             ],
         )
 
-    def test_master_true_clone_group(self):
+    def test_promoted_true_clone_group(self):
         element = self._fixture_group_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./group"), True),
@@ -690,7 +713,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             ],
         )
 
-    def test_master_false_clone_group(self):
+    def test_promoted_false_clone_group(self):
         element = self._fixture_group_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./group"), False),
@@ -703,7 +726,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             ],
         )
 
-    def test_master_true_clone_group_resource(self):
+    def test_promoted_true_clone_group_resource(self):
         element = self._fixture_group_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./group/primitive"), True),
@@ -716,7 +739,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             ],
         )
 
-    def test_master_false_clone_group_resource(self):
+    def test_promoted_false_clone_group_resource(self):
         element = self._fixture_group_clone(False)
         assert_report_item_list_equal(
             self.validate(element.find("./group/primitive"), False),
@@ -752,7 +775,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
 
 class ValidateBan(ValidateMoveBanClearMixin, TestCase):
     validate = staticmethod(validations.validate_ban)
-    report_code_bad_master = (
+    report_code_bad_promoted = (
         reports.codes.CANNOT_BAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
     )
 
@@ -772,6 +795,6 @@ class ValidateBan(ValidateMoveBanClearMixin, TestCase):
 
 class ValidateUnmoveUnban(ValidateMoveBanClearMixin, TestCase):
     validate = staticmethod(validations.validate_unmove_unban)
-    report_code_bad_master = (
+    report_code_bad_promoted = (
         reports.codes.CANNOT_UNMOVE_UNBAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
     )
