@@ -859,95 +859,3 @@ class Unmanage(TestCase):
                 </resource>
             """,
         )
-
-
-class FindResourcesToDelete(TestCase):
-    # pylint: disable=too-many-public-methods
-    def assert_element2element_list(self, element_id, element_id_list):
-        self.assertEqual(
-            common.find_resources_to_delete(
-                fixture_cib.xpath(f'.//*[@id="{element_id}"]')[0]
-            ),
-            [
-                fixture_cib.xpath(f'.//*[@id="{_id}"]')[0]
-                for _id in element_id_list
-            ],
-        )
-
-    def test_primitive(self):
-        self.assert_element2element_list("A", ["A"])
-
-    def test_clone(self):
-        self.assert_element2element_list("B-clone", ["B-clone", "B"])
-
-    def test_primitive_in_clone(self):
-        self.assert_element2element_list("B", ["B-clone", "B"])
-
-    def test_master(self):
-        self.assert_element2element_list("C-master", ["C-master", "C"])
-
-    def test_primitive_in_master(self):
-        self.assert_element2element_list("C", ["C-master", "C"])
-
-    def test_group(self):
-        self.assert_element2element_list("D", ["D", "D1", "D2"])
-
-    def test_primitive_in_group(self):
-        self.assert_element2element_list("D1", ["D1"])
-
-    def test_clone_with_group(self):
-        self.assert_element2element_list(
-            "E-clone",
-            ["E-clone", "E", "E1", "E2"],
-        )
-
-    def test_group_in_clone(self):
-        self.assert_element2element_list("E", ["E-clone", "E", "E1", "E2"])
-
-    def test_primitive_in_cloned_group(self):
-        self.assert_element2element_list("E2", ["E2"])
-
-    def test_master_with_group(self):
-        self.assert_element2element_list(
-            "F-master",
-            ["F-master", "F", "F1", "F2"],
-        )
-
-    def test_group_in_master(self):
-        self.assert_element2element_list("F", ["F-master", "F", "F1", "F2"])
-
-    def test_primitive_in_mastered_group(self):
-        self.assert_element2element_list("F1", ["F1"])
-
-    def test_empty_bundle(self):
-        self.assert_element2element_list("G-bundle", ["G-bundle"])
-
-    def test_bundle_with_primitive(self):
-        self.assert_element2element_list("H-bundle", ["H-bundle", "H"])
-
-    def test_primitive_in_bundle(self):
-        self.assert_element2element_list("H", ["H"])
-
-    def test_group_with_single_primitive(self):
-        self.assert_element2element_list("I", ["I", "I1"])
-
-    def test_single_primitive_in_group(self):
-        self.assert_element2element_list("I1", ["I", "I1"])
-
-    def test_clone_with_group_with_single_primitive(self):
-        self.assert_element2element_list("J-clone", ["J-clone", "J", "J1"])
-
-    def test_group_with_single_primitive_in_clone(self):
-        self.assert_element2element_list("J", ["J-clone", "J", "J1"])
-
-    def test_single_primitive_in_cloned_group(self):
-        self.assert_element2element_list("J1", ["J-clone", "J", "J1"])
-
-    def test_master_with_group_with_single_primitive(self):
-        self.assert_element2element_list("K-master", ["K-master", "K", "K1"])
-
-    def test_group_with_single_primitive_in_master(self):
-        self.assert_element2element_list("K", ["K-master", "K", "K1"])
-
-    def test_single_primitive_in_mastered_group(self):
-        self.assert_element2element_list("K1", ["K-master", "K", "K1"])
