@@ -1,13 +1,17 @@
-from unittest import mock, TestCase
-from lxml import etree
+from unittest import (
+    TestCase,
+    mock,
+)
 
-from pcs_test.tools.assertions import assert_report_item_list_equal
+from lxml import etree
 
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
 from pcs.lib.cib.node import PacemakerNode
 from pcs.lib.cib.resource import remote_node
 
+from pcs_test.tools.assertions import assert_report_item_list_equal
+
 
 class FindNodeList(TestCase):
     def assert_nodes_equals(self, xml, expected_nodes):
