@@ -1,9 +1,7 @@
 from functools import partial
-from unittest import (
-    TestCase,
-    mock,
-)
+from unittest import TestCase
 
+from pcs.common import reports
 from pcs.common.host import Destination
 from pcs.common.reports import codes as report_codes
 from pcs.lib.commands.remote_node import (
@@ -22,6 +20,7 @@ from pcs_test.tier0.lib.commands.remote_node.fixtures_remove import (
     report_pcmk_remote_stop_failed,
     report_remove_file_connection_failed,
 )
+from pcs_test.tier0.lib.commands.test_cib import StopResourcesWaitMixin
 from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
 
@@ -53,14 +52,70 @@ FIXTURE_RESOURCES = """
     REMOTE_HOST,
 )
 
-REPORTS = base_reports_for_host(NODE_NAME)
+FIXTURE_RESOURCES_DISABLED_MODIFIERS = {
+    "resources": """
+        <resources>
+            <primitive class="ocf" id="{0}" provider="pacemaker" type="remote">
+                <meta_attributes id="{0}-meta_attributes">
+                    <nvpair id="{0}-meta_attributes-target-role" name="target-role" value="Stopped"/>
+                </meta_attributes>
+                <instance_attributes id="node-name-instance_attributes">
+                    <nvpair
+                        id="node-name-instance_attributes-server"
+                        name="server" value="{1}"
+                    />
+                </instance_attributes>
+            </primitive>
+        </resources>
+    """.format(
+        NODE_NAME,
+        REMOTE_HOST,
+    )
+}
+
+FIXTURE_RESOURCES_STATE_BEFORE_MODIFIERS = {
+    "resources": """
+        <resources>
+            <resource id="{0}" managed="true" role="Started"/>
+        </resources>
+    """.format(
+        NODE_NAME
+    )
+}
+
+FIXTURE_RESOURCES_STATE_AFTER_MODIFIERS = {
+    "resources": """
+        <resources>
+            <resource id="{0}" managed="true" role="Stopped"/>
+        </resources>
+    """.format(
+        NODE_NAME
+    )
+}
+
+
+REPORTS = fixture.ReportSequenceBuilder().info(
+    report_codes.CIB_REMOVE_RESOURCES,
+    id_list=[NODE_NAME],
+    _name="cib_remove_resources",
+).fixtures + base_reports_for_host(NODE_NAME)
+
+REPORTS_WITH_DISABLE = (
+    fixture.ReportSequenceBuilder()
+    .info(
+        report_codes.STOPPING_RESOURCES_BEFORE_DELETING,
+        resource_id_list=[NODE_NAME],
+    )
+    .info(report_codes.WAIT_FOR_IDLE_STARTED, timeout=0)
+).fixtures + REPORTS
+
 
 get_env_tools = partial(
     get_env_tools, local_extensions={"local": EnvConfigMixin}
 )
 
 
-class RemoveRemote(TestCase):
+class RemoveRemote(TestCase, StopResourcesWaitMixin):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
         self.config.env.set_known_hosts_dests(
@@ -68,12 +123,18 @@ class RemoveRemote(TestCase):
                 NODE_NAME: NODE_DEST_LIST,
             }
         )
-        self.remove_resource = mock.Mock()
+        self.fixture_init_tmp_file_mocker()
 
     def find_by(self, identifier):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
         self.config.runner.cib.load(resources=FIXTURE_RESOURCES)
+        self.fixture_stop_resources_wait_calls(
+            self.config.calls.get("runner.cib.load").stdout,
+            FIXTURE_RESOURCES_STATE_BEFORE_MODIFIERS,
+            FIXTURE_RESOURCES_DISABLED_MODIFIERS,
+            FIXTURE_RESOURCES_STATE_AFTER_MODIFIERS,
+        )
         self.config.local.destroy_pacemaker_remote(
             label=NODE_NAME, dest_list=NODE_DEST_LIST
         )
@@ -82,15 +143,13 @@ class RemoveRemote(TestCase):
                 dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
             ],
         )
+        self.fixture_push_cib_after_stopping(resources="<resources/>")
+        self.config.runner.pcmk.remove_node(NODE_NAME)
+
         node_remove_remote(
-            self.env_assist.get_env(),
-            node_identifier=identifier,
-            remove_resource=self.remove_resource,
+            self.env_assist.get_env(), node_identifier=identifier
         )
-        self.remove_resource.assert_called_once_with(
-            NODE_NAME, is_remove_remote_context=True
-        )
-        self.env_assist.assert_reports(REPORTS)
+        self.env_assist.assert_reports(REPORTS_WITH_DISABLE)
 
     def test_success_base(self):
         self.find_by(REMOTE_HOST)
@@ -99,20 +158,26 @@ class RemoveRemote(TestCase):
         self.find_by(NODE_NAME)
 
 
-class RemoveRemoteOthers(TestCase):
+class RemoveRemoteOthers(TestCase, StopResourcesWaitMixin):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
-        self.remove_resource = mock.Mock()
         self.config.env.set_known_hosts_dests(
             {
                 NODE_NAME: NODE_DEST_LIST,
             }
         )
+        self.fixture_init_tmp_file_mocker()
 
     def test_can_skip_all_offline(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
         self.config.runner.cib.load(resources=FIXTURE_RESOURCES)
+        self.fixture_stop_resources_wait_calls(
+            self.config.calls.get("runner.cib.load").stdout,
+            FIXTURE_RESOURCES_STATE_BEFORE_MODIFIERS,
+            FIXTURE_RESOURCES_DISABLED_MODIFIERS,
+            FIXTURE_RESOURCES_STATE_AFTER_MODIFIERS,
+        )
         self.config.local.destroy_pacemaker_remote(
             label=NODE_NAME, dest_list=NODE_DEST_LIST, **FAIL_HTTP_KWARGS
         )
@@ -122,16 +187,13 @@ class RemoveRemoteOthers(TestCase):
             ],
             **FAIL_HTTP_KWARGS,
         )
+        self.fixture_push_cib_after_stopping(resources="<resources/>")
+        self.config.runner.pcmk.remove_node(NODE_NAME)
 
         node_remove_remote(
-            self.env_assist.get_env(),
-            remove_resource=self.remove_resource,
-            skip_offline_nodes=True,
+            self.env_assist.get_env(), [reports.codes.SKIP_OFFLINE_NODES]
         )
-        self.remove_resource.assert_called_once_with(
-            NODE_NAME, is_remove_remote_context=True
-        )
-        my_reports = REPORTS.copy()
+        my_reports = REPORTS_WITH_DISABLE.copy()
         my_reports.replace(
             "pcmk_remote_disable_success",
             report_manage_services_connection_failed(NODE_NAME).to_warn(),
@@ -144,12 +206,10 @@ class RemoveRemoteOthers(TestCase):
         self.env_assist.assert_reports(my_reports)
 
     def test_fail_when_identifier_not_found(self):
-        (self.config.runner.cib.load(resources=FIXTURE_RESOURCES))
+        self.config.runner.cib.load(resources=FIXTURE_RESOURCES)
         self.env_assist.assert_raise_library_error(
             lambda: node_remove_remote(
-                self.env_assist.get_env(),
-                remove_resource=self.remove_resource,
-                node_identifier="NOEXISTENT",
+                self.env_assist.get_env(), node_identifier="NOEXISTENT"
             ),
             [
                 fixture.error(
@@ -188,8 +248,7 @@ class MultipleResults(TestCase):
 
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
-        self.remove_resource = mock.Mock()
-        (self.config.runner.cib.load(resources=self.fixture_multi_resources))
+        self.config.runner.cib.load(resources=self.fixture_multi_resources)
         self.report_multiple_results = fixture.error(
             report_codes.MULTIPLE_RESULTS_FOUND,
             force_code=report_codes.FORCE,
@@ -210,9 +269,7 @@ class MultipleResults(TestCase):
     def test_fail(self):
         self.env_assist.assert_raise_library_error(
             lambda: node_remove_remote(
-                self.env_assist.get_env(),
-                node_identifier=REMOTE_HOST,
-                remove_resource=self.remove_resource,
+                self.env_assist.get_env(), node_identifier=REMOTE_HOST
             )
         )
         self.env_assist.assert_reports([self.report_multiple_results])
@@ -232,14 +289,26 @@ class MultipleResults(TestCase):
                 dict(label=REMOTE_HOST, dest_list=REMOTE_DEST_LIST),
             ],
         )
+        self.config.env.push_cib(resources="<resources/>")
+        self.config.runner.pcmk.remove_node(
+            NODE_NAME, name="remove_node.node_name"
+        )
+        self.config.runner.pcmk.remove_node(
+            REMOTE_HOST, name="remove_node.remote_host"
+        )
 
         node_remove_remote(
             self.env_assist.get_env(),
             node_identifier=REMOTE_HOST,
-            remove_resource=self.remove_resource,
-            allow_remove_multiple_nodes=True,
+            force_flags=[reports.codes.FORCE],
         )
         my_reports = REPORTS.copy()
+        my_reports.replace(
+            "cib_remove_resources",
+            REPORTS["cib_remove_resources"].adapt(
+                id_list=[NODE_NAME, REMOTE_HOST]
+            ),
+        )
         my_reports.replace(
             "pcmk_remote_disable_stop_started",
             REPORTS["pcmk_remote_disable_stop_started"].adapt(
@@ -262,10 +331,15 @@ class MultipleResults(TestCase):
             REPORTS["authkey_remove_success"].adapt(node=REMOTE_HOST)
         )
         my_reports.append(self.report_multiple_results.to_warn())
+        my_reports.append(
+            fixture.warn(
+                reports.codes.STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED
+            )
+        )
         self.env_assist.assert_reports(my_reports)
 
 
-class AuthkeyRemove(TestCase):
+class AuthkeyRemove(TestCase, StopResourcesWaitMixin):
     def setUp(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
@@ -275,15 +349,21 @@ class AuthkeyRemove(TestCase):
                 NODE_NAME: NODE_DEST_LIST,
             }
         )
+        self.fixture_init_tmp_file_mocker()
         self.config.runner.cib.load(resources=FIXTURE_RESOURCES)
-        self.config.local.destroy_pacemaker_remote(
-            label=NODE_NAME, dest_list=NODE_DEST_LIST
-        )
-        self.remove_resource = mock.Mock()
 
     def test_fails_when_offline(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
+        self.fixture_stop_resources_wait_calls(
+            self.config.calls.get("runner.cib.load").stdout,
+            FIXTURE_RESOURCES_STATE_BEFORE_MODIFIERS,
+            FIXTURE_RESOURCES_DISABLED_MODIFIERS,
+            FIXTURE_RESOURCES_STATE_AFTER_MODIFIERS,
+        )
+        self.config.local.destroy_pacemaker_remote(
+            label=NODE_NAME, dest_list=NODE_DEST_LIST
+        )
         self.config.local.remove_authkey(
             communication_list=[
                 dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
@@ -291,12 +371,9 @@ class AuthkeyRemove(TestCase):
             **FAIL_HTTP_KWARGS,
         )
         self.env_assist.assert_raise_library_error(
-            lambda: node_remove_remote(
-                self.env_assist.get_env(),
-                remove_resource=self.remove_resource,
-            )
+            lambda: node_remove_remote(self.env_assist.get_env())
         )
-        my_reports = REPORTS.copy()
+        my_reports = REPORTS_WITH_DISABLE.copy()
         my_reports.replace(
             "authkey_remove_success",
             report_remove_file_connection_failed(NODE_NAME),
@@ -306,6 +383,15 @@ class AuthkeyRemove(TestCase):
     def test_fails_when_remotely_fails(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
+        self.fixture_stop_resources_wait_calls(
+            self.config.calls.get("runner.cib.load").stdout,
+            FIXTURE_RESOURCES_STATE_BEFORE_MODIFIERS,
+            FIXTURE_RESOURCES_DISABLED_MODIFIERS,
+            FIXTURE_RESOURCES_STATE_AFTER_MODIFIERS,
+        )
+        self.config.local.destroy_pacemaker_remote(
+            label=NODE_NAME, dest_list=NODE_DEST_LIST
+        )
         self.config.local.remove_authkey(
             communication_list=[
                 dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
@@ -316,12 +402,9 @@ class AuthkeyRemove(TestCase):
             },
         )
         self.env_assist.assert_raise_library_error(
-            lambda: node_remove_remote(
-                self.env_assist.get_env(),
-                remove_resource=self.remove_resource,
-            )
+            lambda: node_remove_remote(self.env_assist.get_env())
         )
-        my_reports = REPORTS.copy()
+        my_reports = REPORTS_WITH_DISABLE.copy()
         my_reports.replace(
             "authkey_remove_success",
             report_authkey_remove_failed(NODE_NAME),
@@ -331,6 +414,9 @@ class AuthkeyRemove(TestCase):
     def test_forceable_when_remotely_fail(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
+        self.config.local.destroy_pacemaker_remote(
+            label=NODE_NAME, dest_list=NODE_DEST_LIST
+        )
         self.config.local.remove_authkey(
             communication_list=[
                 dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
@@ -340,49 +426,62 @@ class AuthkeyRemove(TestCase):
                 "message": "Access denied",
             },
         )
-        node_remove_remote(
-            self.env_assist.get_env(),
-            remove_resource=self.remove_resource,
-            allow_pacemaker_remote_service_fail=True,
-        )
+        self.config.env.push_cib(resources="<resources/>")
+        self.config.runner.pcmk.remove_node(NODE_NAME)
+
+        node_remove_remote(self.env_assist.get_env(), [reports.codes.FORCE])
         my_reports = REPORTS.copy()
         my_reports.replace(
             "authkey_remove_success",
             report_authkey_remove_failed(NODE_NAME).to_warn(),
         )
+        my_reports.append(
+            fixture.warn(
+                reports.codes.STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED
+            )
+        )
         self.env_assist.assert_reports(my_reports)
 
 
-class PcmkRemoteServiceDestroy(TestCase):
+class PcmkRemoteServiceDestroy(TestCase, StopResourcesWaitMixin):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
         self.config.runner.cib.load(resources=FIXTURE_RESOURCES)
-        self.remove_resource = mock.Mock()
         self.config.env.set_known_hosts_dests(
             {
                 NODE_NAME: NODE_DEST_LIST,
             }
         )
+        self.fixture_init_tmp_file_mocker()
 
     def test_fails_when_offline(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
+        self.fixture_stop_resources_wait_calls(
+            self.config.calls.get("runner.cib.load").stdout,
+            FIXTURE_RESOURCES_STATE_BEFORE_MODIFIERS,
+            FIXTURE_RESOURCES_DISABLED_MODIFIERS,
+            FIXTURE_RESOURCES_STATE_AFTER_MODIFIERS,
+        )
         self.config.local.destroy_pacemaker_remote(
             label=NODE_NAME, dest_list=NODE_DEST_LIST, **FAIL_HTTP_KWARGS
         )
         self.env_assist.assert_raise_library_error(
-            lambda: node_remove_remote(
-                self.env_assist.get_env(),
-                remove_resource=self.remove_resource,
-            )
+            lambda: node_remove_remote(self.env_assist.get_env())
         )
-        my_reports = REPORTS[:"pcmk_remote_disable_success"]
+        my_reports = REPORTS_WITH_DISABLE[:"pcmk_remote_disable_success"]
         my_reports.append(report_manage_services_connection_failed(NODE_NAME))
         self.env_assist.assert_reports(my_reports)
 
     def test_fails_when_remotely_fails(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
+        self.fixture_stop_resources_wait_calls(
+            self.config.calls.get("runner.cib.load").stdout,
+            FIXTURE_RESOURCES_STATE_BEFORE_MODIFIERS,
+            FIXTURE_RESOURCES_DISABLED_MODIFIERS,
+            FIXTURE_RESOURCES_STATE_AFTER_MODIFIERS,
+        )
         self.config.local.destroy_pacemaker_remote(
             label=NODE_NAME,
             dest_list=NODE_DEST_LIST,
@@ -392,12 +491,9 @@ class PcmkRemoteServiceDestroy(TestCase):
             },
         )
         self.env_assist.assert_raise_library_error(
-            lambda: node_remove_remote(
-                self.env_assist.get_env(),
-                remove_resource=self.remove_resource,
-            )
+            lambda: node_remove_remote(self.env_assist.get_env())
         )
-        my_reports = REPORTS[:"pcmk_remote_disable_success"]
+        my_reports = REPORTS_WITH_DISABLE[:"pcmk_remote_disable_success"]
         my_reports.append(report_pcmk_remote_disable_failed(NODE_NAME))
         my_reports.append(report_pcmk_remote_stop_failed(NODE_NAME))
         self.env_assist.assert_reports(my_reports)
@@ -417,11 +513,10 @@ class PcmkRemoteServiceDestroy(TestCase):
                 dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
             ],
         )
-        node_remove_remote(
-            self.env_assist.get_env(),
-            remove_resource=self.remove_resource,
-            allow_pacemaker_remote_service_fail=True,
-        )
+        self.config.env.push_cib(resources="<resources/>")
+        self.config.runner.pcmk.remove_node(NODE_NAME)
+
+        node_remove_remote(self.env_assist.get_env(), [reports.codes.FORCE])
         my_reports = REPORTS.copy()
         my_reports.replace(
             "pcmk_remote_disable_success",
@@ -431,4 +526,9 @@ class PcmkRemoteServiceDestroy(TestCase):
             "pcmk_remote_stop_success",
             report_pcmk_remote_stop_failed(NODE_NAME).to_warn(),
         )
+        my_reports.append(
+            fixture.warn(
+                reports.codes.STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED
+            )
+        )
         self.env_assist.assert_reports(my_reports)
