@@ -108,7 +108,6 @@ class Basics(TestCase):
 class ContainerParametrized(TestCase):
     allowed_options = [
         "image",
-        "masters",
         "network",
         "options",
         "promoted-max",
@@ -154,17 +153,6 @@ class ContainerParametrized(TestCase):
             container_type=self.container_type
         )
 
-    fixture_report_deprecated_masters = (
-        severities.DEPRECATION,
-        report_codes.DEPRECATED_OPTION,
-        {
-            "option_name": "masters",
-            "option_type": "container",
-            "replaced_by": ["promoted-max"],
-        },
-        None,
-    )
-
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
 
@@ -323,7 +311,6 @@ class ContainerParametrized(TestCase):
                 self.env_assist.get_env(),
                 "B1",
                 container_options={
-                    "masters": "-1",
                     "promoted-max": "-2",
                     "replicas": "0",
                     "replicas-per-host": "0",
@@ -332,15 +319,6 @@ class ContainerParametrized(TestCase):
         )
         self.env_assist.assert_reports(
             [
-                self.fixture_report_deprecated_masters,
-                fixture.error(
-                    report_codes.INVALID_OPTION_VALUE,
-                    option_name="masters",
-                    option_value="-1",
-                    allowed_values="a non-negative integer",
-                    cannot_be_empty=False,
-                    forbidden_characters=None,
-                ),
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
                     option_name="promoted-max",
@@ -349,18 +327,6 @@ class ContainerParametrized(TestCase):
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
-                (
-                    severities.ERROR,
-                    report_codes.MUTUALLY_EXCLUSIVE_OPTIONS,
-                    {
-                        "option_names": [
-                            "masters",
-                            "promoted-max",
-                        ],
-                        "option_type": "container",
-                    },
-                    None,
-                ),
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
                     option_name="replicas",
@@ -380,25 +346,33 @@ class ContainerParametrized(TestCase):
             ]
         )
 
-    def _test_deprecated_options_set(self):
-        # Setting both deprecated options and their new variants is tested in
-        # self.test_options_errors. This shows deprecated options emit warning
-        # even when not forced.
-        (
-            self.config.runner.cib.load(
-                resources=fixture_resources_minimal(self.container_type)
-            ).env.push_cib(resources=self.fixture_cib_masters)
+    def _test_legacy_options_no_longer_allowed(self):
+        self.config.runner.cib.load(
+            resources=fixture_resources_minimal(self.container_type)
         )
-        resource.bundle_update(
-            self.env_assist.get_env(),
-            "B1",
-            container_options={
-                "masters": "2",
-            },
+        self.env_assist.assert_raise_library_error(
+            lambda: resource.bundle_update(
+                self.env_assist.get_env(),
+                "B1",
+                container_options={
+                    "masters": "2",
+                },
+            )
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    report_codes.INVALID_OPTIONS,
+                    force_code=report_codes.FORCE,
+                    option_names=["masters"],
+                    option_type="container",
+                    allowed=self.allowed_options,
+                    allowed_patterns=[],
+                ),
+            ]
         )
-        self.env_assist.assert_reports([self.fixture_report_deprecated_masters])
 
-    def _test_deprecated_options_remove(self):
+    def _test_legacy_options_can_be_removed(self):
         (
             self.config.runner.cib.load(
                 resources=self.fixture_cib_masters
@@ -431,50 +405,6 @@ class ContainerParametrized(TestCase):
             },
         )
 
-    def _test_masters_set_after_promoted_max(self):
-        (self.config.runner.cib.load(resources=self.fixture_cib_promoted_max))
-        self.env_assist.assert_raise_library_error(
-            lambda: resource.bundle_update(
-                self.env_assist.get_env(),
-                "B1",
-                container_options={
-                    "masters": "2",
-                },
-            )
-        )
-        self.env_assist.assert_reports(
-            [
-                self.fixture_report_deprecated_masters,
-                (
-                    severities.ERROR,
-                    report_codes.PREREQUISITE_OPTION_MUST_NOT_BE_SET,
-                    {
-                        "option_name": "masters",
-                        "option_type": "container",
-                        "prerequisite_name": "promoted-max",
-                        "prerequisite_type": "container",
-                    },
-                    None,
-                ),
-            ]
-        )
-
-    def _test_masters_set_after_promoted_max_with_remove(self):
-        (
-            self.config.runner.cib.load(
-                resources=self.fixture_cib_promoted_max
-            ).env.push_cib(resources=self.fixture_cib_masters)
-        )
-        resource.bundle_update(
-            self.env_assist.get_env(),
-            "B1",
-            container_options={
-                "masters": "2",
-                "promoted-max": "",
-            },
-        )
-        self.env_assist.assert_reports([self.fixture_report_deprecated_masters])
-
     def _test_promoted_max_set_after_masters(self):
         (self.config.runner.cib.load(resources=self.fixture_cib_masters))
         self.env_assist.assert_raise_library_error(
@@ -530,10 +460,6 @@ class ContainerPodman(
     container_type = "podman"
 
 
-class ContainerRkt(ContainerParametrized, metaclass=ParametrizedTestMetaClass):
-    container_type = "rkt"
-
-
 class ContainerUnknown(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
@@ -659,9 +585,7 @@ class ContainerUnknown(TestCase):
                 fixture.error(
                     report_codes.RESOURCE_BUNDLE_UNSUPPORTED_CONTAINER_TYPE,
                     bundle_id="B1",
-                    supported_container_types=sorted(
-                        ["rkt", "docker", "podman"]
-                    ),
+                    supported_container_types=sorted(["docker", "podman"]),
                     updating_options=True,
                 )
             ]
@@ -1193,7 +1117,7 @@ class Meta(TestCase):
     fixture_no_meta = """
         <resources>
             <bundle id="B1">
-                <docker image="pcs:test" masters="3" replicas="6"/>
+                <docker image="pcs:test" promoted-max="3" replicas="6"/>
             </bundle>
         </resources>
     """
@@ -1202,7 +1126,7 @@ class Meta(TestCase):
         <resources>
             <bundle id="B1">
                 <meta_attributes id="B1-meta_attributes" />
-                <docker image="pcs:test" masters="3" replicas="6"/>
+                <docker image="pcs:test" promoted-max="3" replicas="6"/>
             </bundle>
         </resources>
     """
@@ -1214,7 +1138,7 @@ class Meta(TestCase):
                 <nvpair id="B1-meta_attributes-target-role"
                     name="target-role" value="Stopped" />
                 </meta_attributes>
-                <docker image="pcs:test" masters="3" replicas="6"/>
+                <docker image="pcs:test" promoted-max="3" replicas="6"/>
             </bundle>
         </resources>
     """
@@ -1262,7 +1186,7 @@ class Meta(TestCase):
                     <nvpair id="B1-meta_attributes-is-managed"
                         name="is-managed" value="false" />
                     </meta_attributes>
-                    <docker image="pcs:test" masters="3" replicas="6"/>
+                    <docker image="pcs:test" promoted-max="3" replicas="6"/>
                 </bundle>
             </resources>
         """
@@ -1277,7 +1201,7 @@ class Meta(TestCase):
                     <nvpair id="B1-meta_attributes-resource-stickiness"
                         name="resource-stickiness" value="100" />
                     </meta_attributes>
-                    <docker image="pcs:test" masters="3" replicas="6"/>
+                    <docker image="pcs:test" promoted-max="3" replicas="6"/>
                 </bundle>
             </resources>
         """
@@ -1378,6 +1302,9 @@ class Wait(TestCase):
             [fixture.report_wait_for_idle_timed_out(wait_error_message)],
             expected_in_processor=False,
         )
+        self.env_assist.assert_reports(
+            [fixture.deprecation(reports.codes.RESOURCE_WAIT_DEPRECATED)]
+        )
 
     @mock.patch.object(
         settings,
@@ -1396,6 +1323,7 @@ class Wait(TestCase):
                 fixture.report_resource_running(
                     "B1", {"Started": ["node1", "node2"]}
                 ),
+                fixture.deprecation(reports.codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
@@ -1414,6 +1342,7 @@ class Wait(TestCase):
         self.env_assist.assert_reports(
             [
                 fixture.report_resource_not_running("B1", severities.INFO),
+                fixture.deprecation(reports.codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
 
