@@ -46,6 +46,10 @@ def _rsc_primitive_fixture(res_id):
     return f'<primitive id="{res_id}"/>'
 
 
+def _rsc_stonith_primitive_fixture(res_id):
+    return f'<primitive id="{res_id}" class="stonith"/>'
+
+
 def _rsc_clone_fixture(clone_id, primitive=None, is_promotable=False):
     if not primitive:
         primitive = _rsc_primitive_fixture(f"{clone_id}-primitive")
@@ -322,7 +326,7 @@ class MoveAutocleanSuccess(MoveAutocleanCommonSetup):
         )
         self.config.runner.pcmk.resource_move(
             resource=resource_id,
-            master=is_promotable,
+            promoted=is_promotable,
             node=self.new_node if with_node else None,
             env=dict(CIB_file=self.cib_rsc_move_tmp_file_name),
         )
@@ -334,7 +338,7 @@ class MoveAutocleanSuccess(MoveAutocleanCommonSetup):
         )
         self.config.runner.pcmk.resource_clear(
             resource=resource_id,
-            master=is_promotable,
+            promoted=is_promotable,
             node=self.new_node if with_node else None,
             env=dict(CIB_file=self.cib_constraint_removed_by_unmove_file_name),
         )
@@ -506,7 +510,7 @@ class MoveAutocleanSuccess(MoveAutocleanCommonSetup):
         move_autoclean(self.env_assist.get_env(), resource_id, strict=True)
         self.env_assist.assert_reports(self.get_reports(resource_id))
 
-    def test_master(self):
+    def test_promoted(self):
         resource_id = "clone-A"
         self.tmp_file_mock_obj.set_calls(
             self.get_tmp_files(_simulation_transition_fixture())
@@ -533,7 +537,7 @@ class MoveAutocleanSuccess(MoveAutocleanCommonSetup):
             ]
         )
 
-    def test_master_with_node(self):
+    def test_promoted_with_node(self):
         resource_id = "clone-A"
         self.tmp_file_mock_obj.set_calls(
             self.get_tmp_files(
@@ -570,7 +574,7 @@ class MoveAutocleanSuccess(MoveAutocleanCommonSetup):
             ]
         )
 
-    def test_master_with_node_strict(self):
+    def test_promoted_with_node_strict(self):
         resource_id = "clone-A"
         self.tmp_file_mock_obj.set_calls(
             self.get_tmp_files(_simulation_transition_fixture())
@@ -648,6 +652,24 @@ class MoveAutocleanValidations(MoveAutocleanCommonSetup):
             ]
         )
 
+    def test_resource_wrong_type_stonith(self):
+        stonith_id = "stonith_rsc"
+        self.config.runner.cib.load(
+            resources=_resources_tag(_rsc_stonith_primitive_fixture(stonith_id))
+        )
+        self.env_assist.assert_raise_library_error(
+            lambda: move_autoclean(self.env_assist.get_env(), stonith_id),
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    reports.codes.COMMAND_ARGUMENT_TYPE_MISMATCH,
+                    not_accepted_type="stonith resource",
+                    command_to_use_instead=None,
+                )
+            ]
+        )
+
     def test_resource_wrong_type_bundle_inner(self):
         bundle_id = "bundle_rsc"
         resource_id = "bundle_rsc-primitive"
