@@ -5,6 +5,7 @@ from unittest import (
 )
 
 from pcs.common import reports
+from pcs.common.resource_status import ResourceState
 from pcs.lib.commands import cib as lib
 
 from pcs_test.tools import fixture
@@ -60,9 +61,9 @@ def fixture_remote_resource(resource_id: str) -> str:
 
 def fixture_guest_resource(resource_id: str) -> str:
     return f"""
-        <primitive id="{resource_id}" class="ocf" type="VirtualDomain" provider="heartbeat">
+        <primitive id="{resource_id}" class="heartbeat" type="VirtualDomain">
             <meta_attributes id="meta">
-                <nvpair id="meta-remote-node" name="remote-node" value="{resource_id}-remote"/>
+                <nvpair id="meta-remote-node" name="remote-node" value="remote"/>
             </meta_attributes>
         </primitive>
     """
@@ -343,51 +344,28 @@ class RemoveElements(TestCase):
             """,
         )
         self.config.runner.cib.load_content(cib)
-        self.config.env.push_cib(
-            load_key="runner.cib.load_content", resources="<resources/>"
-        )
-        self.config.runner.pcmk.remove_node("R1-remote", name="remove_node-R1")
-        self.config.runner.pcmk.remove_node("R2-remote", name="remove_node-R2")
-        self.config.runner.pcmk.remove_node("R3-remote", name="remove_node-R3")
-        self.config.runner.pcmk.remove_node("R4-remote", name="remove_node-R4")
-
-        lib.remove_elements(
-            self.env_assist.get_env(),
-            ["R1", "R2", "R3", "R4"],
-            [reports.codes.FORCE],
+        self.env_assist.assert_raise_library_error(
+            lambda: lib.remove_elements(
+                self.env_assist.get_env(), ["R1", "R2", "R3", "R4"]
+            )
         )
         self.env_assist.assert_reports(
             [
-                fixture.deprecation(
-                    reports.codes.USE_COMMAND_NODE_REMOVE_GUEST
+                fixture.error(
+                    reports.codes.USE_COMMAND_NODE_REMOVE_GUEST,
+                    resource_id="R1",
                 ),
-                fixture.warn(
-                    reports.codes.STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED
+                fixture.error(
+                    reports.codes.USE_COMMAND_NODE_REMOVE_GUEST,
+                    resource_id="R2",
                 ),
-                fixture.warn(
-                    reports.codes.GUEST_NODE_REMOVAL_INCOMPLETE,
-                    node_name="R1-remote",
+                fixture.error(
+                    reports.codes.USE_COMMAND_NODE_REMOVE_GUEST,
+                    resource_id="R3",
                 ),
-                fixture.warn(
-                    reports.codes.GUEST_NODE_REMOVAL_INCOMPLETE,
-                    node_name="R2-remote",
-                ),
-                fixture.warn(
-                    reports.codes.GUEST_NODE_REMOVAL_INCOMPLETE,
-                    node_name="R3-remote",
-                ),
-                fixture.warn(
-                    reports.codes.GUEST_NODE_REMOVAL_INCOMPLETE,
-                    node_name="R4-remote",
-                ),
-                fixture.info(
-                    reports.codes.CIB_REMOVE_DEPENDANT_ELEMENTS,
-                    id_tag_map={
-                        "C1": "clone",
-                        "C2": "clone",
-                        "G1": "group",
-                        "G2": "group",
-                    },
+                fixture.error(
+                    reports.codes.USE_COMMAND_NODE_REMOVE_GUEST,
+                    resource_id="R4",
                 ),
             ]
         )
@@ -413,47 +391,28 @@ class RemoveElements(TestCase):
             """,
         )
         self.config.runner.cib.load_content(cib)
-        self.config.env.push_cib(
-            resources="<resources/>", load_key="runner.cib.load_content"
-        )
-        self.config.runner.pcmk.remove_node("R1", name="remove_node-R1")
-        self.config.runner.pcmk.remove_node("R2", name="remove_node-R2")
-        self.config.runner.pcmk.remove_node("R3", name="remove_node-R3")
-        self.config.runner.pcmk.remove_node("R4", name="remove_node-R4")
-
-        lib.remove_elements(
-            self.env_assist.get_env(),
-            ["R1", "R2", "R3", "R4"],
-            [reports.codes.FORCE],
+        self.env_assist.assert_raise_library_error(
+            lambda: lib.remove_elements(
+                self.env_assist.get_env(), ["R1", "R2", "R3", "R4"]
+            )
         )
         self.env_assist.assert_reports(
             [
-                fixture.deprecation(
-                    reports.codes.USE_COMMAND_NODE_REMOVE_REMOTE
+                fixture.error(
+                    reports.codes.USE_COMMAND_NODE_REMOVE_REMOTE,
+                    resource_id="R1",
                 ),
-                fixture.warn(
-                    reports.codes.STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED
+                fixture.error(
+                    reports.codes.USE_COMMAND_NODE_REMOVE_REMOTE,
+                    resource_id="R2",
                 ),
-                fixture.warn(
-                    reports.codes.REMOTE_NODE_REMOVAL_INCOMPLETE, node_name="R1"
+                fixture.error(
+                    reports.codes.USE_COMMAND_NODE_REMOVE_REMOTE,
+                    resource_id="R3",
                 ),
-                fixture.warn(
-                    reports.codes.REMOTE_NODE_REMOVAL_INCOMPLETE, node_name="R2"
-                ),
-                fixture.warn(
-                    reports.codes.REMOTE_NODE_REMOVAL_INCOMPLETE, node_name="R3"
-                ),
-                fixture.warn(
-                    reports.codes.REMOTE_NODE_REMOVAL_INCOMPLETE, node_name="R4"
-                ),
-                fixture.info(
-                    reports.codes.CIB_REMOVE_DEPENDANT_ELEMENTS,
-                    id_tag_map={
-                        "C1": "clone",
-                        "C2": "clone",
-                        "G1": "group",
-                        "G2": "group",
-                    },
+                fixture.error(
+                    reports.codes.USE_COMMAND_NODE_REMOVE_REMOTE,
+                    resource_id="R4",
                 ),
             ]
         )
@@ -991,3 +950,68 @@ class RemoveElementsStopResources(TestCase, StopResourcesWaitMixin):
                 ),
             ]
         )
+
+    def test_skip_state_check_on_missing_from_status(self):
+        self.config.runner.cib.load(
+            resources="""
+                <resources>
+                    <bundle id="test-bundle">
+                        <podman image="localhost/pcmktest:test"/>
+                        <primitive id="apa" class="ocf" type="apache" provider="heartbeat"/>
+                    </bundle>
+                </resources>
+            """
+        )
+        self.fixture_stop_resources_wait_calls(
+            self.config.calls.get("runner.cib.load").stdout,
+            initial_state_modifiers={"resources": "<resources/>"},
+            after_disable_cib_modifiers={
+                "resources": """
+                    <resources>
+                        <bundle id="test-bundle">
+                            <podman image="localhost/pcmktest:test"/>
+                            <primitive id="apa" class="ocf" type="apache" provider="heartbeat">
+                                <meta_attributes id="apa-meta_attributes">
+                                    <nvpair id="apa-meta_attributes-target-role" name="target-role" value="Stopped"/>
+                                </meta_attributes>
+                            </primitive>
+                        </bundle>
+                    </resources>
+                """
+            },
+            after_disable_state_modifiers={"resources": "<resources/>"},
+        )
+        self.fixture_push_cib_after_stopping(
+            resources="""
+                <resources>
+                    <bundle id="test-bundle">
+                        <podman image="localhost/pcmktest:test"/>
+                    </bundle>
+                </resources>
+            """
+        )
+        lib.remove_elements(self.env_assist.get_env(), ["apa"])
+        self.env_assist.assert_reports(
+            [
+                fixture.info(
+                    reports.codes.STOPPING_RESOURCES_BEFORE_DELETING,
+                    resource_id_list=["apa"],
+                ),
+                fixture.debug(
+                    reports.codes.CONFIGURED_RESOURCE_MISSING_IN_STATUS,
+                    resource_id="apa",
+                    checked_state=ResourceState.UNMANAGED,
+                ),
+                fixture.info(reports.codes.WAIT_FOR_IDLE_STARTED, timeout=0),
+                fixture.debug(
+                    reports.codes.CONFIGURED_RESOURCE_MISSING_IN_STATUS,
+                    resource_id="apa",
+                    checked_state=ResourceState.STOPPED,
+                ),
+                fixture.info(
+                    reports.codes.CIB_REMOVE_REFERENCES,
+                    id_tag_map={"apa": "primitive", "test-bundle": "bundle"},
+                    removing_references_from={"apa": {"test-bundle"}},
+                ),
+            ]
+        )
