@@ -1,4 +1,3 @@
-from functools import partial
 from unittest import (
     TestCase,
     mock,
@@ -89,7 +88,13 @@ expected_cib_unknown = """
 """
 
 
-class CreateMixin:
+class Create(TestCase):
+    _create = staticmethod(stonith.create)
+
+    @staticmethod
+    def _expected_cib(xml):
+        return "<resources>" + xml + "</resources>"
+
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
 
@@ -106,6 +111,9 @@ class CreateMixin:
         )
         self.config.runner.pcmk.load_fake_agent_metadata()
         self.config.runner.cib.load()
+        self.config.runner.pcmk.stonith_agent_self_validation(
+            instance_attributes, agent_name
+        )
         self.config.env.push_cib(
             resources=self._expected_cib(expected_cib_simple)
         )
@@ -166,7 +174,9 @@ class CreateMixin:
             ]
         )
 
-    def test_agent_self_validation_failure_forced(self):
+    def assert_agent_self_validation_warnings(
+        self, user_enabled, extra_reports
+    ):
         agent_name = "test_simple"
         instance_attributes = {
             "must-set": "value",
@@ -203,11 +213,12 @@ class CreateMixin:
             operations=[],
             meta_attributes={},
             instance_attributes=instance_attributes,
-            allow_invalid_instance_attributes=True,
-            enable_agent_self_validation=True,
+            allow_invalid_instance_attributes=user_enabled,
+            enable_agent_self_validation=user_enabled,
         )
         self.env_assist.assert_reports(
-            [
+            (extra_reports or [])
+            + [
                 fixture.warn(
                     reports.codes.AGENT_SELF_VALIDATION_RESULT,
                     result="not ignored\nfirst issue\nanother one",
@@ -215,6 +226,19 @@ class CreateMixin:
             ]
         )
 
+    def test_agent_self_validation_failure_forced(self):
+        self.assert_agent_self_validation_warnings(True, [])
+
+    def test_agent_self_validation_failure_default(self):
+        self.assert_agent_self_validation_warnings(
+            False,
+            [
+                fixture.warn(
+                    reports.codes.AGENT_SELF_VALIDATION_AUTO_ON_WITH_WARNINGS
+                ),
+            ],
+        )
+
     def test_agent_self_validation_invalid_output(self):
         agent_name = "test_simple"
         instance_attributes = {
@@ -255,8 +279,52 @@ class CreateMixin:
             ]
         )
 
+    def test_agent_self_validation_invalid_output_default(self):
+        agent_name = "test_simple"
+        instance_attributes = {
+            "must-set": "value",
+            "must-set-new": "B",
+        }
+
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
+        )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.runner.pcmk.stonith_agent_self_validation(
+            instance_attributes,
+            agent_name,
+            output="""<not valid> xml""",
+            returncode=0,
+        )
+        self.config.env.push_cib(
+            resources=self._expected_cib(expected_cib_simple)
+        )
+
+        self._create(
+            self.env_assist.get_env(),
+            "stonith-test",
+            agent_name,
+            operations=[],
+            meta_attributes={},
+            instance_attributes=instance_attributes,
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.AGENT_SELF_VALIDATION_AUTO_ON_WITH_WARNINGS
+                ),
+                fixture.warn(
+                    reports.codes.AGENT_SELF_VALIDATION_INVALID_DATA,
+                    reason="Specification mandates value for attribute valid, line 5, column 29 (<string>, line 5)",
+                ),
+            ]
+        )
+
     def test_unfencing(self):
         agent_name = "test_unfencing"
+        instance_attributes = {}
 
         self.config.runner.pcmk.load_agent(
             agent_name=f"stonith:{agent_name}",
@@ -264,6 +332,9 @@ class CreateMixin:
         )
         self.config.runner.pcmk.load_fake_agent_metadata()
         self.config.runner.cib.load()
+        self.config.runner.pcmk.stonith_agent_self_validation(
+            instance_attributes, agent_name
+        )
         self.config.env.push_cib(
             resources=self._expected_cib(expected_cib_unfencing)
         )
@@ -274,7 +345,7 @@ class CreateMixin:
             agent_name,
             operations=[],
             meta_attributes={},
-            instance_attributes={},
+            instance_attributes=instance_attributes,
         )
 
     def test_disabled(self):
@@ -301,6 +372,9 @@ class CreateMixin:
         )
         self.config.runner.pcmk.load_fake_agent_metadata()
         self.config.runner.cib.load()
+        self.config.runner.pcmk.stonith_agent_self_validation(
+            instance_attributes, agent_name
+        )
         self.config.env.push_cib(resources=self._expected_cib(expected_cib))
 
         self._create(
@@ -319,6 +393,7 @@ class CreateMixin:
         # it is worth testing. If it ever changes, the test should fail and be
         # updated to test new behaviour.
         agent_name = "test_custom_actions"
+        instance_attributes = {}
 
         self.config.runner.pcmk.load_agent(
             agent_name=f"stonith:{agent_name}",
@@ -326,6 +401,9 @@ class CreateMixin:
         )
         self.config.runner.pcmk.load_fake_agent_metadata()
         self.config.runner.cib.load()
+        self.config.runner.pcmk.stonith_agent_self_validation(
+            instance_attributes, agent_name
+        )
         self.config.env.push_cib(
             resources=self._expected_cib(expected_cib_operations)
         )
@@ -336,7 +414,7 @@ class CreateMixin:
             agent_name,
             operations=[],
             meta_attributes={},
-            instance_attributes={},
+            instance_attributes=instance_attributes,
             use_default_operations=use_default_operations,
         )
 
@@ -384,6 +462,9 @@ class CreateMixin:
         )
         self.config.runner.pcmk.load_fake_agent_metadata()
         self.config.runner.cib.load()
+        self.config.runner.pcmk.stonith_agent_self_validation(
+            instance_attributes, agent_name
+        )
         self.config.env.push_cib(
             resources=self._expected_cib(expected_cib_simple_forced)
         )
@@ -596,6 +677,9 @@ class CreateMixin:
         )
         self.config.runner.pcmk.load_fake_agent_metadata()
         self.config.runner.cib.load()
+        self.config.runner.pcmk.stonith_agent_self_validation(
+            instance_attributes, agent_name
+        )
         self.config.env.push_cib(
             resources=self._expected_cib(expected_cib_simple), wait=timeout
         )
@@ -617,114 +701,6 @@ class CreateMixin:
                     roles_with_nodes={"Started": ["node1"]},
                     resource_id=instance_name,
                 ),
+                fixture.deprecation(reports.codes.RESOURCE_WAIT_DEPRECATED),
             ]
         )
-
-
-class Create(CreateMixin, TestCase):
-    _create = staticmethod(stonith.create)
-
-    @staticmethod
-    def _expected_cib(xml):
-        return "<resources>" + xml + "</resources>"
-
-
-class CreateInGroup(CreateMixin, TestCase):
-    _create = staticmethod(
-        partial(stonith.create_in_group, group_id="my-group")
-    )
-
-    @staticmethod
-    def _expected_cib(xml):
-        return "<resources><group id='my-group'>" + xml + "</group></resources>"
-
-    @staticmethod
-    def _dummy(name):
-        return f"""
-            <primitive class="ocf" id="{name}" provider="pacemaker" type="Dummy"
-            />
-        """
-
-    def test_group_not_valid(self):
-        agent_name = "test_simple"
-
-        self.config.runner.pcmk.load_agent(
-            agent_name=f"stonith:{agent_name}",
-            agent_filename="stonith_agent_fence_simple.xml",
-        )
-        self.config.runner.pcmk.load_fake_agent_metadata()
-        self.config.runner.cib.load()
-
-        self.env_assist.assert_raise_library_error(
-            lambda: stonith.create_in_group(
-                self.env_assist.get_env(),
-                "stonith-test",
-                agent_name,
-                "0-group",
-                operations=[],
-                meta_attributes={},
-                instance_attributes={
-                    "must-set": "value",
-                    "must-set-new": "B",
-                },
-            ),
-            expected_in_processor=False,
-        )
-
-        self.env_assist.assert_reports(
-            [
-                fixture.error(
-                    reports.codes.INVALID_ID_BAD_CHAR,
-                    id="0-group",
-                    id_description="group name",
-                    is_first_char=True,
-                    invalid_character="0",
-                )
-            ]
-        )
-
-    def _assert_adjacent(self, adjacent, after):
-        agent_name = "test_simple"
-        instance_attributes = {
-            "must-set": "value",
-            "must-set-new": "B",
-        }
-        original_cib = (
-            "<resources><group id='my-group'>"
-            + self._dummy("dummy1")
-            + self._dummy("dummy2")
-            + "</group></resources>"
-        )
-        expected_cib = (
-            "<resources><group id='my-group'>"
-            + self._dummy("dummy1")
-            + expected_cib_simple
-            + self._dummy("dummy2")
-            + "</group></resources>"
-        )
-
-        self.config.runner.pcmk.load_agent(
-            agent_name=f"stonith:{agent_name}",
-            agent_filename="stonith_agent_fence_simple.xml",
-        )
-        self.config.runner.pcmk.load_fake_agent_metadata()
-        self.config.runner.cib.load(resources=original_cib)
-        self.config.env.push_cib(resources=expected_cib)
-
-        stonith.create_in_group(
-            self.env_assist.get_env(),
-            "stonith-test",
-            agent_name,
-            "my-group",
-            operations=[],
-            meta_attributes={},
-            instance_attributes=instance_attributes,
-            adjacent_resource_id=adjacent,
-            put_after_adjacent=after,
-        )
-
-    def test_put_after_adjacent(self):
-        self._assert_adjacent("dummy1", True)
-
-    def test_put_before_adjacent(self):
-        self._assert_adjacent("dummy2", False)
