@@ -1,6 +1,9 @@
 # pylint: disable=too-many-lines
 from unittest import TestCase
 
+from pcs.common.reports import codes as report_codes
+from pcs.lib.corosync import config_validators
+
 from pcs_test.tier0.lib.corosync.test_config_validators_common import (
     TotemBase,
     TransportKnetBase,
@@ -10,9 +13,6 @@ from pcs_test.tools import fixture
 from pcs_test.tools.assertions import assert_report_item_list_equal
 from pcs_test.tools.custom_mock import patch_getaddrinfo
 
-from pcs.common.reports import codes as report_codes
-from pcs.lib.corosync import config_validators
-
 # pylint: disable=no-self-use
 
 forbidden_characters_kwargs = dict(
@@ -514,13 +514,13 @@ class Create(TestCase):
             [
                 fixture.error(
                     report_codes.COROSYNC_IP_VERSION_MISMATCH_IN_LINKS,
-                    link_numbers=[0],
+                    link_numbers=["0"],
                 ),
                 fixture.error(
                     report_codes.COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK,
                     address="::ffff:10:0:0:1",
                     expected_address_type="IPv4",
-                    link_number=0,
+                    link_number="0",
                 ),
             ],
         )
@@ -540,13 +540,13 @@ class Create(TestCase):
             [
                 fixture.error(
                     report_codes.COROSYNC_IP_VERSION_MISMATCH_IN_LINKS,
-                    link_numbers=[0],
+                    link_numbers=["0"],
                 ),
                 fixture.error(
                     report_codes.COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK,
                     address="10.0.0.3",
                     expected_address_type="IPv6",
-                    link_number=0,
+                    link_number="0",
                 ),
             ],
         )
@@ -785,7 +785,7 @@ class Create(TestCase):
                 ),
                 fixture.error(
                     report_codes.COROSYNC_IP_VERSION_MISMATCH_IN_LINKS,
-                    link_numbers=[4, 6, 7],
+                    link_numbers=["4", "6", "7"],
                 ),
             ],
         )
