@@ -107,11 +107,20 @@ class Move(
     def test_wait_not_supported_with_file(self):
         self.assert_pcs_fail(
             "resource move-with-constraint A --wait".split(),
-            "Error: Cannot use '-f' together with '--wait'\n",
+            (
+                "Deprecation Warning: Using '--wait' is deprecated. Instead, "
+                "use the 'pcs status wait' command to wait for the cluster to "
+                "settle into stable state. Use the 'pcs status query resource' "
+                "commands to verify that the resource is in the expected state "
+                "after the wait.\n"
+                "Error: Cannot use '-f' together with '--wait'\n"
+            ),
         )
 
     def test_move_autoclean_not_supported_with_file(self):
         self.assert_pcs_fail(
             "resource move A".split(),
-            "Error: Specified option '-f' is not supported in this command\n",
+            "Error: Specified option '-f' is not supported in this command\n"
+            "Hint: Syntax has changed from previous version. See 'man pcs' -> "
+            "Changes in pcs-0.12.\n",
         )
