@@ -3,12 +3,15 @@ from pcs_test.tools.bin_mock import get_mock_settings
 
 
 class Enable(ResourceTest):
+    def setUp(self):
+        super().setUp()
+        self.pcs_runner.mock_settings = get_mock_settings()
+
     def test_enable_disabled_stonith(self):
-        self.pcs_runner.mock_settings = get_mock_settings("crm_resource_exec")
         self.assert_effect(
-            "stonith create S fence_xvm --disabled".split(),
+            "stonith create S fence_pcsmock_minimal --disabled".split(),
             """<resources>
-                <primitive class="stonith" id="S" type="fence_xvm">
+                <primitive class="stonith" id="S" type="fence_pcsmock_minimal">
                     <meta_attributes id="S-meta_attributes">
                         <nvpair id="S-meta_attributes-target-role"
                             name="target-role" value="Stopped"
@@ -25,7 +28,7 @@ class Enable(ResourceTest):
         self.assert_effect(
             "stonith enable S".split(),
             """<resources>
-                <primitive class="stonith" id="S" type="fence_xvm">
+                <primitive class="stonith" id="S" type="fence_pcsmock_minimal">
                     <meta_attributes id="S-meta_attributes"/>
                     <operations>
                         <op id="S-monitor-interval-60s" interval="60s"
@@ -37,9 +40,8 @@ class Enable(ResourceTest):
         )
 
     def test_keep_enabled_stonith(self):
-        self.pcs_runner.mock_settings = get_mock_settings("crm_resource_exec")
         result_xml = """<resources>
-            <primitive class="stonith" id="S" type="fence_xvm">
+            <primitive class="stonith" id="S" type="fence_pcsmock_minimal">
                 <operations>
                     <op id="S-monitor-interval-60s" interval="60s"
                         name="monitor"
@@ -48,17 +50,22 @@ class Enable(ResourceTest):
             </primitive>
         </resources>"""
 
-        self.assert_effect("stonith create S fence_xvm".split(), result_xml)
+        self.assert_effect(
+            "stonith create S fence_pcsmock_minimal".split(), result_xml
+        )
         self.assert_effect("stonith enable S".split(), result_xml)
 
 
 class Disable(ResourceTest):
+    def setUp(self):
+        super().setUp()
+        self.pcs_runner.mock_settings = get_mock_settings()
+
     def test_disable_enabled_stonith(self):
-        self.pcs_runner.mock_settings = get_mock_settings("crm_resource_exec")
         self.assert_effect(
-            "stonith create S fence_xvm".split(),
+            "stonith create S fence_pcsmock_minimal".split(),
             """<resources>
-                <primitive class="stonith" id="S" type="fence_xvm">
+                <primitive class="stonith" id="S" type="fence_pcsmock_minimal">
                     <operations>
                         <op id="S-monitor-interval-60s" interval="60s"
                             name="monitor"
@@ -70,7 +77,7 @@ class Disable(ResourceTest):
         self.assert_effect(
             "stonith disable S".split(),
             """<resources>
-                <primitive class="stonith" id="S" type="fence_xvm">
+                <primitive class="stonith" id="S" type="fence_pcsmock_minimal">
                     <meta_attributes id="S-meta_attributes">
                         <nvpair id="S-meta_attributes-target-role"
                             name="target-role" value="Stopped"
@@ -86,9 +93,8 @@ class Disable(ResourceTest):
         )
 
     def test_keep_disabled_stonith(self):
-        self.pcs_runner.mock_settings = get_mock_settings("crm_resource_exec")
         result_xml = """<resources>
-            <primitive class="stonith" id="S" type="fence_xvm">
+            <primitive class="stonith" id="S" type="fence_pcsmock_minimal">
                 <meta_attributes id="S-meta_attributes">
                     <nvpair id="S-meta_attributes-target-role"
                         name="target-role" value="Stopped"
@@ -102,6 +108,7 @@ class Disable(ResourceTest):
             </primitive>
         </resources>"""
         self.assert_effect(
-            "stonith create S fence_xvm --disabled".split(), result_xml
+            "stonith create S fence_pcsmock_minimal --disabled".split(),
+            result_xml,
         )
         self.assert_effect("stonith disable S".split(), result_xml)
