@@ -459,48 +459,16 @@ class UtilsTest(TestCase):
             ),
         )
 
-    def test_get_element_with_id(self):
-        dom = xml.dom.minidom.parseString(
-            """
-            <aa>
-                <bb id="bb1"/>
-                <bb/>
-                <bb id="bb2">
-                    <cc id="cc1"/>
-                </bb>
-                <bb id="bb3">
-                    <cc id="cc2"/>
-                </bb>
-            </aa>
-        """
-        ).documentElement
-
-        self.assert_element_id(
-            utils.dom_get_element_with_id(dom, "bb", "bb1"), "bb1"
-        )
-        self.assert_element_id(
-            utils.dom_get_element_with_id(dom, "bb", "bb2"), "bb2"
-        )
-        self.assert_element_id(
-            utils.dom_get_element_with_id(dom, "cc", "cc1"), "cc1"
-        )
-        self.assert_element_id(
-            utils.dom_get_element_with_id(
-                utils.dom_get_element_with_id(dom, "bb", "bb2"), "cc", "cc1"
-            ),
-            "cc1",
-        )
-        self.assertEqual(None, utils.dom_get_element_with_id(dom, "dd", "bb1"))
-        self.assertEqual(None, utils.dom_get_element_with_id(dom, "bb", "bb4"))
-        self.assertEqual(None, utils.dom_get_element_with_id(dom, "bb", "cc1"))
-        self.assertEqual(
-            None,
-            utils.dom_get_element_with_id(
-                utils.dom_get_element_with_id(dom, "bb", "bb2"), "cc", "cc2"
-            ),
-        )
-
     def test_dom_get_parent_by_tag_name(self):
+        def dom_get_element_with_id(dom, tag_name, element_id):
+            for elem in dom.getElementsByTagName(tag_name):
+                if (
+                    elem.hasAttribute("id")
+                    and elem.getAttribute("id") == element_id
+                ):
+                    return elem
+            return None
+
         dom = xml.dom.minidom.parseString(
             """
             <aa id="aa1">
@@ -515,8 +483,8 @@ class UtilsTest(TestCase):
             </aa>
         """
         ).documentElement
-        bb1 = utils.dom_get_element_with_id(dom, "bb", "bb1")
-        cc1 = utils.dom_get_element_with_id(dom, "cc", "cc1")
+        bb1 = dom_get_element_with_id(dom, "bb", "bb1")
+        cc1 = dom_get_element_with_id(dom, "cc", "cc1")
 
         self.assert_element_id(
             utils.dom_get_parent_by_tag_names(bb1, ["aa"]), "aa1"
@@ -846,13 +814,13 @@ class UtilsTest(TestCase):
             </resource>
         </clone>
         <clone id="myMaster">
-            <resource id="myMasteredResource:1" role="{const.PCMK_ROLE_UNPROMOTED_PRIMARY}">
+            <resource id="myMasteredResource:1" role="{const.PCMK_ROLE_UNPROMOTED}">
                 <node name="rh70-node2" />
             </resource>
-            <resource id="myMasteredResource" role="{const.PCMK_ROLE_UNPROMOTED_PRIMARY}">
+            <resource id="myMasteredResource" role="{const.PCMK_ROLE_UNPROMOTED}">
                 <node name="rh70-node3" />
             </resource>
-            <resource id="myMasteredResource" role="{const.PCMK_ROLE_PROMOTED_PRIMARY}">
+            <resource id="myMasteredResource" role="{const.PCMK_ROLE_PROMOTED}">
                 <node name="rh70-node1" />
             </resource>
         </clone>
@@ -885,17 +853,17 @@ class UtilsTest(TestCase):
         </clone>
         <clone id="myGroupMaster">
             <group id="myMasteredGroup:0">
-                 <resource id="myMasteredGroupedResource" role="{const.PCMK_ROLE_UNPROMOTED_PRIMARY}">
+                 <resource id="myMasteredGroupedResource" role="{const.PCMK_ROLE_UNPROMOTED}">
                      <node name="rh70-node1" />
                  </resource>
             </group>
             <group id="myMasteredGroup:1">
-                 <resource id="myMasteredGroupedResource" role="{const.PCMK_ROLE_PROMOTED_PRIMARY}">
+                 <resource id="myMasteredGroupedResource" role="{const.PCMK_ROLE_PROMOTED}">
                      <node name="rh70-node2" />
                  </resource>
             </group>
             <group id="myMasteredGroup:2">
-                 <resource id="myMasteredGroupedResource" role="{const.PCMK_ROLE_UNPROMOTED_PRIMARY}">
+                 <resource id="myMasteredGroupedResource" role="{const.PCMK_ROLE_UNPROMOTED}">
                      <node name="rh70-node3" />
                  </resource>
             </group>
@@ -937,8 +905,8 @@ class UtilsTest(TestCase):
                     "Resource 'myMasteredResource' is {promoted} on node "
                     "rh70-node1; {unpromoted} on nodes rh70-node2, rh70-node3."
                 ).format(
-                    promoted=str(const.PCMK_ROLE_PROMOTED_PRIMARY).lower(),
-                    unpromoted=str(const.PCMK_ROLE_UNPROMOTED_PRIMARY).lower(),
+                    promoted=str(const.PCMK_ROLE_PROMOTED).lower(),
+                    unpromoted=str(const.PCMK_ROLE_UNPROMOTED).lower(),
                 ),
                 "is_running": True,
             },
@@ -950,8 +918,8 @@ class UtilsTest(TestCase):
                     "Resource 'myMaster' is {promoted} on node "
                     "rh70-node1; {unpromoted} on nodes rh70-node2, rh70-node3."
                 ).format(
-                    promoted=str(const.PCMK_ROLE_PROMOTED_PRIMARY).lower(),
-                    unpromoted=str(const.PCMK_ROLE_UNPROMOTED_PRIMARY).lower(),
+                    promoted=str(const.PCMK_ROLE_PROMOTED).lower(),
+                    unpromoted=str(const.PCMK_ROLE_UNPROMOTED).lower(),
                 ),
                 "is_running": True,
             },
@@ -1003,8 +971,8 @@ class UtilsTest(TestCase):
                     "Resource 'myMasteredGroupedResource' is {promoted} on node "
                     "rh70-node2; {unpromoted} on nodes rh70-node1, rh70-node3."
                 ).format(
-                    promoted=str(const.PCMK_ROLE_PROMOTED_PRIMARY).lower(),
-                    unpromoted=str(const.PCMK_ROLE_UNPROMOTED_PRIMARY).lower(),
+                    promoted=str(const.PCMK_ROLE_PROMOTED).lower(),
+                    unpromoted=str(const.PCMK_ROLE_UNPROMOTED).lower(),
                 ),
                 "is_running": True,
             },
@@ -1016,8 +984,8 @@ class UtilsTest(TestCase):
                     "Resource 'myMasteredGroup' is {promoted} on node "
                     "rh70-node2; {unpromoted} on nodes rh70-node1, rh70-node3."
                 ).format(
-                    promoted=str(const.PCMK_ROLE_PROMOTED_PRIMARY).lower(),
-                    unpromoted=str(const.PCMK_ROLE_UNPROMOTED_PRIMARY).lower(),
+                    promoted=str(const.PCMK_ROLE_PROMOTED).lower(),
+                    unpromoted=str(const.PCMK_ROLE_UNPROMOTED).lower(),
                 ),
                 "is_running": True,
             },
@@ -1029,8 +997,8 @@ class UtilsTest(TestCase):
                     "Resource 'myGroupMaster' is {promoted} on node "
                     "rh70-node2; {unpromoted} on nodes rh70-node1, rh70-node3."
                 ).format(
-                    promoted=str(const.PCMK_ROLE_PROMOTED_PRIMARY).lower(),
-                    unpromoted=str(const.PCMK_ROLE_UNPROMOTED_PRIMARY).lower(),
+                    promoted=str(const.PCMK_ROLE_PROMOTED).lower(),
+                    unpromoted=str(const.PCMK_ROLE_UNPROMOTED).lower(),
                 ),
                 "is_running": True,
             },
@@ -1716,3 +1684,44 @@ class TouchCibFile(TestCase):
         err.assert_called_once_with(
             "Unable to write to file: '/fake/filename': 'some message'"
         )
+
+
+@mock.patch("pcs.utils.is_run_interactive", mock.Mock(return_value=False))
+class GetContinueConfirmation(TestCase):
+    def setUp(self):
+        self.text = "some warning text"
+        patcher_output = mock.patch("pcs.cli.reports.output.print_to_stderr")
+        self.addCleanup(patcher_output.stop)
+        self.mock_output = patcher_output.start()
+
+    def test_yes_force(self):
+        self.assertTrue(utils.get_continue_confirmation(self.text, True, True))
+        self.mock_output.assert_called_once_with(f"Warning: {self.text}")
+
+    def test_yes(self):
+        self.assertTrue(utils.get_continue_confirmation(self.text, True, False))
+        self.mock_output.assert_called_once_with(f"Warning: {self.text}")
+
+    def test_force(self):
+        self.assertTrue(utils.get_continue_confirmation(self.text, False, True))
+        self.assertEqual(
+            self.mock_output.mock_calls,
+            [
+                mock.call(
+                    "Deprecation Warning: Using --force to confirm this action "
+                    "is deprecated and might be removed in a future release, "
+                    "use --yes instead"
+                ),
+                mock.call(f"Warning: {self.text}"),
+            ],
+        )
+
+    def test_nothing(self):
+        with self.assertRaises(SystemExit) as cm:
+            self.assertFalse(
+                utils.get_continue_confirmation(self.text, False, False)
+            )
+        self.assertEqual(cm.exception.code, 1)
+        self.mock_output.assert_called_once_with(
+            f"Error: {self.text}, use --yes to override"
+        )
