@@ -701,6 +701,16 @@ class CleanEnableAuthfile(BoothMixin, TestCase):
             )
 
 
+class TicketCleanup(BoothMixinNoFiles, TestCase):
+    def test_too_many_args(self):
+        self.assert_pcs_fail(
+            ["booth", "ticket", "cleanup", "a", "b"],
+            stderr_start=(
+                "\nUsage: pcs booth <command>\n    ticket cleanup [ticket]\n"
+            ),
+        )
+
+
 class BoothTicketOperationBase(BoothMixinNoFiles):
     command = ""
 
@@ -723,10 +733,6 @@ class BoothTicketOperationBase(BoothMixinNoFiles):
         )
 
 
-class TicketCleanup(BoothTicketOperationBase, TestCase):
-    command = "cleanup"
-
-
 class TicketUnstandby(BoothTicketOperationBase, TestCase):
     command = "unstandby"
 
