@@ -197,38 +197,6 @@ class StonithWarningTest(TestCase, AssertPcsMixin):
                 ),
             )
 
-    def test_no_stonith_warning_when_stonith_in_group(self):
-        self.assert_pcs_success(
-            "stonith create S fence_pcsmock_minimal --group G".split(),
-            stderr_full=(
-                "Deprecation Warning: Option to group stonith resource is "
-                "deprecated and will be removed in a future release.\n"
-            ),
-        )
-        self.pcs_runner.corosync_conf_opt = self.corosync_conf
-        if PCMK_2_0_3_PLUS:
-            self.assert_pcs_success(
-                ["status"],
-                stdout_start=dedent(
-                    """\
-                    Cluster name: test99
-                    Cluster Summary:
-                """
-                ),
-            )
-        else:
-            self.assert_pcs_success(
-                ["status"],
-                stdout_start=dedent(
-                    """\
-                    Cluster name: test99
-
-                    Stack: unknown
-                    Current DC: NONE
-                """
-                ),
-            )
-
     def test_disabled_stonith_does_not_care_about_missing_devices(self):
         self.assert_pcs_success("property set stonith-enabled=false".split())
         self.pcs_runner.corosync_conf_opt = self.corosync_conf
