@@ -496,6 +496,80 @@ class PcmkShortcuts:
             instead=instead,
         )
 
+    def is_crm_attribute_list_options_supported(
+        self,
+        name="runner.pcmk.is_crm_attribute_list_options_supported",
+        is_supported=True,
+    ):
+        """
+        Create call for `crm_attribute --help-all`. If is_supported is True,
+        option --list-options is included in command output.
+
+        name -- key of the call
+        is_supported -- flags which decides if digests are supported
+        """
+        self.__calls.place(
+            name,
+            RunnerCall(
+                [settings.crm_attribute_exec, "--help-all"],
+                stdout="--list-options" if is_supported else "",
+                stderr="",
+                returncode=0,
+            ),
+        )
+
+    def load_crm_attribute_metadata(
+        self,
+        name: str = "runner.pcmk.load_crm_attribute_metadata",
+        agent_name: str = "cluster-options",
+        stdout: Optional[str] = None,
+        stderr: str = "",
+        returncode: int = 0,
+        instead: Optional[str] = None,
+        before: Optional[str] = None,
+    ) -> None:
+        """
+        Create a call for loading crm_attribute metadata - metadata provided by
+        `crm_attribute --list-options=TYPE`
+
+        name -- the key of this call
+        agent_name -- name of the crm_attribute agent
+        stdout -- crm_attribute agent stdout, default metadata if None
+        stderr -- crm_attribute agent stderr
+        returncode -- crm_attribute agent returncode
+        instead -- the key of a call instead of which this new call is to
+            be placed
+        before -- the key of a call before which this new call is to be placed
+        """
+        name_to_metadata_file = {
+            "cluster-options": "cluster-options_metadata.xml"
+        }
+        name_to_list_options_type = {"cluster-options": "cluster"}
+        if stdout is None:
+            with open(rc(name_to_metadata_file[agent_name])) as a_file:
+                stdout = a_file.read()
+        self.__calls.place(
+            name,
+            RunnerCall(
+                [
+                    settings.crm_attribute_exec,
+                    "--list-options",
+                    (
+                        name_to_list_options_type[agent_name]
+                        if agent_name in name_to_list_options_type
+                        else agent_name
+                    ),
+                    "--output-as",
+                    "xml",
+                ],
+                stdout=stdout,
+                stderr=stderr,
+                returncode=returncode,
+            ),
+            before=before,
+            instead=instead,
+        )
+
     def local_node_name(
         self,
         name="runner.pcmk.local_node_name",
@@ -676,7 +750,7 @@ class PcmkShortcuts:
         before=None,
         resource=None,
         node=None,
-        master=None,
+        promoted=None,
         lifetime=None,
         stdout="",
         stderr="",
@@ -693,7 +767,7 @@ class PcmkShortcuts:
             placed
         string resource -- the id of a resource to be moved
         string node -- the name of a destination node
-        bool master -- limit move to master role
+        bool promoted -- limit move to promoted role
         string lifetime -- lifetime of the created moving constraint
         string stdout -- crm_resource's stdout
         string stderr -- crm_resource's stderr
@@ -715,7 +789,7 @@ class PcmkShortcuts:
         before=None,
         resource=None,
         node=None,
-        master=None,
+        promoted=None,
         lifetime=None,
         stdout="",
         stderr="",
@@ -731,7 +805,7 @@ class PcmkShortcuts:
             placed
         string resource -- the id of a resource to be banned
         string node -- the name of a destination node
-        bool master -- limit ban to master role
+        bool promoted -- limit ban to promoted role
         string lifetime -- lifetime of the created banning constraint
         string stdout -- crm_resource's stdout
         string stderr -- crm_resource's stderr
@@ -752,7 +826,7 @@ class PcmkShortcuts:
         before=None,
         resource=None,
         node=None,
-        master=None,
+        promoted=None,
         expired=None,
         stdout="",
         stderr="",
@@ -769,7 +843,7 @@ class PcmkShortcuts:
             placed
         string resource -- the id of a resource to be unmoved/unbanned
         string node -- the name of a destination node
-        bool master -- limit clearing to master role
+        bool promoted -- limit clearing to promoted role
         bool epired -- clear only expired moves and bans
         string stdout -- crm_resource's stdout
         string stderr -- crm_resource's stderr
@@ -792,7 +866,7 @@ class PcmkShortcuts:
         before=None,
         resource=None,
         node=None,
-        master=None,
+        promoted=None,
         lifetime=None,
         expired=None,
         stdout="",
@@ -805,8 +879,8 @@ class PcmkShortcuts:
             cmd.extend(["--resource", resource])
         if node:
             cmd.extend(["--node", node])
-        if master:
-            cmd.extend(["--master"])
+        if promoted:
+            cmd.extend(["--promoted"])
         if lifetime:
             cmd.extend(["--lifetime", lifetime])
         if expired:
@@ -1104,9 +1178,20 @@ class PcmkShortcuts:
             cmd.extend(["--provider", provider])
         for key, value in sorted(attributes.items()):
             cmd.extend(["--option", f"{key}={value}"])
-        if output is not None:
-            cmd_str = " ".join(cmd)
-            provider_str = f' provider="{provider}"' if provider else ""
+
+        cmd_str = " ".join(cmd)
+        provider_str = f' provider="{provider}"' if provider else ""
+        if output is None:
+            stdout = f"""
+            <pacemaker-result api-version="2.15" request="{cmd_str}">
+              <resource-agent-action action="validate" class="{standard}" type="{agent_type}"{provider_str}>
+                <overrides/>
+                <agent-status code="0" message="ok" execution_code="0" execution_message="complete"/>
+              </resource-agent-action>
+              <status code="0" message="OK"/>
+            </pacemaker-result>
+            """
+        else:
             stdout = f"""
             <pacemaker-result api-version="2.15" request="{cmd_str}">
               <resource-agent-action action="validate" class="{standard}" type="{agent_type}"{provider_str}>
@@ -1123,6 +1208,7 @@ class PcmkShortcuts:
               </status>
             </pacemaker-result>
             """
+
         self.__calls.place(
             name,
             RunnerCall(cmd, stdout=stdout, returncode=returncode, env=env),
@@ -1154,8 +1240,19 @@ class PcmkShortcuts:
         ]
         for key, value in sorted(attributes.items()):
             cmd.extend(["--option", f"{key}={value}"])
-        if output is not None:
-            cmd_str = " ".join(cmd)
+
+        cmd_str = " ".join(cmd)
+        if output is None:
+            stdout = f"""
+            <pacemaker-result api-version="2.22" request="{cmd_str}">
+              <validate agent="{agent}" valid="true">
+                <command code="0">
+                </command>
+              </validate>
+              <status code="0" message="OK"/>
+            </pacemaker-result>
+            """
+        else:
             stdout = f"""
             <pacemaker-result api-version="2.22" request="{cmd_str}">
               <validate agent="{agent}" valid="false">
@@ -1166,6 +1263,7 @@ class PcmkShortcuts:
               <status code="1" message="Error occurred"/>
             </pacemaker-result>
             """
+
         self.__calls.place(
             name,
             RunnerCall(cmd, stdout=stdout, returncode=returncode, env=env),
