@@ -1,4 +1,5 @@
 import xml.dom.minidom
+
 from lxml import etree
 
 
@@ -12,10 +13,12 @@ def dom_get_child_elements(element):
 
 def etree_to_str(tree):
     # etree returns string in bytes: b'xml'
-    # python 3 removed .encode() from byte strings
-    # run(...) calls subprocess.Popen.communicate which calls encode...
     # so there is bytes to str conversion
-    return etree.tostring(tree).decode()
+    return etree.tostring(tree, pretty_print=True).decode()
+
+
+def str_to_etree(string):
+    return etree.fromstring(string)
 
 
 class XmlManipulation:
@@ -25,7 +28,7 @@ class XmlManipulation:
 
     @classmethod
     def from_str(cls, string):
-        return cls(etree.fromstring(string))
+        return cls(str_to_etree(string))
 
     def __init__(self, tree):
         self.tree = tree
