@@ -110,7 +110,7 @@ def add_location_constraint_rule(
       cmd << "score-attribute=#{score}"
     end
   end
-  cmd.concat(rule.shellsplit())
+  cmd << rule
   flags = []
   flags << '--force' if force
   stdout, stderr, retval = run_cmd(auth_user, PCS, *flags, "--", *cmd)
@@ -195,7 +195,7 @@ def add_colocation_constraint(
     score = "INFINITY"
   end
   command = [
-    "constraint", "colocation", "add", resourceA, "with", resourceB, score
+    "constraint", "colocation", "add", resourceA, "with", resourceB, "score=#{score}"
   ]
   flags = []
   flags << '--force' if force
@@ -844,7 +844,7 @@ def run_cmd(auth_user, *args)
 end
 
 def run_cmd_options(auth_user, options, *args)
-  $logger.info("Running: " + args.join(" "))
+  $logger.info("Running: #{args}")
   cib_user = auth_user[:username]
   # when running 'id -Gn' to get the groups they are not defined yet
   cib_groups = (auth_user[:usergroups] || []).join(' ')
